searchNodes=[{"doc":"GenLSP is an OTP behaviour for building processes that implement the Language Server Protocol . Examples Credo language server. defmodule Credo.Lsp do @moduledoc \"\"\" LSP implementation for Credo. \"\"\" use GenLSP alias GenLSP.Enumerations.TextDocumentSyncKind alias GenLSP.Notifications.{ Exit, Initialized, TextDocumentDidChange, TextDocumentDidClose, TextDocumentDidOpen, TextDocumentDidSave } alias GenLSP.Requests.{Initialize, Shutdown} alias GenLSP.Structures.{ InitializeParams, InitializeResult, SaveOptions, ServerCapabilities, TextDocumentSyncOptions } alias Credo.Lsp.Cache, as: Diagnostics def start_link(args) do GenLSP.start_link(__MODULE__, args, []) end @impl true def init(lsp, args) do cache = Keyword.fetch!(args, :cache) {:ok, assign(lsp, exit_code: 1, cache: cache)} end @impl true def handle_request(%Initialize{params: %InitializeParams{root_uri: root_uri}}, lsp) do {:reply, %InitializeResult{ capabilities: %ServerCapabilities{ text_document_sync: %TextDocumentSyncOptions{ open_close: true, save: %SaveOptions{include_text: true}, change: TextDocumentSyncKind.full() } }, server_info: %{name: \"Credo\"} }, assign(lsp, root_uri: root_uri)} end def handle_request(%Shutdown{}, lsp) do {:noreply, assign(lsp, exit_code: 0)} end @impl true def handle_notification(%Initialized{}, lsp) do GenLSP.log(lsp, :log, \"[Credo] LSP Initialized!\") Diagnostics.refresh(lsp.assigns.cache, lsp) Diagnostics.publish(lsp.assigns.cache, lsp) {:noreply, lsp} end def handle_notification(%TextDocumentDidSave{}, lsp) do Task.start_link(fn -> Diagnostics.clear(lsp.assigns.cache) Diagnostics.refresh(lsp.assigns.cache, lsp) Diagnostics.publish(lsp.assigns.cache, lsp) end) {:noreply, lsp} end def handle_notification(%TextDocumentDidChange{}, lsp) do Task.start_link(fn -> Diagnostics.clear(lsp.assigns.cache) Diagnostics.publish(lsp.assigns.cache, lsp) end) {:noreply, lsp} end def handle_notification(%note{}, lsp) when note in [TextDocumentDidOpen, TextDocumentDidClose] do {:noreply, lsp} end def handle_notification(%Exit{}, lsp) do System.halt(lsp.assigns.exit_code) {:noreply, lsp} end def handle_notification(_thing, lsp) do {:noreply, lsp} end end defmodule Credo.Lsp.Cache do @moduledoc \"\"\" Cache for Credo diagnostics. \"\"\" use Agent alias GenLSP.Structures.{ Diagnostic, Position, PublishDiagnosticsParams, Range } alias GenLSP.Notifications.TextDocumentPublishDiagnostics def start_link(_) do Agent.start_link(fn -> Map.new() end) end def refresh(cache, lsp) do dir = URI.new!(lsp.assigns.root_uri).path issues = Credo.Execution.get_issues(Credo.run([\"--strict\", \"--all\", \"\#{dir}/**/*.ex\"])) GenLSP.log(lsp, :info, \"[Credo] Found \#{Enum.count(issues)} issues\") for issue Map.update(cache, Path.absname(filename), [diagnostic], fn v -> [diagnostic | v] end) end) end def clear(cache) do Agent.update(cache, fn cache -> for {k, _}","ref":"GenLSP.html","title":"GenLSP","type":"behaviour"},{"doc":"Send a window/logMessage error notification to the client. See GenLSP.Enumerations.MessageType.error/0 . Usage GenLSP . error ( lsp , &quot;Failed to compiled!&quot; )","ref":"GenLSP.html#error/2","title":"GenLSP.error/2","type":"function"},{"doc":"The callback responsible for handling normal messages. Receives the message as the first argument and the LSP token GenLSP.LSP.t/0 as the second. Usage @impl true def handle_info ( message , lsp ) do # handle the message { :noreply , lsp } end","ref":"GenLSP.html#c:handle_info/2","title":"GenLSP.handle_info/2","type":"callback"},{"doc":"The callback responsible for handling notifications from the client. Receives the notification struct as the first argument and the LSP token GenLSP.LSP.t/0 as the second. Usage @impl true def handle_notification ( % Initialized { } , lsp ) do # handle the notification { :noreply , lsp } end","ref":"GenLSP.html#c:handle_notification/2","title":"GenLSP.handle_notification/2","type":"callback"},{"doc":"The callback responsible for handling requests from the client. Receives the request struct as the first argument and the LSP token GenLSP.LSP.t/0 as the second. Usage @impl true def handle_request ( % Initialize { params : % InitializeParams { root_uri : root_uri } } , lsp ) do { :reply , % InitializeResult { capabilities : % ServerCapabilities { text_document_sync : % TextDocumentSyncOptions { open_close : true , save : % SaveOptions { include_text : true } , change : TextDocumentSyncKind . full ( ) } } , server_info : %{ name : &quot;MyLSP&quot; } } , assign ( lsp , root_uri : root_uri ) } end","ref":"GenLSP.html#c:handle_request/2","title":"GenLSP.handle_request/2","type":"callback"},{"doc":"Send a window/logMessage info notification to the client. See GenLSP.Enumerations.MessageType.info/0 . Usage GenLSP . info ( lsp , &quot;Compilation complete!&quot; )","ref":"GenLSP.html#info/2","title":"GenLSP.info/2","type":"function"},{"doc":"The callback responsible for initializing the process. Receives the GenLSP.LSP.t/0 token as the first argument and the arguments that were passed to GenLSP.start_link/3 as the second. Usage @impl true def init ( lsp , args ) do some_arg = Keyword . fetch! ( args , :some_arg ) { :ok , assign ( lsp , static_assign : :some_assign , some_arg : some_arg ) } end","ref":"GenLSP.html#c:init/2","title":"GenLSP.init/2","type":"callback"},{"doc":"Send a window/logMessage log notification to the client. See GenLSP.Enumerations.MessageType.log/0 . Usage GenLSP . log ( lsp , &quot;Starting compilation.&quot; )","ref":"GenLSP.html#log/2","title":"GenLSP.log/2","type":"function"},{"doc":"Sends a notification to the client from the LSP process. Usage GenLSP . notify ( lsp , % TextDocumentPublishDiagnostics { params : % PublishDiagnosticsParams { uri : &quot;file:// \#{ file } &quot; , diagnostics : diagnostics } } )","ref":"GenLSP.html#notify/2","title":"GenLSP.notify/2","type":"function"},{"doc":"Sends a notification from the client to the LSP process. Generally used by the GenLSP.Communication.Adapter implementation to forward messages from the buffer to the LSP process. You shouldn't need to use this to implement a language server.","ref":"GenLSP.html#notify_server/2","title":"GenLSP.notify_server/2","type":"function"},{"doc":"Sends a request to the client from the LSP process. Usage GenLSP . request ( lsp , % ClientRegisterCapability { id : System . unique_integer ( [ :positive ] ) , params : params } )","ref":"GenLSP.html#request/2","title":"GenLSP.request/2","type":"function"},{"doc":"Sends a request from the client to the LSP process. Generally used by the GenLSP.Communication.Adapter implementation to forward messages from the buffer to the LSP process. You shouldn't need to use this to implement a language server.","ref":"GenLSP.html#request_server/2","title":"GenLSP.request_server/2","type":"function"},{"doc":"Starts a GenLSP process that is linked to the current process. Options :buffer - The pid/0 or name of the GenLSP.Buffer process. :name ( atom/0 ) - Used for name registration as described in the &quot;Name registration&quot; section in the documentation for GenServer .","ref":"GenLSP.html#start_link/3","title":"GenLSP.start_link/3","type":"function"},{"doc":"Send a window/logMessage error notification to the client. See GenLSP.Enumerations.MessageType.warning/0 . Usage GenLSP . warning ( lsp , &quot;Variable `foo` is unused.&quot; )","ref":"GenLSP.html#warning/2","title":"GenLSP.warning/2","type":"function"},{"doc":"","ref":"GenLSP.BaseTypes.html","title":"GenLSP.BaseTypes","type":"module"},{"doc":"","ref":"GenLSP.BaseTypes.html#t:document_uri/0","title":"GenLSP.BaseTypes.document_uri/0","type":"type"},{"doc":"","ref":"GenLSP.BaseTypes.html#t:null/0","title":"GenLSP.BaseTypes.null/0","type":"type"},{"doc":"","ref":"GenLSP.BaseTypes.html#t:uinteger/0","title":"GenLSP.BaseTypes.uinteger/0","type":"type"},{"doc":"","ref":"GenLSP.BaseTypes.html#t:uri/0","title":"GenLSP.BaseTypes.uri/0","type":"type"},{"doc":"The data buffer between the LSP process and the communication channel.","ref":"GenLSP.Buffer.html","title":"GenLSP.Buffer","type":"module"},{"doc":"Returns a specification to start this module under a supervisor. See Supervisor .","ref":"GenLSP.Buffer.html#child_spec/1","title":"GenLSP.Buffer.child_spec/1","type":"function"},{"doc":"Starts a GenLSP.Buffer process that is linked to the current process. Options :communication - A {module, args} tuple, where module implements the GenLSP.Communication.Adapter behaviour. The default value is {GenLSP.Communication.Stdio, []} . :name ( atom/0 ) - Used for name registration as described in the &quot;Name registration&quot; section in the documentation for GenServer .","ref":"GenLSP.Buffer.html#start_link/1","title":"GenLSP.Buffer.start_link/1","type":"function"},{"doc":"Behaviour for implementing communication adapters for the GenLSP.Buffer module to use. Existing implementations: GenLSP.Communication.Stdio GenLSP.Communication.TCP","ref":"GenLSP.Communication.Adapter.html","title":"GenLSP.Communication.Adapter","type":"behaviour"},{"doc":"Initialize the adapter. Here you should return any state that should be passed into the other callbacks.","ref":"GenLSP.Communication.Adapter.html#c:init/1","title":"GenLSP.Communication.Adapter.init/1","type":"callback"},{"doc":"Tells the adapter to begin listening for data.","ref":"GenLSP.Communication.Adapter.html#c:listen/1","title":"GenLSP.Communication.Adapter.listen/1","type":"callback"},{"doc":"Read from the client. This callback should read a packet of data from the client and return it as the second element in the tuple. The third element can be used to return any data that as already been read from the client but still needs to be parsed into a packet.","ref":"GenLSP.Communication.Adapter.html#c:read/2","title":"GenLSP.Communication.Adapter.read/2","type":"callback"},{"doc":"Write data to the client.","ref":"GenLSP.Communication.Adapter.html#c:write/2","title":"GenLSP.Communication.Adapter.write/2","type":"callback"},{"doc":"","ref":"GenLSP.Communication.Adapter.html#t:state/0","title":"GenLSP.Communication.Adapter.state/0","type":"type"},{"doc":"The Standard IO adapter. This is the default adapter, and is the communication channel that most LSP clients expect to be able to use.","ref":"GenLSP.Communication.Stdio.html","title":"GenLSP.Communication.Stdio","type":"module"},{"doc":"The TCP adapter. This adapter can be used to launch the LSP with a given port and can be connected to by multiple clients. This adapter is also used during test by GenLSP.Test .","ref":"GenLSP.Communication.TCP.html","title":"GenLSP.Communication.TCP","type":"module"},{"doc":"A Response Message sent as a result of a request. If a request doesn’t provide a result value the receiver of a request still needs to return a response message to conform to the JSON-RPC specification. The result property of the ResponseMessage should be set to null in this case to signal a successful request.","ref":"GenLSP.ErrorResponse.html","title":"GenLSP.ErrorResponse","type":"module"},{"doc":"","ref":"GenLSP.ErrorResponse.html#schematic/0","title":"GenLSP.ErrorResponse.schematic/0","type":"function"},{"doc":"","ref":"GenLSP.ErrorResponse.html#t:t/0","title":"GenLSP.ErrorResponse.t/0","type":"type"},{"doc":"","ref":"GenLSP.LSP.html","title":"GenLSP.LSP","type":"module"},{"doc":"The LSP data structure.","ref":"GenLSP.LSP.html#__struct__/0","title":"GenLSP.LSP.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.LSP.html#assign/2","title":"GenLSP.LSP.assign/2","type":"function"},{"doc":"","ref":"GenLSP.LSP.html#t:t/0","title":"GenLSP.LSP.t/0","type":"type"},{"doc":"","ref":"GenLSP.Notifications.html","title":"GenLSP.Notifications","type":"module"},{"doc":"","ref":"GenLSP.Notifications.html#new/1","title":"GenLSP.Notifications.new/1","type":"function"},{"doc":"","ref":"GenLSP.Requests.html","title":"GenLSP.Requests","type":"module"},{"doc":"","ref":"GenLSP.Requests.html#new/1","title":"GenLSP.Requests.new/1","type":"function"},{"doc":"Conveniences for testing GenLSP processes.","ref":"GenLSP.Test.html","title":"GenLSP.Test","type":"module"},{"doc":"Simple helper to determine whether the LSP process is alive.","ref":"GenLSP.Test.html#alive?/1","title":"GenLSP.Test.alive?/1","type":"function"},{"doc":"Assert on the error response of a request that was sent with GenLSP.Test.request/2 . The second argument is a pattern, similar to ExUnit.Assertions.assert_receive/3 . Usage import GenLSP.Test id = 3 request ( client , %{ method : &quot;textDocument/documentSymbol&quot; , id : id , jsonrpc : &quot;2.0&quot; , params : %{ textDocument : %{ uri : &quot;file://file/doesnt/matter.ex&quot; } } } ) assert_error ( ^ id , %{ &quot;code&quot; =&gt; - 32601 , &quot;message&quot; =&gt; &quot;Method Not Found&quot; } )","ref":"GenLSP.Test.html#assert_error/3","title":"GenLSP.Test.assert_error/3","type":"macro"},{"doc":"Assert on a notification that was sent from the server. The second argument is a pattern, similar to ExUnit.Assertions.assert_receive/3 . Usage import GenLSP.Test notify ( client , %{ method : &quot;initialized&quot; , jsonrpc : &quot;2.0&quot; , params : %{ } } ) assert_notification ( &quot;window/logMessage&quot; , %{ &quot;message&quot; =&gt; &quot;[MyLSP] LSP Initialized!&quot; , &quot;type&quot; =&gt; 4 } )","ref":"GenLSP.Test.html#assert_notification/3","title":"GenLSP.Test.assert_notification/3","type":"macro"},{"doc":"Assert on a request that was sent from the server. Usage assert_request ( client , &quot;client/registerCapability&quot; , 1000 , fn params -&gt; assert params == %{ &quot;registrations&quot; =&gt; [ %{ &quot;id&quot; =&gt; &quot;file-watching&quot; , &quot;method&quot; =&gt; &quot;workspace/didChangeWatchedFiles&quot; , &quot;registerOptions&quot; =&gt; %{ &quot;watchers&quot; =&gt; [ %{ &quot;globPattern&quot; =&gt; &quot;{lib|test}/**/*.{ex|exs|heex|eex|leex|surface}&quot; } ] } } ] } nil end )","ref":"GenLSP.Test.html#assert_request/4","title":"GenLSP.Test.assert_request/4","type":"macro"},{"doc":"Assert on the successful response of a request that was sent with GenLSP.Test.request/2 . The second argument is a pattern, similar to ExUnit.Assertions.assert_receive/3 . Usage import GenLSP.Test id = 1 request ( client , %{ method : &quot;initialize&quot; , id : id , jsonrpc : &quot;2.0&quot; , params : %{ capabilities : %{ } , rootUri : &quot;file:// \#{ root_path } &quot; } } ) assert_result ( ^ id , %{ &quot;capabilities&quot; =&gt; %{ &quot;textDocumentSync&quot; =&gt; %{ &quot;openClose&quot; =&gt; true , &quot;save&quot; =&gt; %{ &quot;includeText&quot; =&gt; true } , &quot;change&quot; =&gt; 1 } } , &quot;serverInfo&quot; =&gt; %{ &quot;name&quot; =&gt; &quot;Credo&quot; } } )","ref":"GenLSP.Test.html#assert_result/3","title":"GenLSP.Test.assert_result/3","type":"macro"},{"doc":"Starts a new LSP client for the given server. The &quot;client&quot; is equivalent to a text editor. Usage import GenLSP.Test server = server ( MyLSP , some_arg : some_arg ) client = client ( server )","ref":"GenLSP.Test.html#client/1","title":"GenLSP.Test.client/1","type":"function"},{"doc":"Send a notification from the client to the server. Usage import GenLSP.Test notify ( client , %{ method : &quot;initialized&quot; , jsonrpc : &quot;2.0&quot; , params : %{ } } )","ref":"GenLSP.Test.html#notify/2","title":"GenLSP.Test.notify/2","type":"function"},{"doc":"Send a request from the client to the server. The response from the server will be sent as a message to the current process and can be asserted on using GenLSP.Test.assert_result/3 . Usage import GenLSP.Test request ( client , %{ method : &quot;initialize&quot; , id : 1 , jsonrpc : &quot;2.0&quot; , params : %{ capabilities : %{ } , rootUri : &quot;file:// \#{ root_path } &quot; } } )","ref":"GenLSP.Test.html#request/2","title":"GenLSP.Test.request/2","type":"function"},{"doc":"Starts a new server. Usage import GenLSP.Test server = server ( MyLSP , some_arg : some_arg )","ref":"GenLSP.Test.html#server/2","title":"GenLSP.Test.server/2","type":"function"},{"doc":"Shuts down an LSP client.","ref":"GenLSP.Test.html#shutdown_client!/1","title":"GenLSP.Test.shutdown_client!/1","type":"function"},{"doc":"Shuts down an LSP server.","ref":"GenLSP.Test.html#shutdown_server!/1","title":"GenLSP.Test.shutdown_server!/1","type":"function"},{"doc":"The test client data structure.","ref":"GenLSP.Test.html#t:client/0","title":"GenLSP.Test.client/0","type":"opaque"},{"doc":"The test server data structure.","ref":"GenLSP.Test.html#t:server/0","title":"GenLSP.Test.server/0","type":"opaque"},{"doc":"A set of predefined code action kinds","ref":"GenLSP.Enumerations.CodeActionKind.html","title":"GenLSP.Enumerations.CodeActionKind","type":"module"},{"doc":"Empty kind.","ref":"GenLSP.Enumerations.CodeActionKind.html#empty/0","title":"GenLSP.Enumerations.CodeActionKind.empty/0","type":"function"},{"doc":"Base kind for quickfix actions: 'quickfix'","ref":"GenLSP.Enumerations.CodeActionKind.html#quick_fix/0","title":"GenLSP.Enumerations.CodeActionKind.quick_fix/0","type":"function"},{"doc":"Base kind for refactoring actions: 'refactor'","ref":"GenLSP.Enumerations.CodeActionKind.html#refactor/0","title":"GenLSP.Enumerations.CodeActionKind.refactor/0","type":"function"},{"doc":"Base kind for refactoring extraction actions: 'refactor.extract' Example extract actions: Extract method Extract function Extract variable Extract interface from class ...","ref":"GenLSP.Enumerations.CodeActionKind.html#refactor_extract/0","title":"GenLSP.Enumerations.CodeActionKind.refactor_extract/0","type":"function"},{"doc":"Base kind for refactoring inline actions: 'refactor.inline' Example inline actions: Inline function Inline variable Inline constant ...","ref":"GenLSP.Enumerations.CodeActionKind.html#refactor_inline/0","title":"GenLSP.Enumerations.CodeActionKind.refactor_inline/0","type":"function"},{"doc":"Base kind for refactoring rewrite actions: 'refactor.rewrite' Example rewrite actions: Convert JavaScript function to class Add or remove parameter Encapsulate field Make method static Move method to base class ...","ref":"GenLSP.Enumerations.CodeActionKind.html#refactor_rewrite/0","title":"GenLSP.Enumerations.CodeActionKind.refactor_rewrite/0","type":"function"},{"doc":"Base kind for source actions: source Source code actions apply to the entire file.","ref":"GenLSP.Enumerations.CodeActionKind.html#source/0","title":"GenLSP.Enumerations.CodeActionKind.source/0","type":"function"},{"doc":"Base kind for auto-fix source actions: source.fixAll . Fix all actions automatically fix errors that have a clear fix that do not require user input. They should not suppress errors or perform unsafe fixes such as generating new types or classes. @since 3.15.0","ref":"GenLSP.Enumerations.CodeActionKind.html#source_fix_all/0","title":"GenLSP.Enumerations.CodeActionKind.source_fix_all/0","type":"function"},{"doc":"Base kind for an organize imports source action: source.organizeImports","ref":"GenLSP.Enumerations.CodeActionKind.html#source_organize_imports/0","title":"GenLSP.Enumerations.CodeActionKind.source_organize_imports/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.CodeActionKind.html#t:t/0","title":"GenLSP.Enumerations.CodeActionKind.t/0","type":"type"},{"doc":"The reason why code actions were requested. @since 3.17.0","ref":"GenLSP.Enumerations.CodeActionTriggerKind.html","title":"GenLSP.Enumerations.CodeActionTriggerKind","type":"module"},{"doc":"Code actions were requested automatically. This typically happens when current selection in a file changes, but can also be triggered when file content changes.","ref":"GenLSP.Enumerations.CodeActionTriggerKind.html#automatic/0","title":"GenLSP.Enumerations.CodeActionTriggerKind.automatic/0","type":"function"},{"doc":"Code actions were explicitly requested by the user or by an extension.","ref":"GenLSP.Enumerations.CodeActionTriggerKind.html#invoked/0","title":"GenLSP.Enumerations.CodeActionTriggerKind.invoked/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.CodeActionTriggerKind.html#t:t/0","title":"GenLSP.Enumerations.CodeActionTriggerKind.t/0","type":"type"},{"doc":"The kind of a completion entry.","ref":"GenLSP.Enumerations.CompletionItemKind.html","title":"GenLSP.Enumerations.CompletionItemKind","type":"module"},{"doc":"","ref":"GenLSP.Enumerations.CompletionItemKind.html#class/0","title":"GenLSP.Enumerations.CompletionItemKind.class/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.CompletionItemKind.html#color/0","title":"GenLSP.Enumerations.CompletionItemKind.color/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.CompletionItemKind.html#constant/0","title":"GenLSP.Enumerations.CompletionItemKind.constant/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.CompletionItemKind.html#constructor/0","title":"GenLSP.Enumerations.CompletionItemKind.constructor/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.CompletionItemKind.html#enum/0","title":"GenLSP.Enumerations.CompletionItemKind.enum/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.CompletionItemKind.html#enum_member/0","title":"GenLSP.Enumerations.CompletionItemKind.enum_member/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.CompletionItemKind.html#event/0","title":"GenLSP.Enumerations.CompletionItemKind.event/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.CompletionItemKind.html#field/0","title":"GenLSP.Enumerations.CompletionItemKind.field/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.CompletionItemKind.html#file/0","title":"GenLSP.Enumerations.CompletionItemKind.file/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.CompletionItemKind.html#folder/0","title":"GenLSP.Enumerations.CompletionItemKind.folder/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.CompletionItemKind.html#function/0","title":"GenLSP.Enumerations.CompletionItemKind.function/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.CompletionItemKind.html#interface/0","title":"GenLSP.Enumerations.CompletionItemKind.interface/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.CompletionItemKind.html#keyword/0","title":"GenLSP.Enumerations.CompletionItemKind.keyword/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.CompletionItemKind.html#method/0","title":"GenLSP.Enumerations.CompletionItemKind.method/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.CompletionItemKind.html#module/0","title":"GenLSP.Enumerations.CompletionItemKind.module/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.CompletionItemKind.html#operator/0","title":"GenLSP.Enumerations.CompletionItemKind.operator/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.CompletionItemKind.html#property/0","title":"GenLSP.Enumerations.CompletionItemKind.property/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.CompletionItemKind.html#reference/0","title":"GenLSP.Enumerations.CompletionItemKind.reference/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.CompletionItemKind.html#snippet/0","title":"GenLSP.Enumerations.CompletionItemKind.snippet/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.CompletionItemKind.html#struct/0","title":"GenLSP.Enumerations.CompletionItemKind.struct/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.CompletionItemKind.html#text/0","title":"GenLSP.Enumerations.CompletionItemKind.text/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.CompletionItemKind.html#type_parameter/0","title":"GenLSP.Enumerations.CompletionItemKind.type_parameter/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.CompletionItemKind.html#unit/0","title":"GenLSP.Enumerations.CompletionItemKind.unit/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.CompletionItemKind.html#value/0","title":"GenLSP.Enumerations.CompletionItemKind.value/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.CompletionItemKind.html#variable/0","title":"GenLSP.Enumerations.CompletionItemKind.variable/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.CompletionItemKind.html#t:t/0","title":"GenLSP.Enumerations.CompletionItemKind.t/0","type":"type"},{"doc":"Completion item tags are extra annotations that tweak the rendering of a completion item. @since 3.15.0","ref":"GenLSP.Enumerations.CompletionItemTag.html","title":"GenLSP.Enumerations.CompletionItemTag","type":"module"},{"doc":"Render a completion as obsolete, usually using a strike-out.","ref":"GenLSP.Enumerations.CompletionItemTag.html#deprecated/0","title":"GenLSP.Enumerations.CompletionItemTag.deprecated/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.CompletionItemTag.html#t:t/0","title":"GenLSP.Enumerations.CompletionItemTag.t/0","type":"type"},{"doc":"How a completion was triggered","ref":"GenLSP.Enumerations.CompletionTriggerKind.html","title":"GenLSP.Enumerations.CompletionTriggerKind","type":"module"},{"doc":"Completion was triggered by typing an identifier (24x7 code complete), manual invocation (e.g Ctrl+Space) or via API.","ref":"GenLSP.Enumerations.CompletionTriggerKind.html#invoked/0","title":"GenLSP.Enumerations.CompletionTriggerKind.invoked/0","type":"function"},{"doc":"Completion was triggered by a trigger character specified by the triggerCharacters properties of the CompletionRegistrationOptions .","ref":"GenLSP.Enumerations.CompletionTriggerKind.html#trigger_character/0","title":"GenLSP.Enumerations.CompletionTriggerKind.trigger_character/0","type":"function"},{"doc":"Completion was re-triggered as current completion list is incomplete","ref":"GenLSP.Enumerations.CompletionTriggerKind.html#trigger_for_incomplete_completions/0","title":"GenLSP.Enumerations.CompletionTriggerKind.trigger_for_incomplete_completions/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.CompletionTriggerKind.html#t:t/0","title":"GenLSP.Enumerations.CompletionTriggerKind.t/0","type":"type"},{"doc":"The diagnostic's severity.","ref":"GenLSP.Enumerations.DiagnosticSeverity.html","title":"GenLSP.Enumerations.DiagnosticSeverity","type":"module"},{"doc":"Reports an error.","ref":"GenLSP.Enumerations.DiagnosticSeverity.html#error/0","title":"GenLSP.Enumerations.DiagnosticSeverity.error/0","type":"function"},{"doc":"Reports a hint.","ref":"GenLSP.Enumerations.DiagnosticSeverity.html#hint/0","title":"GenLSP.Enumerations.DiagnosticSeverity.hint/0","type":"function"},{"doc":"Reports an information.","ref":"GenLSP.Enumerations.DiagnosticSeverity.html#information/0","title":"GenLSP.Enumerations.DiagnosticSeverity.information/0","type":"function"},{"doc":"Reports a warning.","ref":"GenLSP.Enumerations.DiagnosticSeverity.html#warning/0","title":"GenLSP.Enumerations.DiagnosticSeverity.warning/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.DiagnosticSeverity.html#t:t/0","title":"GenLSP.Enumerations.DiagnosticSeverity.t/0","type":"type"},{"doc":"The diagnostic tags. @since 3.15.0","ref":"GenLSP.Enumerations.DiagnosticTag.html","title":"GenLSP.Enumerations.DiagnosticTag","type":"module"},{"doc":"Deprecated or obsolete code. Clients are allowed to rendered diagnostics with this tag strike through.","ref":"GenLSP.Enumerations.DiagnosticTag.html#deprecated/0","title":"GenLSP.Enumerations.DiagnosticTag.deprecated/0","type":"function"},{"doc":"Unused or unnecessary code. Clients are allowed to render diagnostics with this tag faded out instead of having an error squiggle.","ref":"GenLSP.Enumerations.DiagnosticTag.html#unnecessary/0","title":"GenLSP.Enumerations.DiagnosticTag.unnecessary/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.DiagnosticTag.html#t:t/0","title":"GenLSP.Enumerations.DiagnosticTag.t/0","type":"type"},{"doc":"The document diagnostic report kinds. @since 3.17.0","ref":"GenLSP.Enumerations.DocumentDiagnosticReportKind.html","title":"GenLSP.Enumerations.DocumentDiagnosticReportKind","type":"module"},{"doc":"A diagnostic report with a full set of problems.","ref":"GenLSP.Enumerations.DocumentDiagnosticReportKind.html#full/0","title":"GenLSP.Enumerations.DocumentDiagnosticReportKind.full/0","type":"function"},{"doc":"A report indicating that the last returned report is still accurate.","ref":"GenLSP.Enumerations.DocumentDiagnosticReportKind.html#unchanged/0","title":"GenLSP.Enumerations.DocumentDiagnosticReportKind.unchanged/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.DocumentDiagnosticReportKind.html#t:t/0","title":"GenLSP.Enumerations.DocumentDiagnosticReportKind.t/0","type":"type"},{"doc":"A document highlight kind.","ref":"GenLSP.Enumerations.DocumentHighlightKind.html","title":"GenLSP.Enumerations.DocumentHighlightKind","type":"module"},{"doc":"Read-access of a symbol, like reading a variable.","ref":"GenLSP.Enumerations.DocumentHighlightKind.html#read/0","title":"GenLSP.Enumerations.DocumentHighlightKind.read/0","type":"function"},{"doc":"A textual occurrence.","ref":"GenLSP.Enumerations.DocumentHighlightKind.html#text/0","title":"GenLSP.Enumerations.DocumentHighlightKind.text/0","type":"function"},{"doc":"Write-access of a symbol, like writing to a variable.","ref":"GenLSP.Enumerations.DocumentHighlightKind.html#write/0","title":"GenLSP.Enumerations.DocumentHighlightKind.write/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.DocumentHighlightKind.html#t:t/0","title":"GenLSP.Enumerations.DocumentHighlightKind.t/0","type":"type"},{"doc":"Predefined error codes.","ref":"GenLSP.Enumerations.ErrorCodes.html","title":"GenLSP.Enumerations.ErrorCodes","type":"module"},{"doc":"","ref":"GenLSP.Enumerations.ErrorCodes.html#internal_error/0","title":"GenLSP.Enumerations.ErrorCodes.internal_error/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.ErrorCodes.html#invalid_params/0","title":"GenLSP.Enumerations.ErrorCodes.invalid_params/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.ErrorCodes.html#invalid_request/0","title":"GenLSP.Enumerations.ErrorCodes.invalid_request/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.ErrorCodes.html#method_not_found/0","title":"GenLSP.Enumerations.ErrorCodes.method_not_found/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.ErrorCodes.html#parse_error/0","title":"GenLSP.Enumerations.ErrorCodes.parse_error/0","type":"function"},{"doc":"Error code indicating that a server received a notification or request before the server has received the initialize request.","ref":"GenLSP.Enumerations.ErrorCodes.html#server_not_initialized/0","title":"GenLSP.Enumerations.ErrorCodes.server_not_initialized/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.ErrorCodes.html#unknown_error_code/0","title":"GenLSP.Enumerations.ErrorCodes.unknown_error_code/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.ErrorCodes.html#t:t/0","title":"GenLSP.Enumerations.ErrorCodes.t/0","type":"type"},{"doc":"","ref":"GenLSP.Enumerations.FailureHandlingKind.html","title":"GenLSP.Enumerations.FailureHandlingKind","type":"module"},{"doc":"Applying the workspace change is simply aborted if one of the changes provided fails. All operations executed before the failing operation stay executed.","ref":"GenLSP.Enumerations.FailureHandlingKind.html#abort/0","title":"GenLSP.Enumerations.FailureHandlingKind.abort/0","type":"function"},{"doc":"If the workspace edit contains only textual file changes they are executed transactional. If resource changes (create, rename or delete file) are part of the change the failure handling strategy is abort.","ref":"GenLSP.Enumerations.FailureHandlingKind.html#text_only_transactional/0","title":"GenLSP.Enumerations.FailureHandlingKind.text_only_transactional/0","type":"function"},{"doc":"All operations are executed transactional. That means they either all succeed or no changes at all are applied to the workspace.","ref":"GenLSP.Enumerations.FailureHandlingKind.html#transactional/0","title":"GenLSP.Enumerations.FailureHandlingKind.transactional/0","type":"function"},{"doc":"The client tries to undo the operations already executed. But there is no guarantee that this is succeeding.","ref":"GenLSP.Enumerations.FailureHandlingKind.html#undo/0","title":"GenLSP.Enumerations.FailureHandlingKind.undo/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.FailureHandlingKind.html#t:t/0","title":"GenLSP.Enumerations.FailureHandlingKind.t/0","type":"type"},{"doc":"The file event type","ref":"GenLSP.Enumerations.FileChangeType.html","title":"GenLSP.Enumerations.FileChangeType","type":"module"},{"doc":"The file got changed.","ref":"GenLSP.Enumerations.FileChangeType.html#changed/0","title":"GenLSP.Enumerations.FileChangeType.changed/0","type":"function"},{"doc":"The file got created.","ref":"GenLSP.Enumerations.FileChangeType.html#created/0","title":"GenLSP.Enumerations.FileChangeType.created/0","type":"function"},{"doc":"The file got deleted.","ref":"GenLSP.Enumerations.FileChangeType.html#deleted/0","title":"GenLSP.Enumerations.FileChangeType.deleted/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.FileChangeType.html#t:t/0","title":"GenLSP.Enumerations.FileChangeType.t/0","type":"type"},{"doc":"A pattern kind describing if a glob pattern matches a file a folder or both. @since 3.16.0","ref":"GenLSP.Enumerations.FileOperationPatternKind.html","title":"GenLSP.Enumerations.FileOperationPatternKind","type":"module"},{"doc":"The pattern matches a file only.","ref":"GenLSP.Enumerations.FileOperationPatternKind.html#file/0","title":"GenLSP.Enumerations.FileOperationPatternKind.file/0","type":"function"},{"doc":"The pattern matches a folder only.","ref":"GenLSP.Enumerations.FileOperationPatternKind.html#folder/0","title":"GenLSP.Enumerations.FileOperationPatternKind.folder/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.FileOperationPatternKind.html#t:t/0","title":"GenLSP.Enumerations.FileOperationPatternKind.t/0","type":"type"},{"doc":"A set of predefined range kinds.","ref":"GenLSP.Enumerations.FoldingRangeKind.html","title":"GenLSP.Enumerations.FoldingRangeKind","type":"module"},{"doc":"Folding range for a comment","ref":"GenLSP.Enumerations.FoldingRangeKind.html#comment/0","title":"GenLSP.Enumerations.FoldingRangeKind.comment/0","type":"function"},{"doc":"Folding range for an import or include","ref":"GenLSP.Enumerations.FoldingRangeKind.html#imports/0","title":"GenLSP.Enumerations.FoldingRangeKind.imports/0","type":"function"},{"doc":"Folding range for a region (e.g. #region )","ref":"GenLSP.Enumerations.FoldingRangeKind.html#region/0","title":"GenLSP.Enumerations.FoldingRangeKind.region/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.FoldingRangeKind.html#t:t/0","title":"GenLSP.Enumerations.FoldingRangeKind.t/0","type":"type"},{"doc":"Inlay hint kinds. @since 3.17.0","ref":"GenLSP.Enumerations.InlayHintKind.html","title":"GenLSP.Enumerations.InlayHintKind","type":"module"},{"doc":"An inlay hint that is for a parameter.","ref":"GenLSP.Enumerations.InlayHintKind.html#parameter/0","title":"GenLSP.Enumerations.InlayHintKind.parameter/0","type":"function"},{"doc":"An inlay hint that for a type annotation.","ref":"GenLSP.Enumerations.InlayHintKind.html#type/0","title":"GenLSP.Enumerations.InlayHintKind.type/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.InlayHintKind.html#t:t/0","title":"GenLSP.Enumerations.InlayHintKind.t/0","type":"type"},{"doc":"Defines whether the insert text in a completion item should be interpreted as plain text or a snippet.","ref":"GenLSP.Enumerations.InsertTextFormat.html","title":"GenLSP.Enumerations.InsertTextFormat","type":"module"},{"doc":"The primary text to be inserted is treated as a plain string.","ref":"GenLSP.Enumerations.InsertTextFormat.html#plain_text/0","title":"GenLSP.Enumerations.InsertTextFormat.plain_text/0","type":"function"},{"doc":"The primary text to be inserted is treated as a snippet. A snippet can define tab stops and placeholders with $1 , $2 and ${3:foo} . $0 defines the final tab stop, it defaults to the end of the snippet. Placeholders with equal identifiers are linked, that is typing in one will update others too. See also: https://microsoft.github.io/language-server-protocol/specifications/specification-current/#snippet_syntax","ref":"GenLSP.Enumerations.InsertTextFormat.html#snippet/0","title":"GenLSP.Enumerations.InsertTextFormat.snippet/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.InsertTextFormat.html#t:t/0","title":"GenLSP.Enumerations.InsertTextFormat.t/0","type":"type"},{"doc":"How whitespace and indentation is handled during completion item insertion. @since 3.16.0","ref":"GenLSP.Enumerations.InsertTextMode.html","title":"GenLSP.Enumerations.InsertTextMode","type":"module"},{"doc":"The editor adjusts leading whitespace of new lines so that they match the indentation up to the cursor of the line for which the item is accepted. Consider a line like this: &lt;2tabs&gt;&lt;cursor&gt;&lt;3tabs&gt;foo. Accepting a multi line completion item is indented using 2 tabs and all following lines inserted will be indented using 2 tabs as well.","ref":"GenLSP.Enumerations.InsertTextMode.html#adjust_indentation/0","title":"GenLSP.Enumerations.InsertTextMode.adjust_indentation/0","type":"function"},{"doc":"The insertion or replace strings is taken as it is. If the value is multi line the lines below the cursor will be inserted using the indentation defined in the string value. The client will not apply any kind of adjustments to the string.","ref":"GenLSP.Enumerations.InsertTextMode.html#as_is/0","title":"GenLSP.Enumerations.InsertTextMode.as_is/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.InsertTextMode.html#t:t/0","title":"GenLSP.Enumerations.InsertTextMode.t/0","type":"type"},{"doc":"","ref":"GenLSP.Enumerations.LSPErrorCodes.html","title":"GenLSP.Enumerations.LSPErrorCodes","type":"module"},{"doc":"The server detected that the content of a document got modified outside normal conditions. A server should NOT send this error code if it detects a content change in it unprocessed messages. The result even computed on an older state might still be useful for the client. If a client decides that a result is not of any use anymore the client should cancel the request.","ref":"GenLSP.Enumerations.LSPErrorCodes.html#content_modified/0","title":"GenLSP.Enumerations.LSPErrorCodes.content_modified/0","type":"function"},{"doc":"The client has canceled a request and a server as detected the cancel.","ref":"GenLSP.Enumerations.LSPErrorCodes.html#request_cancelled/0","title":"GenLSP.Enumerations.LSPErrorCodes.request_cancelled/0","type":"function"},{"doc":"A request failed but it was syntactically correct, e.g the method name was known and the parameters were valid. The error message should contain human readable information about why the request failed. @since 3.17.0","ref":"GenLSP.Enumerations.LSPErrorCodes.html#request_failed/0","title":"GenLSP.Enumerations.LSPErrorCodes.request_failed/0","type":"function"},{"doc":"The server cancelled the request. This error code should only be used for requests that explicitly support being server cancellable. @since 3.17.0","ref":"GenLSP.Enumerations.LSPErrorCodes.html#server_cancelled/0","title":"GenLSP.Enumerations.LSPErrorCodes.server_cancelled/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.LSPErrorCodes.html#t:t/0","title":"GenLSP.Enumerations.LSPErrorCodes.t/0","type":"type"},{"doc":"Describes the content type that a client supports in various result literals like Hover , ParameterInfo or CompletionItem . Please note that MarkupKinds must not start with a $ . This kinds are reserved for internal usage.","ref":"GenLSP.Enumerations.MarkupKind.html","title":"GenLSP.Enumerations.MarkupKind","type":"module"},{"doc":"Markdown is supported as a content format","ref":"GenLSP.Enumerations.MarkupKind.html#markdown/0","title":"GenLSP.Enumerations.MarkupKind.markdown/0","type":"function"},{"doc":"Plain text is supported as a content format","ref":"GenLSP.Enumerations.MarkupKind.html#plain_text/0","title":"GenLSP.Enumerations.MarkupKind.plain_text/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.MarkupKind.html#t:t/0","title":"GenLSP.Enumerations.MarkupKind.t/0","type":"type"},{"doc":"The message type","ref":"GenLSP.Enumerations.MessageType.html","title":"GenLSP.Enumerations.MessageType","type":"module"},{"doc":"An error message.","ref":"GenLSP.Enumerations.MessageType.html#error/0","title":"GenLSP.Enumerations.MessageType.error/0","type":"function"},{"doc":"An information message.","ref":"GenLSP.Enumerations.MessageType.html#info/0","title":"GenLSP.Enumerations.MessageType.info/0","type":"function"},{"doc":"A log message.","ref":"GenLSP.Enumerations.MessageType.html#log/0","title":"GenLSP.Enumerations.MessageType.log/0","type":"function"},{"doc":"A warning message.","ref":"GenLSP.Enumerations.MessageType.html#warning/0","title":"GenLSP.Enumerations.MessageType.warning/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.MessageType.html#t:t/0","title":"GenLSP.Enumerations.MessageType.t/0","type":"type"},{"doc":"The moniker kind. @since 3.16.0","ref":"GenLSP.Enumerations.MonikerKind.html","title":"GenLSP.Enumerations.MonikerKind","type":"module"},{"doc":"The moniker represents a symbol that is exported from a project","ref":"GenLSP.Enumerations.MonikerKind.html#export/0","title":"GenLSP.Enumerations.MonikerKind.export/0","type":"function"},{"doc":"The moniker represent a symbol that is imported into a project","ref":"GenLSP.Enumerations.MonikerKind.html#import/0","title":"GenLSP.Enumerations.MonikerKind.import/0","type":"function"},{"doc":"The moniker represents a symbol that is local to a project (e.g. a local variable of a function, a class not visible outside the project, ...)","ref":"GenLSP.Enumerations.MonikerKind.html#local/0","title":"GenLSP.Enumerations.MonikerKind.local/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.MonikerKind.html#t:t/0","title":"GenLSP.Enumerations.MonikerKind.t/0","type":"type"},{"doc":"A notebook cell kind. @since 3.17.0","ref":"GenLSP.Enumerations.NotebookCellKind.html","title":"GenLSP.Enumerations.NotebookCellKind","type":"module"},{"doc":"A code-cell is source code.","ref":"GenLSP.Enumerations.NotebookCellKind.html#code/0","title":"GenLSP.Enumerations.NotebookCellKind.code/0","type":"function"},{"doc":"A markup-cell is formatted source that is used for display.","ref":"GenLSP.Enumerations.NotebookCellKind.html#markup/0","title":"GenLSP.Enumerations.NotebookCellKind.markup/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.NotebookCellKind.html#t:t/0","title":"GenLSP.Enumerations.NotebookCellKind.t/0","type":"type"},{"doc":"A set of predefined position encoding kinds. @since 3.17.0","ref":"GenLSP.Enumerations.PositionEncodingKind.html","title":"GenLSP.Enumerations.PositionEncodingKind","type":"module"},{"doc":"Character offsets count UTF-8 code units.","ref":"GenLSP.Enumerations.PositionEncodingKind.html#utf8/0","title":"GenLSP.Enumerations.PositionEncodingKind.utf8/0","type":"function"},{"doc":"Character offsets count UTF-16 code units. This is the default and must always be supported by servers","ref":"GenLSP.Enumerations.PositionEncodingKind.html#utf16/0","title":"GenLSP.Enumerations.PositionEncodingKind.utf16/0","type":"function"},{"doc":"Character offsets count UTF-32 code units. Implementation note: these are the same as Unicode code points, so this PositionEncodingKind may also be used for an encoding-agnostic representation of character offsets.","ref":"GenLSP.Enumerations.PositionEncodingKind.html#utf32/0","title":"GenLSP.Enumerations.PositionEncodingKind.utf32/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.PositionEncodingKind.html#t:t/0","title":"GenLSP.Enumerations.PositionEncodingKind.t/0","type":"type"},{"doc":"","ref":"GenLSP.Enumerations.PrepareSupportDefaultBehavior.html","title":"GenLSP.Enumerations.PrepareSupportDefaultBehavior","type":"module"},{"doc":"The client's default behavior is to select the identifier according the to language's syntax rule.","ref":"GenLSP.Enumerations.PrepareSupportDefaultBehavior.html#identifier/0","title":"GenLSP.Enumerations.PrepareSupportDefaultBehavior.identifier/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.PrepareSupportDefaultBehavior.html#t:t/0","title":"GenLSP.Enumerations.PrepareSupportDefaultBehavior.t/0","type":"type"},{"doc":"","ref":"GenLSP.Enumerations.ResourceOperationKind.html","title":"GenLSP.Enumerations.ResourceOperationKind","type":"module"},{"doc":"Supports creating new files and folders.","ref":"GenLSP.Enumerations.ResourceOperationKind.html#create/0","title":"GenLSP.Enumerations.ResourceOperationKind.create/0","type":"function"},{"doc":"Supports deleting existing files and folders.","ref":"GenLSP.Enumerations.ResourceOperationKind.html#delete/0","title":"GenLSP.Enumerations.ResourceOperationKind.delete/0","type":"function"},{"doc":"Supports renaming existing files and folders.","ref":"GenLSP.Enumerations.ResourceOperationKind.html#rename/0","title":"GenLSP.Enumerations.ResourceOperationKind.rename/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.ResourceOperationKind.html#t:t/0","title":"GenLSP.Enumerations.ResourceOperationKind.t/0","type":"type"},{"doc":"A set of predefined token modifiers. This set is not fixed an clients can specify additional token types via the corresponding client capabilities. @since 3.16.0","ref":"GenLSP.Enumerations.SemanticTokenModifiers.html","title":"GenLSP.Enumerations.SemanticTokenModifiers","type":"module"},{"doc":"","ref":"GenLSP.Enumerations.SemanticTokenModifiers.html#abstract/0","title":"GenLSP.Enumerations.SemanticTokenModifiers.abstract/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.SemanticTokenModifiers.html#async/0","title":"GenLSP.Enumerations.SemanticTokenModifiers.async/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.SemanticTokenModifiers.html#declaration/0","title":"GenLSP.Enumerations.SemanticTokenModifiers.declaration/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.SemanticTokenModifiers.html#default_library/0","title":"GenLSP.Enumerations.SemanticTokenModifiers.default_library/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.SemanticTokenModifiers.html#definition/0","title":"GenLSP.Enumerations.SemanticTokenModifiers.definition/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.SemanticTokenModifiers.html#deprecated/0","title":"GenLSP.Enumerations.SemanticTokenModifiers.deprecated/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.SemanticTokenModifiers.html#documentation/0","title":"GenLSP.Enumerations.SemanticTokenModifiers.documentation/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.SemanticTokenModifiers.html#modification/0","title":"GenLSP.Enumerations.SemanticTokenModifiers.modification/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.SemanticTokenModifiers.html#readonly/0","title":"GenLSP.Enumerations.SemanticTokenModifiers.readonly/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.SemanticTokenModifiers.html#static/0","title":"GenLSP.Enumerations.SemanticTokenModifiers.static/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.SemanticTokenModifiers.html#t:t/0","title":"GenLSP.Enumerations.SemanticTokenModifiers.t/0","type":"type"},{"doc":"A set of predefined token types. This set is not fixed an clients can specify additional token types via the corresponding client capabilities. @since 3.16.0","ref":"GenLSP.Enumerations.SemanticTokenTypes.html","title":"GenLSP.Enumerations.SemanticTokenTypes","type":"module"},{"doc":"","ref":"GenLSP.Enumerations.SemanticTokenTypes.html#class/0","title":"GenLSP.Enumerations.SemanticTokenTypes.class/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.SemanticTokenTypes.html#comment/0","title":"GenLSP.Enumerations.SemanticTokenTypes.comment/0","type":"function"},{"doc":"@since 3.17.0","ref":"GenLSP.Enumerations.SemanticTokenTypes.html#decorator/0","title":"GenLSP.Enumerations.SemanticTokenTypes.decorator/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.SemanticTokenTypes.html#enum/0","title":"GenLSP.Enumerations.SemanticTokenTypes.enum/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.SemanticTokenTypes.html#enum_member/0","title":"GenLSP.Enumerations.SemanticTokenTypes.enum_member/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.SemanticTokenTypes.html#event/0","title":"GenLSP.Enumerations.SemanticTokenTypes.event/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.SemanticTokenTypes.html#function/0","title":"GenLSP.Enumerations.SemanticTokenTypes.function/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.SemanticTokenTypes.html#interface/0","title":"GenLSP.Enumerations.SemanticTokenTypes.interface/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.SemanticTokenTypes.html#keyword/0","title":"GenLSP.Enumerations.SemanticTokenTypes.keyword/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.SemanticTokenTypes.html#macro/0","title":"GenLSP.Enumerations.SemanticTokenTypes.macro/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.SemanticTokenTypes.html#method/0","title":"GenLSP.Enumerations.SemanticTokenTypes.method/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.SemanticTokenTypes.html#modifier/0","title":"GenLSP.Enumerations.SemanticTokenTypes.modifier/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.SemanticTokenTypes.html#namespace/0","title":"GenLSP.Enumerations.SemanticTokenTypes.namespace/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.SemanticTokenTypes.html#number/0","title":"GenLSP.Enumerations.SemanticTokenTypes.number/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.SemanticTokenTypes.html#operator/0","title":"GenLSP.Enumerations.SemanticTokenTypes.operator/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.SemanticTokenTypes.html#parameter/0","title":"GenLSP.Enumerations.SemanticTokenTypes.parameter/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.SemanticTokenTypes.html#property/0","title":"GenLSP.Enumerations.SemanticTokenTypes.property/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.SemanticTokenTypes.html#regexp/0","title":"GenLSP.Enumerations.SemanticTokenTypes.regexp/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.SemanticTokenTypes.html#string/0","title":"GenLSP.Enumerations.SemanticTokenTypes.string/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.SemanticTokenTypes.html#struct/0","title":"GenLSP.Enumerations.SemanticTokenTypes.struct/0","type":"function"},{"doc":"Represents a generic type. Acts as a fallback for types which can't be mapped to a specific type like class or enum.","ref":"GenLSP.Enumerations.SemanticTokenTypes.html#type/0","title":"GenLSP.Enumerations.SemanticTokenTypes.type/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.SemanticTokenTypes.html#type_parameter/0","title":"GenLSP.Enumerations.SemanticTokenTypes.type_parameter/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.SemanticTokenTypes.html#variable/0","title":"GenLSP.Enumerations.SemanticTokenTypes.variable/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.SemanticTokenTypes.html#t:t/0","title":"GenLSP.Enumerations.SemanticTokenTypes.t/0","type":"type"},{"doc":"How a signature help was triggered. @since 3.15.0","ref":"GenLSP.Enumerations.SignatureHelpTriggerKind.html","title":"GenLSP.Enumerations.SignatureHelpTriggerKind","type":"module"},{"doc":"Signature help was triggered by the cursor moving or by the document content changing.","ref":"GenLSP.Enumerations.SignatureHelpTriggerKind.html#content_change/0","title":"GenLSP.Enumerations.SignatureHelpTriggerKind.content_change/0","type":"function"},{"doc":"Signature help was invoked manually by the user or by a command.","ref":"GenLSP.Enumerations.SignatureHelpTriggerKind.html#invoked/0","title":"GenLSP.Enumerations.SignatureHelpTriggerKind.invoked/0","type":"function"},{"doc":"Signature help was triggered by a trigger character.","ref":"GenLSP.Enumerations.SignatureHelpTriggerKind.html#trigger_character/0","title":"GenLSP.Enumerations.SignatureHelpTriggerKind.trigger_character/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.SignatureHelpTriggerKind.html#t:t/0","title":"GenLSP.Enumerations.SignatureHelpTriggerKind.t/0","type":"type"},{"doc":"A symbol kind.","ref":"GenLSP.Enumerations.SymbolKind.html","title":"GenLSP.Enumerations.SymbolKind","type":"module"},{"doc":"","ref":"GenLSP.Enumerations.SymbolKind.html#array/0","title":"GenLSP.Enumerations.SymbolKind.array/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.SymbolKind.html#boolean/0","title":"GenLSP.Enumerations.SymbolKind.boolean/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.SymbolKind.html#class/0","title":"GenLSP.Enumerations.SymbolKind.class/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.SymbolKind.html#constant/0","title":"GenLSP.Enumerations.SymbolKind.constant/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.SymbolKind.html#constructor/0","title":"GenLSP.Enumerations.SymbolKind.constructor/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.SymbolKind.html#enum/0","title":"GenLSP.Enumerations.SymbolKind.enum/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.SymbolKind.html#enum_member/0","title":"GenLSP.Enumerations.SymbolKind.enum_member/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.SymbolKind.html#event/0","title":"GenLSP.Enumerations.SymbolKind.event/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.SymbolKind.html#field/0","title":"GenLSP.Enumerations.SymbolKind.field/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.SymbolKind.html#file/0","title":"GenLSP.Enumerations.SymbolKind.file/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.SymbolKind.html#function/0","title":"GenLSP.Enumerations.SymbolKind.function/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.SymbolKind.html#interface/0","title":"GenLSP.Enumerations.SymbolKind.interface/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.SymbolKind.html#key/0","title":"GenLSP.Enumerations.SymbolKind.key/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.SymbolKind.html#method/0","title":"GenLSP.Enumerations.SymbolKind.method/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.SymbolKind.html#module/0","title":"GenLSP.Enumerations.SymbolKind.module/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.SymbolKind.html#namespace/0","title":"GenLSP.Enumerations.SymbolKind.namespace/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.SymbolKind.html#null/0","title":"GenLSP.Enumerations.SymbolKind.null/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.SymbolKind.html#number/0","title":"GenLSP.Enumerations.SymbolKind.number/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.SymbolKind.html#object/0","title":"GenLSP.Enumerations.SymbolKind.object/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.SymbolKind.html#operator/0","title":"GenLSP.Enumerations.SymbolKind.operator/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.SymbolKind.html#package/0","title":"GenLSP.Enumerations.SymbolKind.package/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.SymbolKind.html#property/0","title":"GenLSP.Enumerations.SymbolKind.property/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.SymbolKind.html#string/0","title":"GenLSP.Enumerations.SymbolKind.string/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.SymbolKind.html#struct/0","title":"GenLSP.Enumerations.SymbolKind.struct/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.SymbolKind.html#type_parameter/0","title":"GenLSP.Enumerations.SymbolKind.type_parameter/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.SymbolKind.html#variable/0","title":"GenLSP.Enumerations.SymbolKind.variable/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.SymbolKind.html#t:t/0","title":"GenLSP.Enumerations.SymbolKind.t/0","type":"type"},{"doc":"Symbol tags are extra annotations that tweak the rendering of a symbol. @since 3.16","ref":"GenLSP.Enumerations.SymbolTag.html","title":"GenLSP.Enumerations.SymbolTag","type":"module"},{"doc":"Render a symbol as obsolete, usually using a strike-out.","ref":"GenLSP.Enumerations.SymbolTag.html#deprecated/0","title":"GenLSP.Enumerations.SymbolTag.deprecated/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.SymbolTag.html#t:t/0","title":"GenLSP.Enumerations.SymbolTag.t/0","type":"type"},{"doc":"Represents reasons why a text document is saved.","ref":"GenLSP.Enumerations.TextDocumentSaveReason.html","title":"GenLSP.Enumerations.TextDocumentSaveReason","type":"module"},{"doc":"Automatic after a delay.","ref":"GenLSP.Enumerations.TextDocumentSaveReason.html#after_delay/0","title":"GenLSP.Enumerations.TextDocumentSaveReason.after_delay/0","type":"function"},{"doc":"When the editor lost focus.","ref":"GenLSP.Enumerations.TextDocumentSaveReason.html#focus_out/0","title":"GenLSP.Enumerations.TextDocumentSaveReason.focus_out/0","type":"function"},{"doc":"Manually triggered, e.g. by the user pressing save, by starting debugging, or by an API call.","ref":"GenLSP.Enumerations.TextDocumentSaveReason.html#manual/0","title":"GenLSP.Enumerations.TextDocumentSaveReason.manual/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.TextDocumentSaveReason.html#t:t/0","title":"GenLSP.Enumerations.TextDocumentSaveReason.t/0","type":"type"},{"doc":"Defines how the host (editor) should sync document changes to the language server.","ref":"GenLSP.Enumerations.TextDocumentSyncKind.html","title":"GenLSP.Enumerations.TextDocumentSyncKind","type":"module"},{"doc":"Documents are synced by always sending the full content of the document.","ref":"GenLSP.Enumerations.TextDocumentSyncKind.html#full/0","title":"GenLSP.Enumerations.TextDocumentSyncKind.full/0","type":"function"},{"doc":"Documents are synced by sending the full content on open. After that only incremental updates to the document are send.","ref":"GenLSP.Enumerations.TextDocumentSyncKind.html#incremental/0","title":"GenLSP.Enumerations.TextDocumentSyncKind.incremental/0","type":"function"},{"doc":"Documents should not be synced at all.","ref":"GenLSP.Enumerations.TextDocumentSyncKind.html#none/0","title":"GenLSP.Enumerations.TextDocumentSyncKind.none/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.TextDocumentSyncKind.html#t:t/0","title":"GenLSP.Enumerations.TextDocumentSyncKind.t/0","type":"type"},{"doc":"","ref":"GenLSP.Enumerations.TokenFormat.html","title":"GenLSP.Enumerations.TokenFormat","type":"module"},{"doc":"","ref":"GenLSP.Enumerations.TokenFormat.html#relative/0","title":"GenLSP.Enumerations.TokenFormat.relative/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.TokenFormat.html#t:t/0","title":"GenLSP.Enumerations.TokenFormat.t/0","type":"type"},{"doc":"","ref":"GenLSP.Enumerations.TraceValues.html","title":"GenLSP.Enumerations.TraceValues","type":"module"},{"doc":"Trace messages only.","ref":"GenLSP.Enumerations.TraceValues.html#messages/0","title":"GenLSP.Enumerations.TraceValues.messages/0","type":"function"},{"doc":"Turn tracing off.","ref":"GenLSP.Enumerations.TraceValues.html#off/0","title":"GenLSP.Enumerations.TraceValues.off/0","type":"function"},{"doc":"Verbose message tracing.","ref":"GenLSP.Enumerations.TraceValues.html#verbose/0","title":"GenLSP.Enumerations.TraceValues.verbose/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.TraceValues.html#t:t/0","title":"GenLSP.Enumerations.TraceValues.t/0","type":"type"},{"doc":"Moniker uniqueness level to define scope of the moniker. @since 3.16.0","ref":"GenLSP.Enumerations.UniquenessLevel.html","title":"GenLSP.Enumerations.UniquenessLevel","type":"module"},{"doc":"The moniker is only unique inside a document","ref":"GenLSP.Enumerations.UniquenessLevel.html#document/0","title":"GenLSP.Enumerations.UniquenessLevel.document/0","type":"function"},{"doc":"The moniker is globally unique","ref":"GenLSP.Enumerations.UniquenessLevel.html#global/0","title":"GenLSP.Enumerations.UniquenessLevel.global/0","type":"function"},{"doc":"The moniker is unique inside the group to which a project belongs","ref":"GenLSP.Enumerations.UniquenessLevel.html#group/0","title":"GenLSP.Enumerations.UniquenessLevel.group/0","type":"function"},{"doc":"The moniker is unique inside a project for which a dump got created","ref":"GenLSP.Enumerations.UniquenessLevel.html#project/0","title":"GenLSP.Enumerations.UniquenessLevel.project/0","type":"function"},{"doc":"The moniker is unique inside the moniker scheme.","ref":"GenLSP.Enumerations.UniquenessLevel.html#scheme/0","title":"GenLSP.Enumerations.UniquenessLevel.scheme/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.UniquenessLevel.html#t:t/0","title":"GenLSP.Enumerations.UniquenessLevel.t/0","type":"type"},{"doc":"","ref":"GenLSP.Enumerations.WatchKind.html","title":"GenLSP.Enumerations.WatchKind","type":"module"},{"doc":"Interested in change events","ref":"GenLSP.Enumerations.WatchKind.html#change/0","title":"GenLSP.Enumerations.WatchKind.change/0","type":"function"},{"doc":"Interested in create events.","ref":"GenLSP.Enumerations.WatchKind.html#create/0","title":"GenLSP.Enumerations.WatchKind.create/0","type":"function"},{"doc":"Interested in delete events","ref":"GenLSP.Enumerations.WatchKind.html#delete/0","title":"GenLSP.Enumerations.WatchKind.delete/0","type":"function"},{"doc":"","ref":"GenLSP.Enumerations.WatchKind.html#t:t/0","title":"GenLSP.Enumerations.WatchKind.t/0","type":"type"},{"doc":"","ref":"GenLSP.Notifications.DollarCancelRequest.html","title":"GenLSP.Notifications.DollarCancelRequest","type":"module"},{"doc":"","ref":"GenLSP.Notifications.DollarCancelRequest.html#t:t/0","title":"GenLSP.Notifications.DollarCancelRequest.t/0","type":"type"},{"doc":"","ref":"GenLSP.Notifications.DollarLogTrace.html","title":"GenLSP.Notifications.DollarLogTrace","type":"module"},{"doc":"","ref":"GenLSP.Notifications.DollarLogTrace.html#t:t/0","title":"GenLSP.Notifications.DollarLogTrace.t/0","type":"type"},{"doc":"","ref":"GenLSP.Notifications.DollarProgress.html","title":"GenLSP.Notifications.DollarProgress","type":"module"},{"doc":"","ref":"GenLSP.Notifications.DollarProgress.html#t:t/0","title":"GenLSP.Notifications.DollarProgress.t/0","type":"type"},{"doc":"","ref":"GenLSP.Notifications.DollarSetTrace.html","title":"GenLSP.Notifications.DollarSetTrace","type":"module"},{"doc":"","ref":"GenLSP.Notifications.DollarSetTrace.html#t:t/0","title":"GenLSP.Notifications.DollarSetTrace.t/0","type":"type"},{"doc":"The exit event is sent from the client to the server to ask the server to exit its process. Message Direction: clientToServer","ref":"GenLSP.Notifications.Exit.html","title":"GenLSP.Notifications.Exit","type":"module"},{"doc":"","ref":"GenLSP.Notifications.Exit.html#t:t/0","title":"GenLSP.Notifications.Exit.t/0","type":"type"},{"doc":"The initialized notification is sent from the client to the server after the client is fully initialized and the server is allowed to send requests from the server to the client. Message Direction: clientToServer","ref":"GenLSP.Notifications.Initialized.html","title":"GenLSP.Notifications.Initialized","type":"module"},{"doc":"","ref":"GenLSP.Notifications.Initialized.html#t:t/0","title":"GenLSP.Notifications.Initialized.t/0","type":"type"},{"doc":"","ref":"GenLSP.Notifications.NotebookDocumentDidChange.html","title":"GenLSP.Notifications.NotebookDocumentDidChange","type":"module"},{"doc":"","ref":"GenLSP.Notifications.NotebookDocumentDidChange.html#t:t/0","title":"GenLSP.Notifications.NotebookDocumentDidChange.t/0","type":"type"},{"doc":"A notification sent when a notebook closes. @since 3.17.0 Message Direction: clientToServer","ref":"GenLSP.Notifications.NotebookDocumentDidClose.html","title":"GenLSP.Notifications.NotebookDocumentDidClose","type":"module"},{"doc":"","ref":"GenLSP.Notifications.NotebookDocumentDidClose.html#t:t/0","title":"GenLSP.Notifications.NotebookDocumentDidClose.t/0","type":"type"},{"doc":"A notification sent when a notebook opens. @since 3.17.0 Message Direction: clientToServer","ref":"GenLSP.Notifications.NotebookDocumentDidOpen.html","title":"GenLSP.Notifications.NotebookDocumentDidOpen","type":"module"},{"doc":"","ref":"GenLSP.Notifications.NotebookDocumentDidOpen.html#t:t/0","title":"GenLSP.Notifications.NotebookDocumentDidOpen.t/0","type":"type"},{"doc":"A notification sent when a notebook document is saved. @since 3.17.0 Message Direction: clientToServer","ref":"GenLSP.Notifications.NotebookDocumentDidSave.html","title":"GenLSP.Notifications.NotebookDocumentDidSave","type":"module"},{"doc":"","ref":"GenLSP.Notifications.NotebookDocumentDidSave.html#t:t/0","title":"GenLSP.Notifications.NotebookDocumentDidSave.t/0","type":"type"},{"doc":"The telemetry event notification is sent from the server to the client to ask the client to log telemetry data. Message Direction: serverToClient","ref":"GenLSP.Notifications.TelemetryEvent.html","title":"GenLSP.Notifications.TelemetryEvent","type":"module"},{"doc":"","ref":"GenLSP.Notifications.TelemetryEvent.html#t:t/0","title":"GenLSP.Notifications.TelemetryEvent.t/0","type":"type"},{"doc":"The document change notification is sent from the client to the server to signal changes to a text document. Message Direction: clientToServer","ref":"GenLSP.Notifications.TextDocumentDidChange.html","title":"GenLSP.Notifications.TextDocumentDidChange","type":"module"},{"doc":"","ref":"GenLSP.Notifications.TextDocumentDidChange.html#t:t/0","title":"GenLSP.Notifications.TextDocumentDidChange.t/0","type":"type"},{"doc":"The document close notification is sent from the client to the server when the document got closed in the client. The document's truth now exists where the document's uri points to (e.g. if the document's uri is a file uri the truth now exists on disk). As with the open notification the close notification is about managing the document's content. Receiving a close notification doesn't mean that the document was open in an editor before. A close notification requires a previous open notification to be sent. Message Direction: clientToServer","ref":"GenLSP.Notifications.TextDocumentDidClose.html","title":"GenLSP.Notifications.TextDocumentDidClose","type":"module"},{"doc":"","ref":"GenLSP.Notifications.TextDocumentDidClose.html#t:t/0","title":"GenLSP.Notifications.TextDocumentDidClose.t/0","type":"type"},{"doc":"The document open notification is sent from the client to the server to signal newly opened text documents. The document's truth is now managed by the client and the server must not try to read the document's truth using the document's uri. Open in this sense means it is managed by the client. It doesn't necessarily mean that its content is presented in an editor. An open notification must not be sent more than once without a corresponding close notification send before. This means open and close notification must be balanced and the max open count is one. Message Direction: clientToServer","ref":"GenLSP.Notifications.TextDocumentDidOpen.html","title":"GenLSP.Notifications.TextDocumentDidOpen","type":"module"},{"doc":"","ref":"GenLSP.Notifications.TextDocumentDidOpen.html#t:t/0","title":"GenLSP.Notifications.TextDocumentDidOpen.t/0","type":"type"},{"doc":"The document save notification is sent from the client to the server when the document got saved in the client. Message Direction: clientToServer","ref":"GenLSP.Notifications.TextDocumentDidSave.html","title":"GenLSP.Notifications.TextDocumentDidSave","type":"module"},{"doc":"","ref":"GenLSP.Notifications.TextDocumentDidSave.html#t:t/0","title":"GenLSP.Notifications.TextDocumentDidSave.t/0","type":"type"},{"doc":"Diagnostics notification are sent from the server to the client to signal results of validation runs. Message Direction: serverToClient","ref":"GenLSP.Notifications.TextDocumentPublishDiagnostics.html","title":"GenLSP.Notifications.TextDocumentPublishDiagnostics","type":"module"},{"doc":"","ref":"GenLSP.Notifications.TextDocumentPublishDiagnostics.html#t:t/0","title":"GenLSP.Notifications.TextDocumentPublishDiagnostics.t/0","type":"type"},{"doc":"A document will save notification is sent from the client to the server before the document is actually saved. Message Direction: clientToServer","ref":"GenLSP.Notifications.TextDocumentWillSave.html","title":"GenLSP.Notifications.TextDocumentWillSave","type":"module"},{"doc":"","ref":"GenLSP.Notifications.TextDocumentWillSave.html#t:t/0","title":"GenLSP.Notifications.TextDocumentWillSave.t/0","type":"type"},{"doc":"The log message notification is sent from the server to the client to ask the client to log a particular message. Message Direction: serverToClient","ref":"GenLSP.Notifications.WindowLogMessage.html","title":"GenLSP.Notifications.WindowLogMessage","type":"module"},{"doc":"","ref":"GenLSP.Notifications.WindowLogMessage.html#t:t/0","title":"GenLSP.Notifications.WindowLogMessage.t/0","type":"type"},{"doc":"The show message notification is sent from a server to a client to ask the client to display a particular message in the user interface. Message Direction: serverToClient","ref":"GenLSP.Notifications.WindowShowMessage.html","title":"GenLSP.Notifications.WindowShowMessage","type":"module"},{"doc":"","ref":"GenLSP.Notifications.WindowShowMessage.html#t:t/0","title":"GenLSP.Notifications.WindowShowMessage.t/0","type":"type"},{"doc":"The window/workDoneProgress/cancel notification is sent from the client to the server to cancel a progress initiated on the server side. Message Direction: clientToServer","ref":"GenLSP.Notifications.WindowWorkDoneProgressCancel.html","title":"GenLSP.Notifications.WindowWorkDoneProgressCancel","type":"module"},{"doc":"","ref":"GenLSP.Notifications.WindowWorkDoneProgressCancel.html#t:t/0","title":"GenLSP.Notifications.WindowWorkDoneProgressCancel.t/0","type":"type"},{"doc":"The configuration change notification is sent from the client to the server when the client's configuration has changed. The notification contains the changed configuration as defined by the language client. Message Direction: clientToServer","ref":"GenLSP.Notifications.WorkspaceDidChangeConfiguration.html","title":"GenLSP.Notifications.WorkspaceDidChangeConfiguration","type":"module"},{"doc":"","ref":"GenLSP.Notifications.WorkspaceDidChangeConfiguration.html#t:t/0","title":"GenLSP.Notifications.WorkspaceDidChangeConfiguration.t/0","type":"type"},{"doc":"The watched files notification is sent from the client to the server when the client detects changes to file watched by the language client. Message Direction: clientToServer","ref":"GenLSP.Notifications.WorkspaceDidChangeWatchedFiles.html","title":"GenLSP.Notifications.WorkspaceDidChangeWatchedFiles","type":"module"},{"doc":"","ref":"GenLSP.Notifications.WorkspaceDidChangeWatchedFiles.html#t:t/0","title":"GenLSP.Notifications.WorkspaceDidChangeWatchedFiles.t/0","type":"type"},{"doc":"The workspace/didChangeWorkspaceFolders notification is sent from the client to the server when the workspace folder configuration changes. Message Direction: clientToServer","ref":"GenLSP.Notifications.WorkspaceDidChangeWorkspaceFolders.html","title":"GenLSP.Notifications.WorkspaceDidChangeWorkspaceFolders","type":"module"},{"doc":"","ref":"GenLSP.Notifications.WorkspaceDidChangeWorkspaceFolders.html#t:t/0","title":"GenLSP.Notifications.WorkspaceDidChangeWorkspaceFolders.t/0","type":"type"},{"doc":"The did create files notification is sent from the client to the server when files were created from within the client. @since 3.16.0 Message Direction: clientToServer","ref":"GenLSP.Notifications.WorkspaceDidCreateFiles.html","title":"GenLSP.Notifications.WorkspaceDidCreateFiles","type":"module"},{"doc":"","ref":"GenLSP.Notifications.WorkspaceDidCreateFiles.html#t:t/0","title":"GenLSP.Notifications.WorkspaceDidCreateFiles.t/0","type":"type"},{"doc":"The will delete files request is sent from the client to the server before files are actually deleted as long as the deletion is triggered from within the client. @since 3.16.0 Message Direction: clientToServer","ref":"GenLSP.Notifications.WorkspaceDidDeleteFiles.html","title":"GenLSP.Notifications.WorkspaceDidDeleteFiles","type":"module"},{"doc":"","ref":"GenLSP.Notifications.WorkspaceDidDeleteFiles.html#t:t/0","title":"GenLSP.Notifications.WorkspaceDidDeleteFiles.t/0","type":"type"},{"doc":"The did rename files notification is sent from the client to the server when files were renamed from within the client. @since 3.16.0 Message Direction: clientToServer","ref":"GenLSP.Notifications.WorkspaceDidRenameFiles.html","title":"GenLSP.Notifications.WorkspaceDidRenameFiles","type":"module"},{"doc":"","ref":"GenLSP.Notifications.WorkspaceDidRenameFiles.html#t:t/0","title":"GenLSP.Notifications.WorkspaceDidRenameFiles.t/0","type":"type"},{"doc":"A request to resolve the incoming calls for a given CallHierarchyItem . @since 3.16.0 Message Direction: clientToServer","ref":"GenLSP.Requests.CallHierarchyIncomingCalls.html","title":"GenLSP.Requests.CallHierarchyIncomingCalls","type":"module"},{"doc":"","ref":"GenLSP.Requests.CallHierarchyIncomingCalls.html#t:result/0","title":"GenLSP.Requests.CallHierarchyIncomingCalls.result/0","type":"type"},{"doc":"","ref":"GenLSP.Requests.CallHierarchyIncomingCalls.html#t:t/0","title":"GenLSP.Requests.CallHierarchyIncomingCalls.t/0","type":"type"},{"doc":"A request to resolve the outgoing calls for a given CallHierarchyItem . @since 3.16.0 Message Direction: clientToServer","ref":"GenLSP.Requests.CallHierarchyOutgoingCalls.html","title":"GenLSP.Requests.CallHierarchyOutgoingCalls","type":"module"},{"doc":"","ref":"GenLSP.Requests.CallHierarchyOutgoingCalls.html#t:result/0","title":"GenLSP.Requests.CallHierarchyOutgoingCalls.result/0","type":"type"},{"doc":"","ref":"GenLSP.Requests.CallHierarchyOutgoingCalls.html#t:t/0","title":"GenLSP.Requests.CallHierarchyOutgoingCalls.t/0","type":"type"},{"doc":"The client/registerCapability request is sent from the server to the client to register a new capability handler on the client side. Message Direction: serverToClient","ref":"GenLSP.Requests.ClientRegisterCapability.html","title":"GenLSP.Requests.ClientRegisterCapability","type":"module"},{"doc":"","ref":"GenLSP.Requests.ClientRegisterCapability.html#t:result/0","title":"GenLSP.Requests.ClientRegisterCapability.result/0","type":"type"},{"doc":"","ref":"GenLSP.Requests.ClientRegisterCapability.html#t:t/0","title":"GenLSP.Requests.ClientRegisterCapability.t/0","type":"type"},{"doc":"The client/unregisterCapability request is sent from the server to the client to unregister a previously registered capability handler on the client side. Message Direction: serverToClient","ref":"GenLSP.Requests.ClientUnregisterCapability.html","title":"GenLSP.Requests.ClientUnregisterCapability","type":"module"},{"doc":"","ref":"GenLSP.Requests.ClientUnregisterCapability.html#t:result/0","title":"GenLSP.Requests.ClientUnregisterCapability.result/0","type":"type"},{"doc":"","ref":"GenLSP.Requests.ClientUnregisterCapability.html#t:t/0","title":"GenLSP.Requests.ClientUnregisterCapability.t/0","type":"type"},{"doc":"Request to resolve additional information for a given code action.The request's parameter is of type {@link CodeAction} the response is of type {@link CodeAction} or a Thenable that resolves to such. Message Direction: clientToServer","ref":"GenLSP.Requests.CodeActionResolve.html","title":"GenLSP.Requests.CodeActionResolve","type":"module"},{"doc":"","ref":"GenLSP.Requests.CodeActionResolve.html#t:result/0","title":"GenLSP.Requests.CodeActionResolve.result/0","type":"type"},{"doc":"","ref":"GenLSP.Requests.CodeActionResolve.html#t:t/0","title":"GenLSP.Requests.CodeActionResolve.t/0","type":"type"},{"doc":"A request to resolve a command for a given code lens. Message Direction: clientToServer","ref":"GenLSP.Requests.CodeLensResolve.html","title":"GenLSP.Requests.CodeLensResolve","type":"module"},{"doc":"","ref":"GenLSP.Requests.CodeLensResolve.html#t:result/0","title":"GenLSP.Requests.CodeLensResolve.result/0","type":"type"},{"doc":"","ref":"GenLSP.Requests.CodeLensResolve.html#t:t/0","title":"GenLSP.Requests.CodeLensResolve.t/0","type":"type"},{"doc":"Request to resolve additional information for a given completion item.The request's parameter is of type {@link CompletionItem} the response is of type {@link CompletionItem} or a Thenable that resolves to such. Message Direction: clientToServer","ref":"GenLSP.Requests.CompletionItemResolve.html","title":"GenLSP.Requests.CompletionItemResolve","type":"module"},{"doc":"","ref":"GenLSP.Requests.CompletionItemResolve.html#t:result/0","title":"GenLSP.Requests.CompletionItemResolve.result/0","type":"type"},{"doc":"","ref":"GenLSP.Requests.CompletionItemResolve.html#t:t/0","title":"GenLSP.Requests.CompletionItemResolve.t/0","type":"type"},{"doc":"Request to resolve additional information for a given document link. The request's parameter is of type {@link DocumentLink} the response is of type {@link DocumentLink} or a Thenable that resolves to such. Message Direction: clientToServer","ref":"GenLSP.Requests.DocumentLinkResolve.html","title":"GenLSP.Requests.DocumentLinkResolve","type":"module"},{"doc":"","ref":"GenLSP.Requests.DocumentLinkResolve.html#t:result/0","title":"GenLSP.Requests.DocumentLinkResolve.result/0","type":"type"},{"doc":"","ref":"GenLSP.Requests.DocumentLinkResolve.html#t:t/0","title":"GenLSP.Requests.DocumentLinkResolve.t/0","type":"type"},{"doc":"The initialize request is sent from the client to the server. It is sent once as the request after starting up the server. The requests parameter is of type {@link InitializeParams} the response if of type {@link InitializeResult} of a Thenable that resolves to such. Message Direction: clientToServer","ref":"GenLSP.Requests.Initialize.html","title":"GenLSP.Requests.Initialize","type":"module"},{"doc":"","ref":"GenLSP.Requests.Initialize.html#t:result/0","title":"GenLSP.Requests.Initialize.result/0","type":"type"},{"doc":"","ref":"GenLSP.Requests.Initialize.html#t:t/0","title":"GenLSP.Requests.Initialize.t/0","type":"type"},{"doc":"A request to resolve additional properties for an inlay hint. The request's parameter is of type {@link InlayHint}, the response is of type {@link InlayHint} or a Thenable that resolves to such. @since 3.17.0 Message Direction: clientToServer","ref":"GenLSP.Requests.InlayHintResolve.html","title":"GenLSP.Requests.InlayHintResolve","type":"module"},{"doc":"","ref":"GenLSP.Requests.InlayHintResolve.html#t:result/0","title":"GenLSP.Requests.InlayHintResolve.result/0","type":"type"},{"doc":"","ref":"GenLSP.Requests.InlayHintResolve.html#t:t/0","title":"GenLSP.Requests.InlayHintResolve.t/0","type":"type"},{"doc":"A shutdown request is sent from the client to the server. It is sent once when the client decides to shutdown the server. The only notification that is sent after a shutdown request is the exit event. Message Direction: clientToServer","ref":"GenLSP.Requests.Shutdown.html","title":"GenLSP.Requests.Shutdown","type":"module"},{"doc":"","ref":"GenLSP.Requests.Shutdown.html#t:result/0","title":"GenLSP.Requests.Shutdown.result/0","type":"type"},{"doc":"","ref":"GenLSP.Requests.Shutdown.html#t:t/0","title":"GenLSP.Requests.Shutdown.t/0","type":"type"},{"doc":"A request to provide commands for the given text document and range. Message Direction: clientToServer","ref":"GenLSP.Requests.TextDocumentCodeAction.html","title":"GenLSP.Requests.TextDocumentCodeAction","type":"module"},{"doc":"","ref":"GenLSP.Requests.TextDocumentCodeAction.html#t:result/0","title":"GenLSP.Requests.TextDocumentCodeAction.result/0","type":"type"},{"doc":"","ref":"GenLSP.Requests.TextDocumentCodeAction.html#t:t/0","title":"GenLSP.Requests.TextDocumentCodeAction.t/0","type":"type"},{"doc":"A request to provide code lens for the given text document. Message Direction: clientToServer","ref":"GenLSP.Requests.TextDocumentCodeLens.html","title":"GenLSP.Requests.TextDocumentCodeLens","type":"module"},{"doc":"","ref":"GenLSP.Requests.TextDocumentCodeLens.html#t:result/0","title":"GenLSP.Requests.TextDocumentCodeLens.result/0","type":"type"},{"doc":"","ref":"GenLSP.Requests.TextDocumentCodeLens.html#t:t/0","title":"GenLSP.Requests.TextDocumentCodeLens.t/0","type":"type"},{"doc":"A request to list all presentation for a color. The request's parameter is of type {@link ColorPresentationParams} the response is of type {@link ColorInformation ColorInformation[]} or a Thenable that resolves to such. Message Direction: clientToServer","ref":"GenLSP.Requests.TextDocumentColorPresentation.html","title":"GenLSP.Requests.TextDocumentColorPresentation","type":"module"},{"doc":"","ref":"GenLSP.Requests.TextDocumentColorPresentation.html#t:result/0","title":"GenLSP.Requests.TextDocumentColorPresentation.result/0","type":"type"},{"doc":"","ref":"GenLSP.Requests.TextDocumentColorPresentation.html#t:t/0","title":"GenLSP.Requests.TextDocumentColorPresentation.t/0","type":"type"},{"doc":"Request to request completion at a given text document position. The request's parameter is of type {@link TextDocumentPosition} the response is of type {@link CompletionItem CompletionItem[]} or {@link CompletionList} or a Thenable that resolves to such. The request can delay the computation of the {@link CompletionItem.detail detail } and {@link CompletionItem.documentation documentation } properties to the completionItem/resolve request. However, properties that are needed for the initial sorting and filtering, like sortText , filterText , insertText , and textEdit , must not be changed during resolve. Message Direction: clientToServer","ref":"GenLSP.Requests.TextDocumentCompletion.html","title":"GenLSP.Requests.TextDocumentCompletion","type":"module"},{"doc":"","ref":"GenLSP.Requests.TextDocumentCompletion.html#t:result/0","title":"GenLSP.Requests.TextDocumentCompletion.result/0","type":"type"},{"doc":"","ref":"GenLSP.Requests.TextDocumentCompletion.html#t:t/0","title":"GenLSP.Requests.TextDocumentCompletion.t/0","type":"type"},{"doc":"A request to resolve the type definition locations of a symbol at a given text document position. The request's parameter is of type [TextDocumentPositionParams] (#TextDocumentPositionParams) the response is of type {@link Declaration} or a typed array of {@link DeclarationLink} or a Thenable that resolves to such. Message Direction: clientToServer","ref":"GenLSP.Requests.TextDocumentDeclaration.html","title":"GenLSP.Requests.TextDocumentDeclaration","type":"module"},{"doc":"","ref":"GenLSP.Requests.TextDocumentDeclaration.html#t:result/0","title":"GenLSP.Requests.TextDocumentDeclaration.result/0","type":"type"},{"doc":"","ref":"GenLSP.Requests.TextDocumentDeclaration.html#t:t/0","title":"GenLSP.Requests.TextDocumentDeclaration.t/0","type":"type"},{"doc":"A request to resolve the definition location of a symbol at a given text document position. The request's parameter is of type [TextDocumentPosition] (#TextDocumentPosition) the response is of either type {@link Definition} or a typed array of {@link DefinitionLink} or a Thenable that resolves to such. Message Direction: clientToServer","ref":"GenLSP.Requests.TextDocumentDefinition.html","title":"GenLSP.Requests.TextDocumentDefinition","type":"module"},{"doc":"","ref":"GenLSP.Requests.TextDocumentDefinition.html#t:result/0","title":"GenLSP.Requests.TextDocumentDefinition.result/0","type":"type"},{"doc":"","ref":"GenLSP.Requests.TextDocumentDefinition.html#t:t/0","title":"GenLSP.Requests.TextDocumentDefinition.t/0","type":"type"},{"doc":"The document diagnostic request definition. @since 3.17.0 Message Direction: clientToServer","ref":"GenLSP.Requests.TextDocumentDiagnostic.html","title":"GenLSP.Requests.TextDocumentDiagnostic","type":"module"},{"doc":"","ref":"GenLSP.Requests.TextDocumentDiagnostic.html#t:result/0","title":"GenLSP.Requests.TextDocumentDiagnostic.result/0","type":"type"},{"doc":"","ref":"GenLSP.Requests.TextDocumentDiagnostic.html#t:t/0","title":"GenLSP.Requests.TextDocumentDiagnostic.t/0","type":"type"},{"doc":"A request to list all color symbols found in a given text document. The request's parameter is of type {@link DocumentColorParams} the response is of type {@link ColorInformation ColorInformation[]} or a Thenable that resolves to such. Message Direction: clientToServer","ref":"GenLSP.Requests.TextDocumentDocumentColor.html","title":"GenLSP.Requests.TextDocumentDocumentColor","type":"module"},{"doc":"","ref":"GenLSP.Requests.TextDocumentDocumentColor.html#t:result/0","title":"GenLSP.Requests.TextDocumentDocumentColor.result/0","type":"type"},{"doc":"","ref":"GenLSP.Requests.TextDocumentDocumentColor.html#t:t/0","title":"GenLSP.Requests.TextDocumentDocumentColor.t/0","type":"type"},{"doc":"Request to resolve a {@link DocumentHighlight} for a given text document position. The request's parameter is of type [TextDocumentPosition] (#TextDocumentPosition) the request response is of type [DocumentHighlight[]] (#DocumentHighlight) or a Thenable that resolves to such. Message Direction: clientToServer","ref":"GenLSP.Requests.TextDocumentDocumentHighlight.html","title":"GenLSP.Requests.TextDocumentDocumentHighlight","type":"module"},{"doc":"","ref":"GenLSP.Requests.TextDocumentDocumentHighlight.html#t:result/0","title":"GenLSP.Requests.TextDocumentDocumentHighlight.result/0","type":"type"},{"doc":"","ref":"GenLSP.Requests.TextDocumentDocumentHighlight.html#t:t/0","title":"GenLSP.Requests.TextDocumentDocumentHighlight.t/0","type":"type"},{"doc":"A request to provide document links Message Direction: clientToServer","ref":"GenLSP.Requests.TextDocumentDocumentLink.html","title":"GenLSP.Requests.TextDocumentDocumentLink","type":"module"},{"doc":"","ref":"GenLSP.Requests.TextDocumentDocumentLink.html#t:result/0","title":"GenLSP.Requests.TextDocumentDocumentLink.result/0","type":"type"},{"doc":"","ref":"GenLSP.Requests.TextDocumentDocumentLink.html#t:t/0","title":"GenLSP.Requests.TextDocumentDocumentLink.t/0","type":"type"},{"doc":"A request to list all symbols found in a given text document. The request's parameter is of type {@link TextDocumentIdentifier} the response is of type {@link SymbolInformation SymbolInformation[]} or a Thenable that resolves to such. Message Direction: clientToServer","ref":"GenLSP.Requests.TextDocumentDocumentSymbol.html","title":"GenLSP.Requests.TextDocumentDocumentSymbol","type":"module"},{"doc":"","ref":"GenLSP.Requests.TextDocumentDocumentSymbol.html#t:result/0","title":"GenLSP.Requests.TextDocumentDocumentSymbol.result/0","type":"type"},{"doc":"","ref":"GenLSP.Requests.TextDocumentDocumentSymbol.html#t:t/0","title":"GenLSP.Requests.TextDocumentDocumentSymbol.t/0","type":"type"},{"doc":"A request to provide folding ranges in a document. The request's parameter is of type {@link FoldingRangeParams}, the response is of type {@link FoldingRangeList} or a Thenable that resolves to such. Message Direction: clientToServer","ref":"GenLSP.Requests.TextDocumentFoldingRange.html","title":"GenLSP.Requests.TextDocumentFoldingRange","type":"module"},{"doc":"","ref":"GenLSP.Requests.TextDocumentFoldingRange.html#t:result/0","title":"GenLSP.Requests.TextDocumentFoldingRange.result/0","type":"type"},{"doc":"","ref":"GenLSP.Requests.TextDocumentFoldingRange.html#t:t/0","title":"GenLSP.Requests.TextDocumentFoldingRange.t/0","type":"type"},{"doc":"A request to format a whole document. Message Direction: clientToServer","ref":"GenLSP.Requests.TextDocumentFormatting.html","title":"GenLSP.Requests.TextDocumentFormatting","type":"module"},{"doc":"","ref":"GenLSP.Requests.TextDocumentFormatting.html#t:result/0","title":"GenLSP.Requests.TextDocumentFormatting.result/0","type":"type"},{"doc":"","ref":"GenLSP.Requests.TextDocumentFormatting.html#t:t/0","title":"GenLSP.Requests.TextDocumentFormatting.t/0","type":"type"},{"doc":"Request to request hover information at a given text document position. The request's parameter is of type {@link TextDocumentPosition} the response is of type {@link Hover} or a Thenable that resolves to such. Message Direction: clientToServer","ref":"GenLSP.Requests.TextDocumentHover.html","title":"GenLSP.Requests.TextDocumentHover","type":"module"},{"doc":"","ref":"GenLSP.Requests.TextDocumentHover.html#t:result/0","title":"GenLSP.Requests.TextDocumentHover.result/0","type":"type"},{"doc":"","ref":"GenLSP.Requests.TextDocumentHover.html#t:t/0","title":"GenLSP.Requests.TextDocumentHover.t/0","type":"type"},{"doc":"A request to resolve the implementation locations of a symbol at a given text document position. The request's parameter is of type [TextDocumentPositionParams] (#TextDocumentPositionParams) the response is of type {@link Definition} or a Thenable that resolves to such. Message Direction: clientToServer","ref":"GenLSP.Requests.TextDocumentImplementation.html","title":"GenLSP.Requests.TextDocumentImplementation","type":"module"},{"doc":"","ref":"GenLSP.Requests.TextDocumentImplementation.html#t:result/0","title":"GenLSP.Requests.TextDocumentImplementation.result/0","type":"type"},{"doc":"","ref":"GenLSP.Requests.TextDocumentImplementation.html#t:t/0","title":"GenLSP.Requests.TextDocumentImplementation.t/0","type":"type"},{"doc":"A request to provide inlay hints in a document. The request's parameter is of type {@link InlayHintsParams}, the response is of type {@link InlayHint InlayHint[]} or a Thenable that resolves to such. @since 3.17.0 Message Direction: clientToServer","ref":"GenLSP.Requests.TextDocumentInlayHint.html","title":"GenLSP.Requests.TextDocumentInlayHint","type":"module"},{"doc":"","ref":"GenLSP.Requests.TextDocumentInlayHint.html#t:result/0","title":"GenLSP.Requests.TextDocumentInlayHint.result/0","type":"type"},{"doc":"","ref":"GenLSP.Requests.TextDocumentInlayHint.html#t:t/0","title":"GenLSP.Requests.TextDocumentInlayHint.t/0","type":"type"},{"doc":"A request to provide inline values in a document. The request's parameter is of type {@link InlineValueParams}, the response is of type {@link InlineValue InlineValue[]} or a Thenable that resolves to such. @since 3.17.0 Message Direction: clientToServer","ref":"GenLSP.Requests.TextDocumentInlineValue.html","title":"GenLSP.Requests.TextDocumentInlineValue","type":"module"},{"doc":"","ref":"GenLSP.Requests.TextDocumentInlineValue.html#t:result/0","title":"GenLSP.Requests.TextDocumentInlineValue.result/0","type":"type"},{"doc":"","ref":"GenLSP.Requests.TextDocumentInlineValue.html#t:t/0","title":"GenLSP.Requests.TextDocumentInlineValue.t/0","type":"type"},{"doc":"A request to provide ranges that can be edited together. @since 3.16.0 Message Direction: clientToServer","ref":"GenLSP.Requests.TextDocumentLinkedEditingRange.html","title":"GenLSP.Requests.TextDocumentLinkedEditingRange","type":"module"},{"doc":"","ref":"GenLSP.Requests.TextDocumentLinkedEditingRange.html#t:result/0","title":"GenLSP.Requests.TextDocumentLinkedEditingRange.result/0","type":"type"},{"doc":"","ref":"GenLSP.Requests.TextDocumentLinkedEditingRange.html#t:t/0","title":"GenLSP.Requests.TextDocumentLinkedEditingRange.t/0","type":"type"},{"doc":"A request to get the moniker of a symbol at a given text document position. The request parameter is of type {@link TextDocumentPositionParams}. The response is of type {@link Moniker Moniker[]} or null . Message Direction: clientToServer","ref":"GenLSP.Requests.TextDocumentMoniker.html","title":"GenLSP.Requests.TextDocumentMoniker","type":"module"},{"doc":"","ref":"GenLSP.Requests.TextDocumentMoniker.html#t:result/0","title":"GenLSP.Requests.TextDocumentMoniker.result/0","type":"type"},{"doc":"","ref":"GenLSP.Requests.TextDocumentMoniker.html#t:t/0","title":"GenLSP.Requests.TextDocumentMoniker.t/0","type":"type"},{"doc":"A request to format a document on type. Message Direction: clientToServer","ref":"GenLSP.Requests.TextDocumentOnTypeFormatting.html","title":"GenLSP.Requests.TextDocumentOnTypeFormatting","type":"module"},{"doc":"","ref":"GenLSP.Requests.TextDocumentOnTypeFormatting.html#t:result/0","title":"GenLSP.Requests.TextDocumentOnTypeFormatting.result/0","type":"type"},{"doc":"","ref":"GenLSP.Requests.TextDocumentOnTypeFormatting.html#t:t/0","title":"GenLSP.Requests.TextDocumentOnTypeFormatting.t/0","type":"type"},{"doc":"A request to result a CallHierarchyItem in a document at a given position. Can be used as an input to an incoming or outgoing call hierarchy. @since 3.16.0 Message Direction: clientToServer","ref":"GenLSP.Requests.TextDocumentPrepareCallHierarchy.html","title":"GenLSP.Requests.TextDocumentPrepareCallHierarchy","type":"module"},{"doc":"","ref":"GenLSP.Requests.TextDocumentPrepareCallHierarchy.html#t:result/0","title":"GenLSP.Requests.TextDocumentPrepareCallHierarchy.result/0","type":"type"},{"doc":"","ref":"GenLSP.Requests.TextDocumentPrepareCallHierarchy.html#t:t/0","title":"GenLSP.Requests.TextDocumentPrepareCallHierarchy.t/0","type":"type"},{"doc":"A request to test and perform the setup necessary for a rename. @since 3.16 - support for default behavior Message Direction: clientToServer","ref":"GenLSP.Requests.TextDocumentPrepareRename.html","title":"GenLSP.Requests.TextDocumentPrepareRename","type":"module"},{"doc":"","ref":"GenLSP.Requests.TextDocumentPrepareRename.html#t:result/0","title":"GenLSP.Requests.TextDocumentPrepareRename.result/0","type":"type"},{"doc":"","ref":"GenLSP.Requests.TextDocumentPrepareRename.html#t:t/0","title":"GenLSP.Requests.TextDocumentPrepareRename.t/0","type":"type"},{"doc":"A request to result a TypeHierarchyItem in a document at a given position. Can be used as an input to a subtypes or supertypes type hierarchy. @since 3.17.0 Message Direction: clientToServer","ref":"GenLSP.Requests.TextDocumentPrepareTypeHierarchy.html","title":"GenLSP.Requests.TextDocumentPrepareTypeHierarchy","type":"module"},{"doc":"","ref":"GenLSP.Requests.TextDocumentPrepareTypeHierarchy.html#t:result/0","title":"GenLSP.Requests.TextDocumentPrepareTypeHierarchy.result/0","type":"type"},{"doc":"","ref":"GenLSP.Requests.TextDocumentPrepareTypeHierarchy.html#t:t/0","title":"GenLSP.Requests.TextDocumentPrepareTypeHierarchy.t/0","type":"type"},{"doc":"A request to format a range in a document. Message Direction: clientToServer","ref":"GenLSP.Requests.TextDocumentRangeFormatting.html","title":"GenLSP.Requests.TextDocumentRangeFormatting","type":"module"},{"doc":"","ref":"GenLSP.Requests.TextDocumentRangeFormatting.html#t:result/0","title":"GenLSP.Requests.TextDocumentRangeFormatting.result/0","type":"type"},{"doc":"","ref":"GenLSP.Requests.TextDocumentRangeFormatting.html#t:t/0","title":"GenLSP.Requests.TextDocumentRangeFormatting.t/0","type":"type"},{"doc":"A request to resolve project-wide references for the symbol denoted by the given text document position. The request's parameter is of type {@link ReferenceParams} the response is of type {@link Location Location[]} or a Thenable that resolves to such. Message Direction: clientToServer","ref":"GenLSP.Requests.TextDocumentReferences.html","title":"GenLSP.Requests.TextDocumentReferences","type":"module"},{"doc":"","ref":"GenLSP.Requests.TextDocumentReferences.html#t:result/0","title":"GenLSP.Requests.TextDocumentReferences.result/0","type":"type"},{"doc":"","ref":"GenLSP.Requests.TextDocumentReferences.html#t:t/0","title":"GenLSP.Requests.TextDocumentReferences.t/0","type":"type"},{"doc":"A request to rename a symbol. Message Direction: clientToServer","ref":"GenLSP.Requests.TextDocumentRename.html","title":"GenLSP.Requests.TextDocumentRename","type":"module"},{"doc":"","ref":"GenLSP.Requests.TextDocumentRename.html#t:result/0","title":"GenLSP.Requests.TextDocumentRename.result/0","type":"type"},{"doc":"","ref":"GenLSP.Requests.TextDocumentRename.html#t:t/0","title":"GenLSP.Requests.TextDocumentRename.t/0","type":"type"},{"doc":"A request to provide selection ranges in a document. The request's parameter is of type {@link SelectionRangeParams}, the response is of type {@link SelectionRange SelectionRange[]} or a Thenable that resolves to such. Message Direction: clientToServer","ref":"GenLSP.Requests.TextDocumentSelectionRange.html","title":"GenLSP.Requests.TextDocumentSelectionRange","type":"module"},{"doc":"","ref":"GenLSP.Requests.TextDocumentSelectionRange.html#t:result/0","title":"GenLSP.Requests.TextDocumentSelectionRange.result/0","type":"type"},{"doc":"","ref":"GenLSP.Requests.TextDocumentSelectionRange.html#t:t/0","title":"GenLSP.Requests.TextDocumentSelectionRange.t/0","type":"type"},{"doc":"@since 3.16.0 Message Direction: clientToServer","ref":"GenLSP.Requests.TextDocumentSemanticTokensFull.html","title":"GenLSP.Requests.TextDocumentSemanticTokensFull","type":"module"},{"doc":"","ref":"GenLSP.Requests.TextDocumentSemanticTokensFull.html#t:result/0","title":"GenLSP.Requests.TextDocumentSemanticTokensFull.result/0","type":"type"},{"doc":"","ref":"GenLSP.Requests.TextDocumentSemanticTokensFull.html#t:t/0","title":"GenLSP.Requests.TextDocumentSemanticTokensFull.t/0","type":"type"},{"doc":"@since 3.16.0 Message Direction: clientToServer","ref":"GenLSP.Requests.TextDocumentSemanticTokensFullDelta.html","title":"GenLSP.Requests.TextDocumentSemanticTokensFullDelta","type":"module"},{"doc":"","ref":"GenLSP.Requests.TextDocumentSemanticTokensFullDelta.html#t:result/0","title":"GenLSP.Requests.TextDocumentSemanticTokensFullDelta.result/0","type":"type"},{"doc":"","ref":"GenLSP.Requests.TextDocumentSemanticTokensFullDelta.html#t:t/0","title":"GenLSP.Requests.TextDocumentSemanticTokensFullDelta.t/0","type":"type"},{"doc":"@since 3.16.0 Message Direction: clientToServer","ref":"GenLSP.Requests.TextDocumentSemanticTokensRange.html","title":"GenLSP.Requests.TextDocumentSemanticTokensRange","type":"module"},{"doc":"","ref":"GenLSP.Requests.TextDocumentSemanticTokensRange.html#t:result/0","title":"GenLSP.Requests.TextDocumentSemanticTokensRange.result/0","type":"type"},{"doc":"","ref":"GenLSP.Requests.TextDocumentSemanticTokensRange.html#t:t/0","title":"GenLSP.Requests.TextDocumentSemanticTokensRange.t/0","type":"type"},{"doc":"","ref":"GenLSP.Requests.TextDocumentSignatureHelp.html","title":"GenLSP.Requests.TextDocumentSignatureHelp","type":"module"},{"doc":"","ref":"GenLSP.Requests.TextDocumentSignatureHelp.html#t:result/0","title":"GenLSP.Requests.TextDocumentSignatureHelp.result/0","type":"type"},{"doc":"","ref":"GenLSP.Requests.TextDocumentSignatureHelp.html#t:t/0","title":"GenLSP.Requests.TextDocumentSignatureHelp.t/0","type":"type"},{"doc":"A request to resolve the type definition locations of a symbol at a given text document position. The request's parameter is of type [TextDocumentPositionParams] (#TextDocumentPositionParams) the response is of type {@link Definition} or a Thenable that resolves to such. Message Direction: clientToServer","ref":"GenLSP.Requests.TextDocumentTypeDefinition.html","title":"GenLSP.Requests.TextDocumentTypeDefinition","type":"module"},{"doc":"","ref":"GenLSP.Requests.TextDocumentTypeDefinition.html#t:result/0","title":"GenLSP.Requests.TextDocumentTypeDefinition.result/0","type":"type"},{"doc":"","ref":"GenLSP.Requests.TextDocumentTypeDefinition.html#t:t/0","title":"GenLSP.Requests.TextDocumentTypeDefinition.t/0","type":"type"},{"doc":"A document will save request is sent from the client to the server before the document is actually saved. The request can return an array of TextEdits which will be applied to the text document before it is saved. Please note that clients might drop results if computing the text edits took too long or if a server constantly fails on this request. This is done to keep the save fast and reliable. Message Direction: clientToServer","ref":"GenLSP.Requests.TextDocumentWillSaveWaitUntil.html","title":"GenLSP.Requests.TextDocumentWillSaveWaitUntil","type":"module"},{"doc":"","ref":"GenLSP.Requests.TextDocumentWillSaveWaitUntil.html#t:result/0","title":"GenLSP.Requests.TextDocumentWillSaveWaitUntil.result/0","type":"type"},{"doc":"","ref":"GenLSP.Requests.TextDocumentWillSaveWaitUntil.html#t:t/0","title":"GenLSP.Requests.TextDocumentWillSaveWaitUntil.t/0","type":"type"},{"doc":"A request to resolve the subtypes for a given TypeHierarchyItem . @since 3.17.0 Message Direction: clientToServer","ref":"GenLSP.Requests.TypeHierarchySubtypes.html","title":"GenLSP.Requests.TypeHierarchySubtypes","type":"module"},{"doc":"","ref":"GenLSP.Requests.TypeHierarchySubtypes.html#t:result/0","title":"GenLSP.Requests.TypeHierarchySubtypes.result/0","type":"type"},{"doc":"","ref":"GenLSP.Requests.TypeHierarchySubtypes.html#t:t/0","title":"GenLSP.Requests.TypeHierarchySubtypes.t/0","type":"type"},{"doc":"A request to resolve the supertypes for a given TypeHierarchyItem . @since 3.17.0 Message Direction: clientToServer","ref":"GenLSP.Requests.TypeHierarchySupertypes.html","title":"GenLSP.Requests.TypeHierarchySupertypes","type":"module"},{"doc":"","ref":"GenLSP.Requests.TypeHierarchySupertypes.html#t:result/0","title":"GenLSP.Requests.TypeHierarchySupertypes.result/0","type":"type"},{"doc":"","ref":"GenLSP.Requests.TypeHierarchySupertypes.html#t:t/0","title":"GenLSP.Requests.TypeHierarchySupertypes.t/0","type":"type"},{"doc":"A request to show a document. This request might open an external program depending on the value of the URI to open. For example a request to open https://code.visualstudio.com/ will very likely open the URI in a WEB browser. @since 3.16.0 Message Direction: serverToClient","ref":"GenLSP.Requests.WindowShowDocument.html","title":"GenLSP.Requests.WindowShowDocument","type":"module"},{"doc":"","ref":"GenLSP.Requests.WindowShowDocument.html#t:result/0","title":"GenLSP.Requests.WindowShowDocument.result/0","type":"type"},{"doc":"","ref":"GenLSP.Requests.WindowShowDocument.html#t:t/0","title":"GenLSP.Requests.WindowShowDocument.t/0","type":"type"},{"doc":"The show message request is sent from the server to the client to show a message and a set of options actions to the user. Message Direction: serverToClient","ref":"GenLSP.Requests.WindowShowMessageRequest.html","title":"GenLSP.Requests.WindowShowMessageRequest","type":"module"},{"doc":"","ref":"GenLSP.Requests.WindowShowMessageRequest.html#t:result/0","title":"GenLSP.Requests.WindowShowMessageRequest.result/0","type":"type"},{"doc":"","ref":"GenLSP.Requests.WindowShowMessageRequest.html#t:t/0","title":"GenLSP.Requests.WindowShowMessageRequest.t/0","type":"type"},{"doc":"The window/workDoneProgress/create request is sent from the server to the client to initiate progress reporting from the server. Message Direction: serverToClient","ref":"GenLSP.Requests.WindowWorkDoneProgressCreate.html","title":"GenLSP.Requests.WindowWorkDoneProgressCreate","type":"module"},{"doc":"","ref":"GenLSP.Requests.WindowWorkDoneProgressCreate.html#t:result/0","title":"GenLSP.Requests.WindowWorkDoneProgressCreate.result/0","type":"type"},{"doc":"","ref":"GenLSP.Requests.WindowWorkDoneProgressCreate.html#t:t/0","title":"GenLSP.Requests.WindowWorkDoneProgressCreate.t/0","type":"type"},{"doc":"A request sent from the server to the client to modified certain resources. Message Direction: serverToClient","ref":"GenLSP.Requests.WorkspaceApplyEdit.html","title":"GenLSP.Requests.WorkspaceApplyEdit","type":"module"},{"doc":"","ref":"GenLSP.Requests.WorkspaceApplyEdit.html#t:result/0","title":"GenLSP.Requests.WorkspaceApplyEdit.result/0","type":"type"},{"doc":"","ref":"GenLSP.Requests.WorkspaceApplyEdit.html#t:t/0","title":"GenLSP.Requests.WorkspaceApplyEdit.t/0","type":"type"},{"doc":"A request to refresh all code actions @since 3.16.0 Message Direction: serverToClient","ref":"GenLSP.Requests.WorkspaceCodeLensRefresh.html","title":"GenLSP.Requests.WorkspaceCodeLensRefresh","type":"module"},{"doc":"","ref":"GenLSP.Requests.WorkspaceCodeLensRefresh.html#t:result/0","title":"GenLSP.Requests.WorkspaceCodeLensRefresh.result/0","type":"type"},{"doc":"","ref":"GenLSP.Requests.WorkspaceCodeLensRefresh.html#t:t/0","title":"GenLSP.Requests.WorkspaceCodeLensRefresh.t/0","type":"type"},{"doc":"The 'workspace/configuration' request is sent from the server to the client to fetch a certain configuration setting. This pull model replaces the old push model were the client signaled configuration change via an event. If the server still needs to react to configuration changes (since the server caches the result of workspace/configuration requests) the server should register for an empty configuration change event and empty the cache if such an event is received. Message Direction: serverToClient","ref":"GenLSP.Requests.WorkspaceConfiguration.html","title":"GenLSP.Requests.WorkspaceConfiguration","type":"module"},{"doc":"","ref":"GenLSP.Requests.WorkspaceConfiguration.html#t:result/0","title":"GenLSP.Requests.WorkspaceConfiguration.result/0","type":"type"},{"doc":"","ref":"GenLSP.Requests.WorkspaceConfiguration.html#t:t/0","title":"GenLSP.Requests.WorkspaceConfiguration.t/0","type":"type"},{"doc":"The workspace diagnostic request definition. @since 3.17.0 Message Direction: clientToServer","ref":"GenLSP.Requests.WorkspaceDiagnostic.html","title":"GenLSP.Requests.WorkspaceDiagnostic","type":"module"},{"doc":"","ref":"GenLSP.Requests.WorkspaceDiagnostic.html#t:result/0","title":"GenLSP.Requests.WorkspaceDiagnostic.result/0","type":"type"},{"doc":"","ref":"GenLSP.Requests.WorkspaceDiagnostic.html#t:t/0","title":"GenLSP.Requests.WorkspaceDiagnostic.t/0","type":"type"},{"doc":"The diagnostic refresh request definition. @since 3.17.0 Message Direction: serverToClient","ref":"GenLSP.Requests.WorkspaceDiagnosticRefresh.html","title":"GenLSP.Requests.WorkspaceDiagnosticRefresh","type":"module"},{"doc":"","ref":"GenLSP.Requests.WorkspaceDiagnosticRefresh.html#t:result/0","title":"GenLSP.Requests.WorkspaceDiagnosticRefresh.result/0","type":"type"},{"doc":"","ref":"GenLSP.Requests.WorkspaceDiagnosticRefresh.html#t:t/0","title":"GenLSP.Requests.WorkspaceDiagnosticRefresh.t/0","type":"type"},{"doc":"A request send from the client to the server to execute a command. The request might return a workspace edit which the client will apply to the workspace. Message Direction: clientToServer","ref":"GenLSP.Requests.WorkspaceExecuteCommand.html","title":"GenLSP.Requests.WorkspaceExecuteCommand","type":"module"},{"doc":"","ref":"GenLSP.Requests.WorkspaceExecuteCommand.html#t:result/0","title":"GenLSP.Requests.WorkspaceExecuteCommand.result/0","type":"type"},{"doc":"","ref":"GenLSP.Requests.WorkspaceExecuteCommand.html#t:t/0","title":"GenLSP.Requests.WorkspaceExecuteCommand.t/0","type":"type"},{"doc":"@since 3.17.0 Message Direction: serverToClient","ref":"GenLSP.Requests.WorkspaceInlayHintRefresh.html","title":"GenLSP.Requests.WorkspaceInlayHintRefresh","type":"module"},{"doc":"","ref":"GenLSP.Requests.WorkspaceInlayHintRefresh.html#t:result/0","title":"GenLSP.Requests.WorkspaceInlayHintRefresh.result/0","type":"type"},{"doc":"","ref":"GenLSP.Requests.WorkspaceInlayHintRefresh.html#t:t/0","title":"GenLSP.Requests.WorkspaceInlayHintRefresh.t/0","type":"type"},{"doc":"@since 3.17.0 Message Direction: serverToClient","ref":"GenLSP.Requests.WorkspaceInlineValueRefresh.html","title":"GenLSP.Requests.WorkspaceInlineValueRefresh","type":"module"},{"doc":"","ref":"GenLSP.Requests.WorkspaceInlineValueRefresh.html#t:result/0","title":"GenLSP.Requests.WorkspaceInlineValueRefresh.result/0","type":"type"},{"doc":"","ref":"GenLSP.Requests.WorkspaceInlineValueRefresh.html#t:t/0","title":"GenLSP.Requests.WorkspaceInlineValueRefresh.t/0","type":"type"},{"doc":"@since 3.16.0 Message Direction: serverToClient","ref":"GenLSP.Requests.WorkspaceSemanticTokensRefresh.html","title":"GenLSP.Requests.WorkspaceSemanticTokensRefresh","type":"module"},{"doc":"","ref":"GenLSP.Requests.WorkspaceSemanticTokensRefresh.html#t:result/0","title":"GenLSP.Requests.WorkspaceSemanticTokensRefresh.result/0","type":"type"},{"doc":"","ref":"GenLSP.Requests.WorkspaceSemanticTokensRefresh.html#t:t/0","title":"GenLSP.Requests.WorkspaceSemanticTokensRefresh.t/0","type":"type"},{"doc":"A request to list project-wide symbols matching the query string given by the {@link WorkspaceSymbolParams}. The response is of type {@link SymbolInformation SymbolInformation[]} or a Thenable that resolves to such. @since 3.17.0 - support for WorkspaceSymbol in the returned data. Clients need to advertise support for WorkspaceSymbols via the client capability workspace.symbol.resolveSupport . Message Direction: clientToServer","ref":"GenLSP.Requests.WorkspaceSymbol.html","title":"GenLSP.Requests.WorkspaceSymbol","type":"module"},{"doc":"","ref":"GenLSP.Requests.WorkspaceSymbol.html#t:result/0","title":"GenLSP.Requests.WorkspaceSymbol.result/0","type":"type"},{"doc":"","ref":"GenLSP.Requests.WorkspaceSymbol.html#t:t/0","title":"GenLSP.Requests.WorkspaceSymbol.t/0","type":"type"},{"doc":"A request to resolve the range inside the workspace symbol's location. @since 3.17.0 Message Direction: clientToServer","ref":"GenLSP.Requests.WorkspaceSymbolResolve.html","title":"GenLSP.Requests.WorkspaceSymbolResolve","type":"module"},{"doc":"","ref":"GenLSP.Requests.WorkspaceSymbolResolve.html#t:result/0","title":"GenLSP.Requests.WorkspaceSymbolResolve.result/0","type":"type"},{"doc":"","ref":"GenLSP.Requests.WorkspaceSymbolResolve.html#t:t/0","title":"GenLSP.Requests.WorkspaceSymbolResolve.t/0","type":"type"},{"doc":"The will create files request is sent from the client to the server before files are actually created as long as the creation is triggered from within the client. @since 3.16.0 Message Direction: clientToServer","ref":"GenLSP.Requests.WorkspaceWillCreateFiles.html","title":"GenLSP.Requests.WorkspaceWillCreateFiles","type":"module"},{"doc":"","ref":"GenLSP.Requests.WorkspaceWillCreateFiles.html#t:result/0","title":"GenLSP.Requests.WorkspaceWillCreateFiles.result/0","type":"type"},{"doc":"","ref":"GenLSP.Requests.WorkspaceWillCreateFiles.html#t:t/0","title":"GenLSP.Requests.WorkspaceWillCreateFiles.t/0","type":"type"},{"doc":"The did delete files notification is sent from the client to the server when files were deleted from within the client. @since 3.16.0 Message Direction: clientToServer","ref":"GenLSP.Requests.WorkspaceWillDeleteFiles.html","title":"GenLSP.Requests.WorkspaceWillDeleteFiles","type":"module"},{"doc":"","ref":"GenLSP.Requests.WorkspaceWillDeleteFiles.html#t:result/0","title":"GenLSP.Requests.WorkspaceWillDeleteFiles.result/0","type":"type"},{"doc":"","ref":"GenLSP.Requests.WorkspaceWillDeleteFiles.html#t:t/0","title":"GenLSP.Requests.WorkspaceWillDeleteFiles.t/0","type":"type"},{"doc":"The will rename files request is sent from the client to the server before files are actually renamed as long as the rename is triggered from within the client. @since 3.16.0 Message Direction: clientToServer","ref":"GenLSP.Requests.WorkspaceWillRenameFiles.html","title":"GenLSP.Requests.WorkspaceWillRenameFiles","type":"module"},{"doc":"","ref":"GenLSP.Requests.WorkspaceWillRenameFiles.html#t:result/0","title":"GenLSP.Requests.WorkspaceWillRenameFiles.result/0","type":"type"},{"doc":"","ref":"GenLSP.Requests.WorkspaceWillRenameFiles.html#t:t/0","title":"GenLSP.Requests.WorkspaceWillRenameFiles.t/0","type":"type"},{"doc":"The workspace/workspaceFolders is sent from the server to the client to fetch the open workspace folders. Message Direction: serverToClient","ref":"GenLSP.Requests.WorkspaceWorkspaceFolders.html","title":"GenLSP.Requests.WorkspaceWorkspaceFolders","type":"module"},{"doc":"","ref":"GenLSP.Requests.WorkspaceWorkspaceFolders.html#t:result/0","title":"GenLSP.Requests.WorkspaceWorkspaceFolders.result/0","type":"type"},{"doc":"","ref":"GenLSP.Requests.WorkspaceWorkspaceFolders.html#t:t/0","title":"GenLSP.Requests.WorkspaceWorkspaceFolders.t/0","type":"type"},{"doc":"A special text edit with an additional change annotation. @since 3.16.0.","ref":"GenLSP.Structures.AnnotatedTextEdit.html","title":"GenLSP.Structures.AnnotatedTextEdit","type":"module"},{"doc":"Fields annotation_id: The actual identifier of the change annotation range: The range of the text document to be manipulated. To insert text into a document create a range where start === end. new_text: The string to be inserted. For delete operations use an empty string.","ref":"GenLSP.Structures.AnnotatedTextEdit.html#__struct__/0","title":"GenLSP.Structures.AnnotatedTextEdit.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.AnnotatedTextEdit.html#t:t/0","title":"GenLSP.Structures.AnnotatedTextEdit.t/0","type":"type"},{"doc":"The parameters passed via an apply workspace edit request.","ref":"GenLSP.Structures.ApplyWorkspaceEditParams.html","title":"GenLSP.Structures.ApplyWorkspaceEditParams","type":"module"},{"doc":"Fields label: An optional label of the workspace edit. This label is presented in the user interface for example on an undo stack to undo the workspace edit. edit: The edits to apply.","ref":"GenLSP.Structures.ApplyWorkspaceEditParams.html#__struct__/0","title":"GenLSP.Structures.ApplyWorkspaceEditParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.ApplyWorkspaceEditParams.html#t:t/0","title":"GenLSP.Structures.ApplyWorkspaceEditParams.t/0","type":"type"},{"doc":"The result returned from the apply workspace edit request. @since 3.17 renamed from ApplyWorkspaceEditResponse","ref":"GenLSP.Structures.ApplyWorkspaceEditResult.html","title":"GenLSP.Structures.ApplyWorkspaceEditResult","type":"module"},{"doc":"Fields applied: Indicates whether the edit was applied or not. failure_reason: An optional textual description for why the edit was not applied. This may be used by the server for diagnostic logging or to provide a suitable error for a request that triggered the edit. failed_change: Depending on the client's failure handling strategy failedChange might contain the index of the change that failed. This property is only available if the client signals a failureHandlingStrategy in its client capabilities.","ref":"GenLSP.Structures.ApplyWorkspaceEditResult.html#__struct__/0","title":"GenLSP.Structures.ApplyWorkspaceEditResult.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.ApplyWorkspaceEditResult.html#t:t/0","title":"GenLSP.Structures.ApplyWorkspaceEditResult.t/0","type":"type"},{"doc":"A base for all symbol information.","ref":"GenLSP.Structures.BaseSymbolInformation.html","title":"GenLSP.Structures.BaseSymbolInformation","type":"module"},{"doc":"Fields name: The name of this symbol. kind: The kind of this symbol. tags: Tags for this symbol. @since 3.16.0 container_name: The name of the symbol containing this symbol. This information is for user interface purposes (e.g. to render a qualifier in the user interface if necessary). It can't be used to re-infer a hierarchy for the document symbols.","ref":"GenLSP.Structures.BaseSymbolInformation.html#__struct__/0","title":"GenLSP.Structures.BaseSymbolInformation.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.BaseSymbolInformation.html#t:t/0","title":"GenLSP.Structures.BaseSymbolInformation.t/0","type":"type"},{"doc":"@since 3.16.0","ref":"GenLSP.Structures.CallHierarchyClientCapabilities.html","title":"GenLSP.Structures.CallHierarchyClientCapabilities","type":"module"},{"doc":"Fields dynamic_registration: Whether implementation supports dynamic registration. If this is set to true the client supports the new (TextDocumentRegistrationOptions &amp; StaticRegistrationOptions) return value for the corresponding server capability as well.","ref":"GenLSP.Structures.CallHierarchyClientCapabilities.html#__struct__/0","title":"GenLSP.Structures.CallHierarchyClientCapabilities.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.CallHierarchyClientCapabilities.html#t:t/0","title":"GenLSP.Structures.CallHierarchyClientCapabilities.t/0","type":"type"},{"doc":"Represents an incoming call, e.g. a caller of a method or constructor. @since 3.16.0","ref":"GenLSP.Structures.CallHierarchyIncomingCall.html","title":"GenLSP.Structures.CallHierarchyIncomingCall","type":"module"},{"doc":"Fields from: The item that makes the call. from_ranges: The ranges at which the calls appear. This is relative to the caller denoted by {@link CallHierarchyIncomingCall.from this.from }.","ref":"GenLSP.Structures.CallHierarchyIncomingCall.html#__struct__/0","title":"GenLSP.Structures.CallHierarchyIncomingCall.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.CallHierarchyIncomingCall.html#t:t/0","title":"GenLSP.Structures.CallHierarchyIncomingCall.t/0","type":"type"},{"doc":"The parameter of a callHierarchy/incomingCalls request. @since 3.16.0","ref":"GenLSP.Structures.CallHierarchyIncomingCallsParams.html","title":"GenLSP.Structures.CallHierarchyIncomingCallsParams","type":"module"},{"doc":"Fields item work_done_token: An optional token that a server can use to report work done progress. partial_result_token: An optional token that a server can use to report partial results (e.g. streaming) to the client.","ref":"GenLSP.Structures.CallHierarchyIncomingCallsParams.html#__struct__/0","title":"GenLSP.Structures.CallHierarchyIncomingCallsParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.CallHierarchyIncomingCallsParams.html#t:t/0","title":"GenLSP.Structures.CallHierarchyIncomingCallsParams.t/0","type":"type"},{"doc":"Represents programming constructs like functions or constructors in the context of call hierarchy. @since 3.16.0","ref":"GenLSP.Structures.CallHierarchyItem.html","title":"GenLSP.Structures.CallHierarchyItem","type":"module"},{"doc":"Fields name: The name of this item. kind: The kind of this item. tags: Tags for this item. detail: More detail for this item, e.g. the signature of a function. uri: The resource identifier of this item. range: The range enclosing this symbol not including leading/trailing whitespace but everything else, e.g. comments and code. selection_range: The range that should be selected and revealed when this symbol is being picked, e.g. the name of a function. Must be contained by the {@link CallHierarchyItem.range range }. data: A data entry field that is preserved between a call hierarchy prepare and incoming calls or outgoing calls requests.","ref":"GenLSP.Structures.CallHierarchyItem.html#__struct__/0","title":"GenLSP.Structures.CallHierarchyItem.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.CallHierarchyItem.html#t:t/0","title":"GenLSP.Structures.CallHierarchyItem.t/0","type":"type"},{"doc":"Call hierarchy options used during static registration. @since 3.16.0","ref":"GenLSP.Structures.CallHierarchyOptions.html","title":"GenLSP.Structures.CallHierarchyOptions","type":"module"},{"doc":"Fields work_done_progress","ref":"GenLSP.Structures.CallHierarchyOptions.html#__struct__/0","title":"GenLSP.Structures.CallHierarchyOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.CallHierarchyOptions.html#t:t/0","title":"GenLSP.Structures.CallHierarchyOptions.t/0","type":"type"},{"doc":"Represents an outgoing call, e.g. calling a getter from a method or a method from a constructor etc. @since 3.16.0","ref":"GenLSP.Structures.CallHierarchyOutgoingCall.html","title":"GenLSP.Structures.CallHierarchyOutgoingCall","type":"module"},{"doc":"Fields to: The item that is called. from_ranges: The range at which this item is called. This is the range relative to the caller, e.g the item passed to {@link CallHierarchyItemProvider.provideCallHierarchyOutgoingCalls provideCallHierarchyOutgoingCalls } and not {@link CallHierarchyOutgoingCall.to this.to }.","ref":"GenLSP.Structures.CallHierarchyOutgoingCall.html#__struct__/0","title":"GenLSP.Structures.CallHierarchyOutgoingCall.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.CallHierarchyOutgoingCall.html#t:t/0","title":"GenLSP.Structures.CallHierarchyOutgoingCall.t/0","type":"type"},{"doc":"The parameter of a callHierarchy/outgoingCalls request. @since 3.16.0","ref":"GenLSP.Structures.CallHierarchyOutgoingCallsParams.html","title":"GenLSP.Structures.CallHierarchyOutgoingCallsParams","type":"module"},{"doc":"Fields item work_done_token: An optional token that a server can use to report work done progress. partial_result_token: An optional token that a server can use to report partial results (e.g. streaming) to the client.","ref":"GenLSP.Structures.CallHierarchyOutgoingCallsParams.html#__struct__/0","title":"GenLSP.Structures.CallHierarchyOutgoingCallsParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.CallHierarchyOutgoingCallsParams.html#t:t/0","title":"GenLSP.Structures.CallHierarchyOutgoingCallsParams.t/0","type":"type"},{"doc":"The parameter of a textDocument/prepareCallHierarchy request. @since 3.16.0","ref":"GenLSP.Structures.CallHierarchyPrepareParams.html","title":"GenLSP.Structures.CallHierarchyPrepareParams","type":"module"},{"doc":"Fields work_done_token: An optional token that a server can use to report work done progress. text_document: The text document. position: The position inside the text document.","ref":"GenLSP.Structures.CallHierarchyPrepareParams.html#__struct__/0","title":"GenLSP.Structures.CallHierarchyPrepareParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.CallHierarchyPrepareParams.html#t:t/0","title":"GenLSP.Structures.CallHierarchyPrepareParams.t/0","type":"type"},{"doc":"Call hierarchy options used during static or dynamic registration. @since 3.16.0","ref":"GenLSP.Structures.CallHierarchyRegistrationOptions.html","title":"GenLSP.Structures.CallHierarchyRegistrationOptions","type":"module"},{"doc":"Fields id: The id used to register the request. The id can be used to deregister the request again. See also Registration#id. document_selector: A document selector to identify the scope of the registration. If set to null the document selector provided on the client side will be used.","ref":"GenLSP.Structures.CallHierarchyRegistrationOptions.html#__struct__/0","title":"GenLSP.Structures.CallHierarchyRegistrationOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.CallHierarchyRegistrationOptions.html#t:t/0","title":"GenLSP.Structures.CallHierarchyRegistrationOptions.t/0","type":"type"},{"doc":"","ref":"GenLSP.Structures.CancelParams.html","title":"GenLSP.Structures.CancelParams","type":"module"},{"doc":"Fields id: The request id to cancel.","ref":"GenLSP.Structures.CancelParams.html#__struct__/0","title":"GenLSP.Structures.CancelParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.CancelParams.html#t:t/0","title":"GenLSP.Structures.CancelParams.t/0","type":"type"},{"doc":"Additional information that describes document changes. @since 3.16.0","ref":"GenLSP.Structures.ChangeAnnotation.html","title":"GenLSP.Structures.ChangeAnnotation","type":"module"},{"doc":"Fields label: A human-readable string describing the actual change. The string is rendered prominent in the user interface. needs_confirmation: A flag which indicates that user confirmation is needed before applying the change. description: A human-readable string which is rendered less prominent in the user interface.","ref":"GenLSP.Structures.ChangeAnnotation.html#__struct__/0","title":"GenLSP.Structures.ChangeAnnotation.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.ChangeAnnotation.html#t:t/0","title":"GenLSP.Structures.ChangeAnnotation.t/0","type":"type"},{"doc":"Defines the capabilities provided by the client.","ref":"GenLSP.Structures.ClientCapabilities.html","title":"GenLSP.Structures.ClientCapabilities","type":"module"},{"doc":"Fields workspace: Workspace specific client capabilities. text_document: Text document specific client capabilities. notebook_document: Capabilities specific to the notebook document support. @since 3.17.0 window: Window specific client capabilities. general: General client capabilities. @since 3.16.0 experimental: Experimental client capabilities.","ref":"GenLSP.Structures.ClientCapabilities.html#__struct__/0","title":"GenLSP.Structures.ClientCapabilities.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.ClientCapabilities.html#t:t/0","title":"GenLSP.Structures.ClientCapabilities.t/0","type":"type"},{"doc":"A code action represents a change that can be performed in code, e.g. to fix a problem or to refactor code. A CodeAction must set either edit and/or a command . If both are supplied, the edit is applied first, then the command is executed.","ref":"GenLSP.Structures.CodeAction.html","title":"GenLSP.Structures.CodeAction","type":"module"},{"doc":"Fields title: A short, human-readable, title for this code action. kind: The kind of the code action. Used to filter code actions. diagnostics: The diagnostics that this code action resolves. is_preferred: Marks this as a preferred action. Preferred actions are used by the auto fix command and can be targeted by keybindings. A quick fix should be marked preferred if it properly addresses the underlying error. A refactoring should be marked preferred if it is the most reasonable choice of actions to take. @since 3.15.0 disabled: Marks that the code action cannot currently be applied. Clients should follow the following guidelines regarding disabled code actions: Disabled code actions are not shown in automatic lightbulbs code action menus. Disabled actions are shown as faded out in the code action menu when the user requests a more specific type of code action, such as refactorings. If the user has a keybinding that auto applies a code action and only disabled code actions are returned, the client should show the user an error message with reason in the editor. @since 3.16.0 edit: The workspace edit this code action performs. command: A command this code action executes. If a code action provides an edit and a command, first the edit is executed and then the command. data: A data entry field that is preserved on a code action between a textDocument/codeAction and a codeAction/resolve request. @since 3.16.0","ref":"GenLSP.Structures.CodeAction.html#__struct__/0","title":"GenLSP.Structures.CodeAction.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.CodeAction.html#t:t/0","title":"GenLSP.Structures.CodeAction.t/0","type":"type"},{"doc":"The Client Capabilities of a {@link CodeActionRequest}.","ref":"GenLSP.Structures.CodeActionClientCapabilities.html","title":"GenLSP.Structures.CodeActionClientCapabilities","type":"module"},{"doc":"Fields dynamic_registration: Whether code action supports dynamic registration. code_action_literal_support: The client support code action literals of type CodeAction as a valid response of the textDocument/codeAction request. If the property is not set the request can only return Command literals. @since 3.8.0 is_preferred_support: Whether code action supports the isPreferred property. @since 3.15.0 disabled_support: Whether code action supports the disabled property. @since 3.16.0 data_support: Whether code action supports the data property which is preserved between a textDocument/codeAction and a codeAction/resolve request. @since 3.16.0 resolve_support: Whether the client supports resolving additional code action properties via a separate codeAction/resolve request. @since 3.16.0 honors_change_annotations: Whether the client honors the change annotations in text edits and resource operations returned via the CodeAction#edit property by for example presenting the workspace edit in the user interface and asking for confirmation. @since 3.16.0","ref":"GenLSP.Structures.CodeActionClientCapabilities.html#__struct__/0","title":"GenLSP.Structures.CodeActionClientCapabilities.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.CodeActionClientCapabilities.html#t:t/0","title":"GenLSP.Structures.CodeActionClientCapabilities.t/0","type":"type"},{"doc":"Contains additional diagnostic information about the context in which a {@link CodeActionProvider.provideCodeActions code action} is run.","ref":"GenLSP.Structures.CodeActionContext.html","title":"GenLSP.Structures.CodeActionContext","type":"module"},{"doc":"Fields diagnostics: An array of diagnostics known on the client side overlapping the range provided to the textDocument/codeAction request. They are provided so that the server knows which errors are currently presented to the user for the given range. There is no guarantee that these accurately reflect the error state of the resource. The primary parameter to compute code actions is the provided range. only: Requested kind of actions to return. Actions not of this kind are filtered out by the client before being shown. So servers can omit computing them. trigger_kind: The reason why code actions were requested. @since 3.17.0","ref":"GenLSP.Structures.CodeActionContext.html#__struct__/0","title":"GenLSP.Structures.CodeActionContext.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.CodeActionContext.html#t:t/0","title":"GenLSP.Structures.CodeActionContext.t/0","type":"type"},{"doc":"Provider options for a {@link CodeActionRequest}.","ref":"GenLSP.Structures.CodeActionOptions.html","title":"GenLSP.Structures.CodeActionOptions","type":"module"},{"doc":"Fields code_action_kinds: CodeActionKinds that this server may return. The list of kinds may be generic, such as CodeActionKind.Refactor , or the server may list out every specific kind they provide. resolve_provider: The server provides support to resolve additional information for a code action. @since 3.16.0 work_done_progress","ref":"GenLSP.Structures.CodeActionOptions.html#__struct__/0","title":"GenLSP.Structures.CodeActionOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.CodeActionOptions.html#t:t/0","title":"GenLSP.Structures.CodeActionOptions.t/0","type":"type"},{"doc":"The parameters of a {@link CodeActionRequest}.","ref":"GenLSP.Structures.CodeActionParams.html","title":"GenLSP.Structures.CodeActionParams","type":"module"},{"doc":"Fields text_document: The document in which the command was invoked. range: The range for which the command was invoked. context: Context carrying additional information. work_done_token: An optional token that a server can use to report work done progress. partial_result_token: An optional token that a server can use to report partial results (e.g. streaming) to the client.","ref":"GenLSP.Structures.CodeActionParams.html#__struct__/0","title":"GenLSP.Structures.CodeActionParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.CodeActionParams.html#t:t/0","title":"GenLSP.Structures.CodeActionParams.t/0","type":"type"},{"doc":"Registration options for a {@link CodeActionRequest}.","ref":"GenLSP.Structures.CodeActionRegistrationOptions.html","title":"GenLSP.Structures.CodeActionRegistrationOptions","type":"module"},{"doc":"Fields document_selector: A document selector to identify the scope of the registration. If set to null the document selector provided on the client side will be used. code_action_kinds: CodeActionKinds that this server may return. The list of kinds may be generic, such as CodeActionKind.Refactor , or the server may list out every specific kind they provide. resolve_provider: The server provides support to resolve additional information for a code action. @since 3.16.0","ref":"GenLSP.Structures.CodeActionRegistrationOptions.html#__struct__/0","title":"GenLSP.Structures.CodeActionRegistrationOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.CodeActionRegistrationOptions.html#t:t/0","title":"GenLSP.Structures.CodeActionRegistrationOptions.t/0","type":"type"},{"doc":"Structure to capture a description for an error code. @since 3.16.0","ref":"GenLSP.Structures.CodeDescription.html","title":"GenLSP.Structures.CodeDescription","type":"module"},{"doc":"Fields href: An URI to open with more information about the diagnostic error.","ref":"GenLSP.Structures.CodeDescription.html#__struct__/0","title":"GenLSP.Structures.CodeDescription.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.CodeDescription.html#t:t/0","title":"GenLSP.Structures.CodeDescription.t/0","type":"type"},{"doc":"A code lens represents a {@link Command command} that should be shown along with source text, like the number of references, a way to run tests, etc. A code lens is unresolved when no command is associated to it. For performance reasons the creation of a code lens and resolving should be done in two stages.","ref":"GenLSP.Structures.CodeLens.html","title":"GenLSP.Structures.CodeLens","type":"module"},{"doc":"Fields range: The range in which this code lens is valid. Should only span a single line. command: The command this code lens represents. data: A data entry field that is preserved on a code lens item between a {@link CodeLensRequest} and a [CodeLensResolveRequest] (#CodeLensResolveRequest)","ref":"GenLSP.Structures.CodeLens.html#__struct__/0","title":"GenLSP.Structures.CodeLens.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.CodeLens.html#t:t/0","title":"GenLSP.Structures.CodeLens.t/0","type":"type"},{"doc":"The client capabilities of a {@link CodeLensRequest}.","ref":"GenLSP.Structures.CodeLensClientCapabilities.html","title":"GenLSP.Structures.CodeLensClientCapabilities","type":"module"},{"doc":"Fields dynamic_registration: Whether code lens supports dynamic registration.","ref":"GenLSP.Structures.CodeLensClientCapabilities.html#__struct__/0","title":"GenLSP.Structures.CodeLensClientCapabilities.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.CodeLensClientCapabilities.html#t:t/0","title":"GenLSP.Structures.CodeLensClientCapabilities.t/0","type":"type"},{"doc":"Code Lens provider options of a {@link CodeLensRequest}.","ref":"GenLSP.Structures.CodeLensOptions.html","title":"GenLSP.Structures.CodeLensOptions","type":"module"},{"doc":"Fields resolve_provider: Code lens has a resolve provider as well. work_done_progress","ref":"GenLSP.Structures.CodeLensOptions.html#__struct__/0","title":"GenLSP.Structures.CodeLensOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.CodeLensOptions.html#t:t/0","title":"GenLSP.Structures.CodeLensOptions.t/0","type":"type"},{"doc":"The parameters of a {@link CodeLensRequest}.","ref":"GenLSP.Structures.CodeLensParams.html","title":"GenLSP.Structures.CodeLensParams","type":"module"},{"doc":"Fields text_document: The document to request code lens for. work_done_token: An optional token that a server can use to report work done progress. partial_result_token: An optional token that a server can use to report partial results (e.g. streaming) to the client.","ref":"GenLSP.Structures.CodeLensParams.html#__struct__/0","title":"GenLSP.Structures.CodeLensParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.CodeLensParams.html#t:t/0","title":"GenLSP.Structures.CodeLensParams.t/0","type":"type"},{"doc":"Registration options for a {@link CodeLensRequest}.","ref":"GenLSP.Structures.CodeLensRegistrationOptions.html","title":"GenLSP.Structures.CodeLensRegistrationOptions","type":"module"},{"doc":"Fields document_selector: A document selector to identify the scope of the registration. If set to null the document selector provided on the client side will be used. resolve_provider: Code lens has a resolve provider as well.","ref":"GenLSP.Structures.CodeLensRegistrationOptions.html#__struct__/0","title":"GenLSP.Structures.CodeLensRegistrationOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.CodeLensRegistrationOptions.html#t:t/0","title":"GenLSP.Structures.CodeLensRegistrationOptions.t/0","type":"type"},{"doc":"@since 3.16.0","ref":"GenLSP.Structures.CodeLensWorkspaceClientCapabilities.html","title":"GenLSP.Structures.CodeLensWorkspaceClientCapabilities","type":"module"},{"doc":"Fields refresh_support: Whether the client implementation supports a refresh request sent from the server to the client. Note that this event is global and will force the client to refresh all code lenses currently shown. It should be used with absolute care and is useful for situation where a server for example detect a project wide change that requires such a calculation.","ref":"GenLSP.Structures.CodeLensWorkspaceClientCapabilities.html#__struct__/0","title":"GenLSP.Structures.CodeLensWorkspaceClientCapabilities.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.CodeLensWorkspaceClientCapabilities.html#t:t/0","title":"GenLSP.Structures.CodeLensWorkspaceClientCapabilities.t/0","type":"type"},{"doc":"Represents a color in RGBA space.","ref":"GenLSP.Structures.Color.html","title":"GenLSP.Structures.Color","type":"module"},{"doc":"Fields red: The red component of this color in the range [0-1]. green: The green component of this color in the range [0-1]. blue: The blue component of this color in the range [0-1]. alpha: The alpha component of this color in the range [0-1].","ref":"GenLSP.Structures.Color.html#__struct__/0","title":"GenLSP.Structures.Color.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.Color.html#t:t/0","title":"GenLSP.Structures.Color.t/0","type":"type"},{"doc":"Represents a color range from a document.","ref":"GenLSP.Structures.ColorInformation.html","title":"GenLSP.Structures.ColorInformation","type":"module"},{"doc":"Fields range: The range in the document where this color appears. color: The actual color value for this color range.","ref":"GenLSP.Structures.ColorInformation.html#__struct__/0","title":"GenLSP.Structures.ColorInformation.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.ColorInformation.html#t:t/0","title":"GenLSP.Structures.ColorInformation.t/0","type":"type"},{"doc":"","ref":"GenLSP.Structures.ColorPresentation.html","title":"GenLSP.Structures.ColorPresentation","type":"module"},{"doc":"Fields label: The label of this color presentation. It will be shown on the color picker header. By default this is also the text that is inserted when selecting this color presentation. text_edit: An {@link TextEdit edit} which is applied to a document when selecting this presentation for the color. When falsy the {@link ColorPresentation.label label} is used. additional_text_edits: An optional array of additional {@link TextEdit text edits} that are applied when selecting this color presentation. Edits must not overlap with the main {@link ColorPresentation.textEdit edit} nor with themselves.","ref":"GenLSP.Structures.ColorPresentation.html#__struct__/0","title":"GenLSP.Structures.ColorPresentation.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.ColorPresentation.html#t:t/0","title":"GenLSP.Structures.ColorPresentation.t/0","type":"type"},{"doc":"Parameters for a {@link ColorPresentationRequest}.","ref":"GenLSP.Structures.ColorPresentationParams.html","title":"GenLSP.Structures.ColorPresentationParams","type":"module"},{"doc":"Fields text_document: The text document. color: The color to request presentations for. range: The range where the color would be inserted. Serves as a context. work_done_token: An optional token that a server can use to report work done progress. partial_result_token: An optional token that a server can use to report partial results (e.g. streaming) to the client.","ref":"GenLSP.Structures.ColorPresentationParams.html#__struct__/0","title":"GenLSP.Structures.ColorPresentationParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.ColorPresentationParams.html#t:t/0","title":"GenLSP.Structures.ColorPresentationParams.t/0","type":"type"},{"doc":"Represents a reference to a command. Provides a title which will be used to represent a command in the UI and, optionally, an array of arguments which will be passed to the command handler function when invoked.","ref":"GenLSP.Structures.Command.html","title":"GenLSP.Structures.Command","type":"module"},{"doc":"Fields title: Title of the command, like save . command: The identifier of the actual command handler. arguments: Arguments that the command handler should be invoked with.","ref":"GenLSP.Structures.Command.html#__struct__/0","title":"GenLSP.Structures.Command.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.Command.html#t:t/0","title":"GenLSP.Structures.Command.t/0","type":"type"},{"doc":"Completion client capabilities","ref":"GenLSP.Structures.CompletionClientCapabilities.html","title":"GenLSP.Structures.CompletionClientCapabilities","type":"module"},{"doc":"Fields dynamic_registration: Whether completion supports dynamic registration. completion_item: The client supports the following CompletionItem specific capabilities. completion_item_kind insert_text_mode: Defines how the client handles whitespace and indentation when accepting a completion item that uses multi line text in either insertText or textEdit . @since 3.17.0 context_support: The client supports to send additional context information for a textDocument/completion request. completion_list: The client supports the following CompletionList specific capabilities. @since 3.17.0","ref":"GenLSP.Structures.CompletionClientCapabilities.html#__struct__/0","title":"GenLSP.Structures.CompletionClientCapabilities.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.CompletionClientCapabilities.html#t:t/0","title":"GenLSP.Structures.CompletionClientCapabilities.t/0","type":"type"},{"doc":"Contains additional information about the context in which a completion request is triggered.","ref":"GenLSP.Structures.CompletionContext.html","title":"GenLSP.Structures.CompletionContext","type":"module"},{"doc":"Fields trigger_kind: How the completion was triggered. trigger_character: The trigger character (a single character) that has trigger code complete. Is undefined if triggerKind !== CompletionTriggerKind.TriggerCharacter","ref":"GenLSP.Structures.CompletionContext.html#__struct__/0","title":"GenLSP.Structures.CompletionContext.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.CompletionContext.html#t:t/0","title":"GenLSP.Structures.CompletionContext.t/0","type":"type"},{"doc":"A completion item represents a text snippet that is proposed to complete text that is being typed.","ref":"GenLSP.Structures.CompletionItem.html","title":"GenLSP.Structures.CompletionItem","type":"module"},{"doc":"Fields label: The label of this completion item. The label property is also by default the text that is inserted when selecting this completion. If label details are provided the label itself should be an unqualified name of the completion item. label_details: Additional details for the label @since 3.17.0 kind: The kind of this completion item. Based of the kind an icon is chosen by the editor. tags: Tags for this completion item. @since 3.15.0 detail: A human-readable string with additional information about this item, like type or symbol information. documentation: A human-readable string that represents a doc-comment. deprecated: Indicates if this item is deprecated. @deprecated Use tags instead. preselect: Select this item when showing. Note that only one completion item can be selected and that the tool / client decides which item that is. The rule is that the first item of those that match best is selected. sort_text: A string that should be used when comparing this item with other items. When falsy the {@link CompletionItem.label label} is used. filter_text: A string that should be used when filtering a set of completion items. When falsy the {@link CompletionItem.label label} is used. insert_text: A string that should be inserted into a document when selecting this completion. When falsy the {@link CompletionItem.label label} is used. The insertText is subject to interpretation by the client side. Some tools might not take the string literally. For example VS Code when code complete is requested in this example con&lt;cursor position&gt; and a completion item with an insertText of console is provided it will only insert sole . Therefore it is recommended to use textEdit instead since it avoids additional client side interpretation. insert_text_format: The format of the insert text. The format applies to both the insertText property and the newText property of a provided textEdit . If omitted defaults to InsertTextFormat.PlainText . Please note that the insertTextFormat doesn't apply to additionalTextEdits . insert_text_mode: How whitespace and indentation is handled during completion item insertion. If not provided the clients default value depends on the textDocument.completion.insertTextMode client capability. @since 3.16.0 text_edit: An {@link TextEdit edit} which is applied to a document when selecting this completion. When an edit is provided the value of {@link CompletionItem.insertText insertText} is ignored. Most editors support two different operations when accepting a completion item. One is to insert a completion text and the other is to replace an existing text with a completion text. Since this can usually not be predetermined by a server it can report both ranges. Clients need to signal support for InsertReplaceEdits via the textDocument.completion.insertReplaceSupport client capability property. Note 1: The text edit's range as well as both ranges from an insert replace edit must be a [single line] and they must contain the position at which completion has been requested. Note 2: If an InsertReplaceEdit is returned the edit's insert range must be a prefix of the edit's replace range, that means it must be contained and starting at the same position. @since 3.16.0 additional type InsertReplaceEdit text_edit_text: The edit text used if the completion item is part of a CompletionList and CompletionList defines an item default for the text edit range. Clients will only honor this property if they opt into completion list item defaults using the capability completionList.itemDefaults . If not provided and a list's default range is provided the label property is used as a text. @since 3.17.0 additional_text_edits: An optional array of additional {@link TextEdit text edits} that are applied when selecting this completion. Edits must not overlap (including the same insert position) with the main {@link CompletionItem.textEdit edit} nor with themselves. Additional text edits should be used to change text unrelated to the current cursor position (for example adding an import statement at the top of the file if the completion item will insert an unqualified type). commit_characters: An optional set of characters that when pressed while this completion is active will accept it first and then type that character. Note that all commit characters should have length=1 and that superfluous characters will be ignored. command: An optional {@link Command command} that is executed after inserting this completion. Note that additional modifications to the current document should be described with the {@link CompletionItem.additionalTextEdits additionalTextEdits}-property. data: A data entry field that is preserved on a completion item between a {@link CompletionRequest} and a {@link CompletionResolveRequest}.","ref":"GenLSP.Structures.CompletionItem.html#__struct__/0","title":"GenLSP.Structures.CompletionItem.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.CompletionItem.html#t:t/0","title":"GenLSP.Structures.CompletionItem.t/0","type":"type"},{"doc":"Additional details for a completion item label. @since 3.17.0","ref":"GenLSP.Structures.CompletionItemLabelDetails.html","title":"GenLSP.Structures.CompletionItemLabelDetails","type":"module"},{"doc":"Fields detail: An optional string which is rendered less prominently directly after {@link CompletionItem.label label}, without any spacing. Should be used for function signatures and type annotations. description: An optional string which is rendered less prominently after {@link CompletionItem.detail}. Should be used for fully qualified names and file paths.","ref":"GenLSP.Structures.CompletionItemLabelDetails.html#__struct__/0","title":"GenLSP.Structures.CompletionItemLabelDetails.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.CompletionItemLabelDetails.html#t:t/0","title":"GenLSP.Structures.CompletionItemLabelDetails.t/0","type":"type"},{"doc":"Represents a collection of {@link CompletionItem completion items} to be presented in the editor.","ref":"GenLSP.Structures.CompletionList.html","title":"GenLSP.Structures.CompletionList","type":"module"},{"doc":"Fields is_incomplete: This list it not complete. Further typing results in recomputing this list. Recomputed lists have all their items replaced (not appended) in the incomplete completion sessions. item_defaults: In many cases the items of an actual completion result share the same value for properties like commitCharacters or the range of a text edit. A completion list can therefore define item defaults which will be used if a completion item itself doesn't specify the value. If a completion list specifies a default value and a completion item also specifies a corresponding value the one from the item is used. Servers are only allowed to return default values if the client signals support for this via the completionList.itemDefaults capability. @since 3.17.0 items: The completion items.","ref":"GenLSP.Structures.CompletionList.html#__struct__/0","title":"GenLSP.Structures.CompletionList.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.CompletionList.html#t:t/0","title":"GenLSP.Structures.CompletionList.t/0","type":"type"},{"doc":"Completion options.","ref":"GenLSP.Structures.CompletionOptions.html","title":"GenLSP.Structures.CompletionOptions","type":"module"},{"doc":"Fields trigger_characters: Most tools trigger completion request automatically without explicitly requesting it using a keyboard shortcut (e.g. Ctrl+Space). Typically they do so when the user starts to type an identifier. For example if the user types c in a JavaScript file code complete will automatically pop up present console besides others as a completion item. Characters that make up identifiers don't need to be listed here. If code complete should automatically be trigger on characters not being valid inside an identifier (for example . in JavaScript) list them in triggerCharacters . all_commit_characters: The list of all possible characters that commit a completion. This field can be used if clients don't support individual commit characters per completion item. See ClientCapabilities.textDocument.completion.completionItem.commitCharactersSupport If a server provides both allCommitCharacters and commit characters on an individual completion item the ones on the completion item win. @since 3.2.0 resolve_provider: The server provides support to resolve additional information for a completion item. completion_item: The server supports the following CompletionItem specific capabilities. @since 3.17.0 work_done_progress","ref":"GenLSP.Structures.CompletionOptions.html#__struct__/0","title":"GenLSP.Structures.CompletionOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.CompletionOptions.html#t:t/0","title":"GenLSP.Structures.CompletionOptions.t/0","type":"type"},{"doc":"Completion parameters","ref":"GenLSP.Structures.CompletionParams.html","title":"GenLSP.Structures.CompletionParams","type":"module"},{"doc":"Fields context: The completion context. This is only available it the client specifies to send this using the client capability textDocument.completion.contextSupport === true work_done_token: An optional token that a server can use to report work done progress. partial_result_token: An optional token that a server can use to report partial results (e.g. streaming) to the client. text_document: The text document. position: The position inside the text document.","ref":"GenLSP.Structures.CompletionParams.html#__struct__/0","title":"GenLSP.Structures.CompletionParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.CompletionParams.html#t:t/0","title":"GenLSP.Structures.CompletionParams.t/0","type":"type"},{"doc":"Registration options for a {@link CompletionRequest}.","ref":"GenLSP.Structures.CompletionRegistrationOptions.html","title":"GenLSP.Structures.CompletionRegistrationOptions","type":"module"},{"doc":"Fields document_selector: A document selector to identify the scope of the registration. If set to null the document selector provided on the client side will be used. trigger_characters: Most tools trigger completion request automatically without explicitly requesting it using a keyboard shortcut (e.g. Ctrl+Space). Typically they do so when the user starts to type an identifier. For example if the user types c in a JavaScript file code complete will automatically pop up present console besides others as a completion item. Characters that make up identifiers don't need to be listed here. If code complete should automatically be trigger on characters not being valid inside an identifier (for example . in JavaScript) list them in triggerCharacters . all_commit_characters: The list of all possible characters that commit a completion. This field can be used if clients don't support individual commit characters per completion item. See ClientCapabilities.textDocument.completion.completionItem.commitCharactersSupport If a server provides both allCommitCharacters and commit characters on an individual completion item the ones on the completion item win. @since 3.2.0 resolve_provider: The server provides support to resolve additional information for a completion item. completion_item: The server supports the following CompletionItem specific capabilities. @since 3.17.0","ref":"GenLSP.Structures.CompletionRegistrationOptions.html#__struct__/0","title":"GenLSP.Structures.CompletionRegistrationOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.CompletionRegistrationOptions.html#t:t/0","title":"GenLSP.Structures.CompletionRegistrationOptions.t/0","type":"type"},{"doc":"","ref":"GenLSP.Structures.ConfigurationItem.html","title":"GenLSP.Structures.ConfigurationItem","type":"module"},{"doc":"Fields scope_uri: The scope to get the configuration section for. section: The configuration section asked for.","ref":"GenLSP.Structures.ConfigurationItem.html#__struct__/0","title":"GenLSP.Structures.ConfigurationItem.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.ConfigurationItem.html#t:t/0","title":"GenLSP.Structures.ConfigurationItem.t/0","type":"type"},{"doc":"The parameters of a configuration request.","ref":"GenLSP.Structures.ConfigurationParams.html","title":"GenLSP.Structures.ConfigurationParams","type":"module"},{"doc":"Fields items","ref":"GenLSP.Structures.ConfigurationParams.html#__struct__/0","title":"GenLSP.Structures.ConfigurationParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.ConfigurationParams.html#t:t/0","title":"GenLSP.Structures.ConfigurationParams.t/0","type":"type"},{"doc":"Create file operation.","ref":"GenLSP.Structures.CreateFile.html","title":"GenLSP.Structures.CreateFile","type":"module"},{"doc":"Fields kind: A create uri: The resource to create. options: Additional options annotation_id: An optional annotation identifier describing the operation. @since 3.16.0","ref":"GenLSP.Structures.CreateFile.html#__struct__/0","title":"GenLSP.Structures.CreateFile.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.CreateFile.html#t:t/0","title":"GenLSP.Structures.CreateFile.t/0","type":"type"},{"doc":"Options to create a file.","ref":"GenLSP.Structures.CreateFileOptions.html","title":"GenLSP.Structures.CreateFileOptions","type":"module"},{"doc":"Fields overwrite: Overwrite existing file. Overwrite wins over ignoreIfExists ignore_if_exists: Ignore if exists.","ref":"GenLSP.Structures.CreateFileOptions.html#__struct__/0","title":"GenLSP.Structures.CreateFileOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.CreateFileOptions.html#t:t/0","title":"GenLSP.Structures.CreateFileOptions.t/0","type":"type"},{"doc":"The parameters sent in notifications/requests for user-initiated creation of files. @since 3.16.0","ref":"GenLSP.Structures.CreateFilesParams.html","title":"GenLSP.Structures.CreateFilesParams","type":"module"},{"doc":"Fields files: An array of all files/folders created in this operation.","ref":"GenLSP.Structures.CreateFilesParams.html#__struct__/0","title":"GenLSP.Structures.CreateFilesParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.CreateFilesParams.html#t:t/0","title":"GenLSP.Structures.CreateFilesParams.t/0","type":"type"},{"doc":"@since 3.14.0","ref":"GenLSP.Structures.DeclarationClientCapabilities.html","title":"GenLSP.Structures.DeclarationClientCapabilities","type":"module"},{"doc":"Fields dynamic_registration: Whether declaration supports dynamic registration. If this is set to true the client supports the new DeclarationRegistrationOptions return value for the corresponding server capability as well. link_support: The client supports additional metadata in the form of declaration links.","ref":"GenLSP.Structures.DeclarationClientCapabilities.html#__struct__/0","title":"GenLSP.Structures.DeclarationClientCapabilities.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.DeclarationClientCapabilities.html#t:t/0","title":"GenLSP.Structures.DeclarationClientCapabilities.t/0","type":"type"},{"doc":"","ref":"GenLSP.Structures.DeclarationOptions.html","title":"GenLSP.Structures.DeclarationOptions","type":"module"},{"doc":"Fields work_done_progress","ref":"GenLSP.Structures.DeclarationOptions.html#__struct__/0","title":"GenLSP.Structures.DeclarationOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.DeclarationOptions.html#t:t/0","title":"GenLSP.Structures.DeclarationOptions.t/0","type":"type"},{"doc":"","ref":"GenLSP.Structures.DeclarationParams.html","title":"GenLSP.Structures.DeclarationParams","type":"module"},{"doc":"Fields work_done_token: An optional token that a server can use to report work done progress. partial_result_token: An optional token that a server can use to report partial results (e.g. streaming) to the client. text_document: The text document. position: The position inside the text document.","ref":"GenLSP.Structures.DeclarationParams.html#__struct__/0","title":"GenLSP.Structures.DeclarationParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.DeclarationParams.html#t:t/0","title":"GenLSP.Structures.DeclarationParams.t/0","type":"type"},{"doc":"","ref":"GenLSP.Structures.DeclarationRegistrationOptions.html","title":"GenLSP.Structures.DeclarationRegistrationOptions","type":"module"},{"doc":"Fields id: The id used to register the request. The id can be used to deregister the request again. See also Registration#id. document_selector: A document selector to identify the scope of the registration. If set to null the document selector provided on the client side will be used.","ref":"GenLSP.Structures.DeclarationRegistrationOptions.html#__struct__/0","title":"GenLSP.Structures.DeclarationRegistrationOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.DeclarationRegistrationOptions.html#t:t/0","title":"GenLSP.Structures.DeclarationRegistrationOptions.t/0","type":"type"},{"doc":"Client Capabilities for a {@link DefinitionRequest}.","ref":"GenLSP.Structures.DefinitionClientCapabilities.html","title":"GenLSP.Structures.DefinitionClientCapabilities","type":"module"},{"doc":"Fields dynamic_registration: Whether definition supports dynamic registration. link_support: The client supports additional metadata in the form of definition links. @since 3.14.0","ref":"GenLSP.Structures.DefinitionClientCapabilities.html#__struct__/0","title":"GenLSP.Structures.DefinitionClientCapabilities.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.DefinitionClientCapabilities.html#t:t/0","title":"GenLSP.Structures.DefinitionClientCapabilities.t/0","type":"type"},{"doc":"Server Capabilities for a {@link DefinitionRequest}.","ref":"GenLSP.Structures.DefinitionOptions.html","title":"GenLSP.Structures.DefinitionOptions","type":"module"},{"doc":"Fields work_done_progress","ref":"GenLSP.Structures.DefinitionOptions.html#__struct__/0","title":"GenLSP.Structures.DefinitionOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.DefinitionOptions.html#t:t/0","title":"GenLSP.Structures.DefinitionOptions.t/0","type":"type"},{"doc":"Parameters for a {@link DefinitionRequest}.","ref":"GenLSP.Structures.DefinitionParams.html","title":"GenLSP.Structures.DefinitionParams","type":"module"},{"doc":"Fields work_done_token: An optional token that a server can use to report work done progress. partial_result_token: An optional token that a server can use to report partial results (e.g. streaming) to the client. text_document: The text document. position: The position inside the text document.","ref":"GenLSP.Structures.DefinitionParams.html#__struct__/0","title":"GenLSP.Structures.DefinitionParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.DefinitionParams.html#t:t/0","title":"GenLSP.Structures.DefinitionParams.t/0","type":"type"},{"doc":"Registration options for a {@link DefinitionRequest}.","ref":"GenLSP.Structures.DefinitionRegistrationOptions.html","title":"GenLSP.Structures.DefinitionRegistrationOptions","type":"module"},{"doc":"Fields document_selector: A document selector to identify the scope of the registration. If set to null the document selector provided on the client side will be used.","ref":"GenLSP.Structures.DefinitionRegistrationOptions.html#__struct__/0","title":"GenLSP.Structures.DefinitionRegistrationOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.DefinitionRegistrationOptions.html#t:t/0","title":"GenLSP.Structures.DefinitionRegistrationOptions.t/0","type":"type"},{"doc":"Delete file operation","ref":"GenLSP.Structures.DeleteFile.html","title":"GenLSP.Structures.DeleteFile","type":"module"},{"doc":"Fields kind: A delete uri: The file to delete. options: Delete options. annotation_id: An optional annotation identifier describing the operation. @since 3.16.0","ref":"GenLSP.Structures.DeleteFile.html#__struct__/0","title":"GenLSP.Structures.DeleteFile.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.DeleteFile.html#t:t/0","title":"GenLSP.Structures.DeleteFile.t/0","type":"type"},{"doc":"Delete file options","ref":"GenLSP.Structures.DeleteFileOptions.html","title":"GenLSP.Structures.DeleteFileOptions","type":"module"},{"doc":"Fields recursive: Delete the content recursively if a folder is denoted. ignore_if_not_exists: Ignore the operation if the file doesn't exist.","ref":"GenLSP.Structures.DeleteFileOptions.html#__struct__/0","title":"GenLSP.Structures.DeleteFileOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.DeleteFileOptions.html#t:t/0","title":"GenLSP.Structures.DeleteFileOptions.t/0","type":"type"},{"doc":"The parameters sent in notifications/requests for user-initiated deletes of files. @since 3.16.0","ref":"GenLSP.Structures.DeleteFilesParams.html","title":"GenLSP.Structures.DeleteFilesParams","type":"module"},{"doc":"Fields files: An array of all files/folders deleted in this operation.","ref":"GenLSP.Structures.DeleteFilesParams.html#__struct__/0","title":"GenLSP.Structures.DeleteFilesParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.DeleteFilesParams.html#t:t/0","title":"GenLSP.Structures.DeleteFilesParams.t/0","type":"type"},{"doc":"Represents a diagnostic, such as a compiler error or warning. Diagnostic objects are only valid in the scope of a resource.","ref":"GenLSP.Structures.Diagnostic.html","title":"GenLSP.Structures.Diagnostic","type":"module"},{"doc":"Fields range: The range at which the message applies severity: The diagnostic's severity. Can be omitted. If omitted it is up to the client to interpret diagnostics as error, warning, info or hint. code: The diagnostic's code, which usually appear in the user interface. code_description: An optional property to describe the error code. Requires the code field (above) to be present/not null. @since 3.16.0 source: A human-readable string describing the source of this diagnostic, e.g. 'typescript' or 'super lint'. It usually appears in the user interface. message: The diagnostic's message. It usually appears in the user interface tags: Additional metadata about the diagnostic. @since 3.15.0 related_information: An array of related diagnostic information, e.g. when symbol-names within a scope collide all definitions can be marked via this property. data: A data entry field that is preserved between a textDocument/publishDiagnostics notification and textDocument/codeAction request. @since 3.16.0","ref":"GenLSP.Structures.Diagnostic.html#__struct__/0","title":"GenLSP.Structures.Diagnostic.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.Diagnostic.html#t:t/0","title":"GenLSP.Structures.Diagnostic.t/0","type":"type"},{"doc":"Client capabilities specific to diagnostic pull requests. @since 3.17.0","ref":"GenLSP.Structures.DiagnosticClientCapabilities.html","title":"GenLSP.Structures.DiagnosticClientCapabilities","type":"module"},{"doc":"Fields dynamic_registration: Whether implementation supports dynamic registration. If this is set to true the client supports the new (TextDocumentRegistrationOptions &amp; StaticRegistrationOptions) return value for the corresponding server capability as well. related_document_support: Whether the clients supports related documents for document diagnostic pulls.","ref":"GenLSP.Structures.DiagnosticClientCapabilities.html#__struct__/0","title":"GenLSP.Structures.DiagnosticClientCapabilities.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.DiagnosticClientCapabilities.html#t:t/0","title":"GenLSP.Structures.DiagnosticClientCapabilities.t/0","type":"type"},{"doc":"Diagnostic options. @since 3.17.0","ref":"GenLSP.Structures.DiagnosticOptions.html","title":"GenLSP.Structures.DiagnosticOptions","type":"module"},{"doc":"Fields identifier: An optional identifier under which the diagnostics are managed by the client. inter_file_dependencies: Whether the language has inter file dependencies meaning that editing code in one file can result in a different diagnostic set in another file. Inter file dependencies are common for most programming languages and typically uncommon for linters. workspace_diagnostics: The server provides support for workspace diagnostics as well. work_done_progress","ref":"GenLSP.Structures.DiagnosticOptions.html#__struct__/0","title":"GenLSP.Structures.DiagnosticOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.DiagnosticOptions.html#t:t/0","title":"GenLSP.Structures.DiagnosticOptions.t/0","type":"type"},{"doc":"Diagnostic registration options. @since 3.17.0","ref":"GenLSP.Structures.DiagnosticRegistrationOptions.html","title":"GenLSP.Structures.DiagnosticRegistrationOptions","type":"module"},{"doc":"Fields id: The id used to register the request. The id can be used to deregister the request again. See also Registration#id. document_selector: A document selector to identify the scope of the registration. If set to null the document selector provided on the client side will be used. identifier: An optional identifier under which the diagnostics are managed by the client. inter_file_dependencies: Whether the language has inter file dependencies meaning that editing code in one file can result in a different diagnostic set in another file. Inter file dependencies are common for most programming languages and typically uncommon for linters. workspace_diagnostics: The server provides support for workspace diagnostics as well.","ref":"GenLSP.Structures.DiagnosticRegistrationOptions.html#__struct__/0","title":"GenLSP.Structures.DiagnosticRegistrationOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.DiagnosticRegistrationOptions.html#t:t/0","title":"GenLSP.Structures.DiagnosticRegistrationOptions.t/0","type":"type"},{"doc":"Represents a related message and source code location for a diagnostic. This should be used to point to code locations that cause or related to a diagnostics, e.g when duplicating a symbol in a scope.","ref":"GenLSP.Structures.DiagnosticRelatedInformation.html","title":"GenLSP.Structures.DiagnosticRelatedInformation","type":"module"},{"doc":"Fields location: The location of this related diagnostic information. message: The message of this related diagnostic information.","ref":"GenLSP.Structures.DiagnosticRelatedInformation.html#__struct__/0","title":"GenLSP.Structures.DiagnosticRelatedInformation.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.DiagnosticRelatedInformation.html#t:t/0","title":"GenLSP.Structures.DiagnosticRelatedInformation.t/0","type":"type"},{"doc":"Cancellation data returned from a diagnostic request. @since 3.17.0","ref":"GenLSP.Structures.DiagnosticServerCancellationData.html","title":"GenLSP.Structures.DiagnosticServerCancellationData","type":"module"},{"doc":"Fields retrigger_request","ref":"GenLSP.Structures.DiagnosticServerCancellationData.html#__struct__/0","title":"GenLSP.Structures.DiagnosticServerCancellationData.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.DiagnosticServerCancellationData.html#t:t/0","title":"GenLSP.Structures.DiagnosticServerCancellationData.t/0","type":"type"},{"doc":"Workspace client capabilities specific to diagnostic pull requests. @since 3.17.0","ref":"GenLSP.Structures.DiagnosticWorkspaceClientCapabilities.html","title":"GenLSP.Structures.DiagnosticWorkspaceClientCapabilities","type":"module"},{"doc":"Fields refresh_support: Whether the client implementation supports a refresh request sent from the server to the client. Note that this event is global and will force the client to refresh all pulled diagnostics currently shown. It should be used with absolute care and is useful for situation where a server for example detects a project wide change that requires such a calculation.","ref":"GenLSP.Structures.DiagnosticWorkspaceClientCapabilities.html#__struct__/0","title":"GenLSP.Structures.DiagnosticWorkspaceClientCapabilities.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.DiagnosticWorkspaceClientCapabilities.html#t:t/0","title":"GenLSP.Structures.DiagnosticWorkspaceClientCapabilities.t/0","type":"type"},{"doc":"","ref":"GenLSP.Structures.DidChangeConfigurationClientCapabilities.html","title":"GenLSP.Structures.DidChangeConfigurationClientCapabilities","type":"module"},{"doc":"Fields dynamic_registration: Did change configuration notification supports dynamic registration.","ref":"GenLSP.Structures.DidChangeConfigurationClientCapabilities.html#__struct__/0","title":"GenLSP.Structures.DidChangeConfigurationClientCapabilities.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.DidChangeConfigurationClientCapabilities.html#t:t/0","title":"GenLSP.Structures.DidChangeConfigurationClientCapabilities.t/0","type":"type"},{"doc":"The parameters of a change configuration notification.","ref":"GenLSP.Structures.DidChangeConfigurationParams.html","title":"GenLSP.Structures.DidChangeConfigurationParams","type":"module"},{"doc":"Fields settings: The actual changed settings","ref":"GenLSP.Structures.DidChangeConfigurationParams.html#__struct__/0","title":"GenLSP.Structures.DidChangeConfigurationParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.DidChangeConfigurationParams.html#t:t/0","title":"GenLSP.Structures.DidChangeConfigurationParams.t/0","type":"type"},{"doc":"","ref":"GenLSP.Structures.DidChangeConfigurationRegistrationOptions.html","title":"GenLSP.Structures.DidChangeConfigurationRegistrationOptions","type":"module"},{"doc":"Fields section","ref":"GenLSP.Structures.DidChangeConfigurationRegistrationOptions.html#__struct__/0","title":"GenLSP.Structures.DidChangeConfigurationRegistrationOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.DidChangeConfigurationRegistrationOptions.html#t:t/0","title":"GenLSP.Structures.DidChangeConfigurationRegistrationOptions.t/0","type":"type"},{"doc":"The params sent in a change notebook document notification. @since 3.17.0","ref":"GenLSP.Structures.DidChangeNotebookDocumentParams.html","title":"GenLSP.Structures.DidChangeNotebookDocumentParams","type":"module"},{"doc":"Fields notebook_document: The notebook document that did change. The version number points to the version after all provided changes have been applied. If only the text document content of a cell changes the notebook version doesn't necessarily have to change. change: The actual changes to the notebook document.The changes describe single state changes to the notebook document. So if there are two changes c1 (at array index 0) and c2 (at array index 1) for a notebook in state S then c1 moves the notebook from S to S' and c2 from S' to S''. So c1 is computed on the state S and c2 is computed on the state S'.To mirror the content of a notebook using change events use the following approach: start with the same initial content apply the 'notebookDocument/didChange' notifications in the order you receive them. apply the NotebookChangeEvent s in a single notification in the order you receive them.","ref":"GenLSP.Structures.DidChangeNotebookDocumentParams.html#__struct__/0","title":"GenLSP.Structures.DidChangeNotebookDocumentParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.DidChangeNotebookDocumentParams.html#t:t/0","title":"GenLSP.Structures.DidChangeNotebookDocumentParams.t/0","type":"type"},{"doc":"The change text document notification's parameters.","ref":"GenLSP.Structures.DidChangeTextDocumentParams.html","title":"GenLSP.Structures.DidChangeTextDocumentParams","type":"module"},{"doc":"Fields text_document: The document that did change. The version number points to the version after all provided content changes have been applied. content_changes: The actual content changes. The content changes describe single state changes to the document. So if there are two content changes c1 (at array index 0) and c2 (at array index 1) for a document in state S then c1 moves the document from S to S' and c2 from S' to S''. So c1 is computed on the state S and c2 is computed on the state S'.To mirror the content of a document using change events use the following approach: start with the same initial content apply the 'textDocument/didChange' notifications in the order you receive them. apply the TextDocumentContentChangeEvent s in a single notification in the order you receive them.","ref":"GenLSP.Structures.DidChangeTextDocumentParams.html#__struct__/0","title":"GenLSP.Structures.DidChangeTextDocumentParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.DidChangeTextDocumentParams.html#t:t/0","title":"GenLSP.Structures.DidChangeTextDocumentParams.t/0","type":"type"},{"doc":"","ref":"GenLSP.Structures.DidChangeWatchedFilesClientCapabilities.html","title":"GenLSP.Structures.DidChangeWatchedFilesClientCapabilities","type":"module"},{"doc":"Fields dynamic_registration: Did change watched files notification supports dynamic registration. Please note that the current protocol doesn't support static configuration for file changes from the server side. relative_pattern_support: Whether the client has support for {@link RelativePattern relative pattern} or not. @since 3.17.0","ref":"GenLSP.Structures.DidChangeWatchedFilesClientCapabilities.html#__struct__/0","title":"GenLSP.Structures.DidChangeWatchedFilesClientCapabilities.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.DidChangeWatchedFilesClientCapabilities.html#t:t/0","title":"GenLSP.Structures.DidChangeWatchedFilesClientCapabilities.t/0","type":"type"},{"doc":"The watched files change notification's parameters.","ref":"GenLSP.Structures.DidChangeWatchedFilesParams.html","title":"GenLSP.Structures.DidChangeWatchedFilesParams","type":"module"},{"doc":"Fields changes: The actual file events.","ref":"GenLSP.Structures.DidChangeWatchedFilesParams.html#__struct__/0","title":"GenLSP.Structures.DidChangeWatchedFilesParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.DidChangeWatchedFilesParams.html#t:t/0","title":"GenLSP.Structures.DidChangeWatchedFilesParams.t/0","type":"type"},{"doc":"Describe options to be used when registered for text document change events.","ref":"GenLSP.Structures.DidChangeWatchedFilesRegistrationOptions.html","title":"GenLSP.Structures.DidChangeWatchedFilesRegistrationOptions","type":"module"},{"doc":"Fields watchers: The watchers to register.","ref":"GenLSP.Structures.DidChangeWatchedFilesRegistrationOptions.html#__struct__/0","title":"GenLSP.Structures.DidChangeWatchedFilesRegistrationOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.DidChangeWatchedFilesRegistrationOptions.html#t:t/0","title":"GenLSP.Structures.DidChangeWatchedFilesRegistrationOptions.t/0","type":"type"},{"doc":"The parameters of a workspace/didChangeWorkspaceFolders notification.","ref":"GenLSP.Structures.DidChangeWorkspaceFoldersParams.html","title":"GenLSP.Structures.DidChangeWorkspaceFoldersParams","type":"module"},{"doc":"Fields event: The actual workspace folder change event.","ref":"GenLSP.Structures.DidChangeWorkspaceFoldersParams.html#__struct__/0","title":"GenLSP.Structures.DidChangeWorkspaceFoldersParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.DidChangeWorkspaceFoldersParams.html#t:t/0","title":"GenLSP.Structures.DidChangeWorkspaceFoldersParams.t/0","type":"type"},{"doc":"The params sent in a close notebook document notification. @since 3.17.0","ref":"GenLSP.Structures.DidCloseNotebookDocumentParams.html","title":"GenLSP.Structures.DidCloseNotebookDocumentParams","type":"module"},{"doc":"Fields notebook_document: The notebook document that got closed. cell_text_documents: The text documents that represent the content of a notebook cell that got closed.","ref":"GenLSP.Structures.DidCloseNotebookDocumentParams.html#__struct__/0","title":"GenLSP.Structures.DidCloseNotebookDocumentParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.DidCloseNotebookDocumentParams.html#t:t/0","title":"GenLSP.Structures.DidCloseNotebookDocumentParams.t/0","type":"type"},{"doc":"The parameters sent in a close text document notification","ref":"GenLSP.Structures.DidCloseTextDocumentParams.html","title":"GenLSP.Structures.DidCloseTextDocumentParams","type":"module"},{"doc":"Fields text_document: The document that was closed.","ref":"GenLSP.Structures.DidCloseTextDocumentParams.html#__struct__/0","title":"GenLSP.Structures.DidCloseTextDocumentParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.DidCloseTextDocumentParams.html#t:t/0","title":"GenLSP.Structures.DidCloseTextDocumentParams.t/0","type":"type"},{"doc":"The params sent in an open notebook document notification. @since 3.17.0","ref":"GenLSP.Structures.DidOpenNotebookDocumentParams.html","title":"GenLSP.Structures.DidOpenNotebookDocumentParams","type":"module"},{"doc":"Fields notebook_document: The notebook document that got opened. cell_text_documents: The text documents that represent the content of a notebook cell.","ref":"GenLSP.Structures.DidOpenNotebookDocumentParams.html#__struct__/0","title":"GenLSP.Structures.DidOpenNotebookDocumentParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.DidOpenNotebookDocumentParams.html#t:t/0","title":"GenLSP.Structures.DidOpenNotebookDocumentParams.t/0","type":"type"},{"doc":"The parameters sent in an open text document notification","ref":"GenLSP.Structures.DidOpenTextDocumentParams.html","title":"GenLSP.Structures.DidOpenTextDocumentParams","type":"module"},{"doc":"Fields text_document: The document that was opened.","ref":"GenLSP.Structures.DidOpenTextDocumentParams.html#__struct__/0","title":"GenLSP.Structures.DidOpenTextDocumentParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.DidOpenTextDocumentParams.html#t:t/0","title":"GenLSP.Structures.DidOpenTextDocumentParams.t/0","type":"type"},{"doc":"The params sent in a save notebook document notification. @since 3.17.0","ref":"GenLSP.Structures.DidSaveNotebookDocumentParams.html","title":"GenLSP.Structures.DidSaveNotebookDocumentParams","type":"module"},{"doc":"Fields notebook_document: The notebook document that got saved.","ref":"GenLSP.Structures.DidSaveNotebookDocumentParams.html#__struct__/0","title":"GenLSP.Structures.DidSaveNotebookDocumentParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.DidSaveNotebookDocumentParams.html#t:t/0","title":"GenLSP.Structures.DidSaveNotebookDocumentParams.t/0","type":"type"},{"doc":"The parameters sent in a save text document notification","ref":"GenLSP.Structures.DidSaveTextDocumentParams.html","title":"GenLSP.Structures.DidSaveTextDocumentParams","type":"module"},{"doc":"Fields text_document: The document that was saved. text: Optional the content when saved. Depends on the includeText value when the save notification was requested.","ref":"GenLSP.Structures.DidSaveTextDocumentParams.html#__struct__/0","title":"GenLSP.Structures.DidSaveTextDocumentParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.DidSaveTextDocumentParams.html#t:t/0","title":"GenLSP.Structures.DidSaveTextDocumentParams.t/0","type":"type"},{"doc":"","ref":"GenLSP.Structures.DocumentColorClientCapabilities.html","title":"GenLSP.Structures.DocumentColorClientCapabilities","type":"module"},{"doc":"Fields dynamic_registration: Whether implementation supports dynamic registration. If this is set to true the client supports the new DocumentColorRegistrationOptions return value for the corresponding server capability as well.","ref":"GenLSP.Structures.DocumentColorClientCapabilities.html#__struct__/0","title":"GenLSP.Structures.DocumentColorClientCapabilities.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.DocumentColorClientCapabilities.html#t:t/0","title":"GenLSP.Structures.DocumentColorClientCapabilities.t/0","type":"type"},{"doc":"","ref":"GenLSP.Structures.DocumentColorOptions.html","title":"GenLSP.Structures.DocumentColorOptions","type":"module"},{"doc":"Fields work_done_progress","ref":"GenLSP.Structures.DocumentColorOptions.html#__struct__/0","title":"GenLSP.Structures.DocumentColorOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.DocumentColorOptions.html#t:t/0","title":"GenLSP.Structures.DocumentColorOptions.t/0","type":"type"},{"doc":"Parameters for a {@link DocumentColorRequest}.","ref":"GenLSP.Structures.DocumentColorParams.html","title":"GenLSP.Structures.DocumentColorParams","type":"module"},{"doc":"Fields text_document: The text document. work_done_token: An optional token that a server can use to report work done progress. partial_result_token: An optional token that a server can use to report partial results (e.g. streaming) to the client.","ref":"GenLSP.Structures.DocumentColorParams.html#__struct__/0","title":"GenLSP.Structures.DocumentColorParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.DocumentColorParams.html#t:t/0","title":"GenLSP.Structures.DocumentColorParams.t/0","type":"type"},{"doc":"","ref":"GenLSP.Structures.DocumentColorRegistrationOptions.html","title":"GenLSP.Structures.DocumentColorRegistrationOptions","type":"module"},{"doc":"Fields id: The id used to register the request. The id can be used to deregister the request again. See also Registration#id. document_selector: A document selector to identify the scope of the registration. If set to null the document selector provided on the client side will be used.","ref":"GenLSP.Structures.DocumentColorRegistrationOptions.html#__struct__/0","title":"GenLSP.Structures.DocumentColorRegistrationOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.DocumentColorRegistrationOptions.html#t:t/0","title":"GenLSP.Structures.DocumentColorRegistrationOptions.t/0","type":"type"},{"doc":"Parameters of the document diagnostic request. @since 3.17.0","ref":"GenLSP.Structures.DocumentDiagnosticParams.html","title":"GenLSP.Structures.DocumentDiagnosticParams","type":"module"},{"doc":"Fields text_document: The text document. identifier: The additional identifier provided during registration. previous_result_id: The result id of a previous response if provided. work_done_token: An optional token that a server can use to report work done progress. partial_result_token: An optional token that a server can use to report partial results (e.g. streaming) to the client.","ref":"GenLSP.Structures.DocumentDiagnosticParams.html#__struct__/0","title":"GenLSP.Structures.DocumentDiagnosticParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.DocumentDiagnosticParams.html#t:t/0","title":"GenLSP.Structures.DocumentDiagnosticParams.t/0","type":"type"},{"doc":"A partial result for a document diagnostic report. @since 3.17.0","ref":"GenLSP.Structures.DocumentDiagnosticReportPartialResult.html","title":"GenLSP.Structures.DocumentDiagnosticReportPartialResult","type":"module"},{"doc":"Fields related_documents","ref":"GenLSP.Structures.DocumentDiagnosticReportPartialResult.html#__struct__/0","title":"GenLSP.Structures.DocumentDiagnosticReportPartialResult.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.DocumentDiagnosticReportPartialResult.html#t:t/0","title":"GenLSP.Structures.DocumentDiagnosticReportPartialResult.t/0","type":"type"},{"doc":"Client capabilities of a {@link DocumentFormattingRequest}.","ref":"GenLSP.Structures.DocumentFormattingClientCapabilities.html","title":"GenLSP.Structures.DocumentFormattingClientCapabilities","type":"module"},{"doc":"Fields dynamic_registration: Whether formatting supports dynamic registration.","ref":"GenLSP.Structures.DocumentFormattingClientCapabilities.html#__struct__/0","title":"GenLSP.Structures.DocumentFormattingClientCapabilities.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.DocumentFormattingClientCapabilities.html#t:t/0","title":"GenLSP.Structures.DocumentFormattingClientCapabilities.t/0","type":"type"},{"doc":"Provider options for a {@link DocumentFormattingRequest}.","ref":"GenLSP.Structures.DocumentFormattingOptions.html","title":"GenLSP.Structures.DocumentFormattingOptions","type":"module"},{"doc":"Fields work_done_progress","ref":"GenLSP.Structures.DocumentFormattingOptions.html#__struct__/0","title":"GenLSP.Structures.DocumentFormattingOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.DocumentFormattingOptions.html#t:t/0","title":"GenLSP.Structures.DocumentFormattingOptions.t/0","type":"type"},{"doc":"The parameters of a {@link DocumentFormattingRequest}.","ref":"GenLSP.Structures.DocumentFormattingParams.html","title":"GenLSP.Structures.DocumentFormattingParams","type":"module"},{"doc":"Fields text_document: The document to format. options: The format options. work_done_token: An optional token that a server can use to report work done progress.","ref":"GenLSP.Structures.DocumentFormattingParams.html#__struct__/0","title":"GenLSP.Structures.DocumentFormattingParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.DocumentFormattingParams.html#t:t/0","title":"GenLSP.Structures.DocumentFormattingParams.t/0","type":"type"},{"doc":"Registration options for a {@link DocumentFormattingRequest}.","ref":"GenLSP.Structures.DocumentFormattingRegistrationOptions.html","title":"GenLSP.Structures.DocumentFormattingRegistrationOptions","type":"module"},{"doc":"Fields document_selector: A document selector to identify the scope of the registration. If set to null the document selector provided on the client side will be used.","ref":"GenLSP.Structures.DocumentFormattingRegistrationOptions.html#__struct__/0","title":"GenLSP.Structures.DocumentFormattingRegistrationOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.DocumentFormattingRegistrationOptions.html#t:t/0","title":"GenLSP.Structures.DocumentFormattingRegistrationOptions.t/0","type":"type"},{"doc":"A document highlight is a range inside a text document which deserves special attention. Usually a document highlight is visualized by changing the background color of its range.","ref":"GenLSP.Structures.DocumentHighlight.html","title":"GenLSP.Structures.DocumentHighlight","type":"module"},{"doc":"Fields range: The range this highlight applies to. kind: The highlight kind, default is {@link DocumentHighlightKind.Text text}.","ref":"GenLSP.Structures.DocumentHighlight.html#__struct__/0","title":"GenLSP.Structures.DocumentHighlight.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.DocumentHighlight.html#t:t/0","title":"GenLSP.Structures.DocumentHighlight.t/0","type":"type"},{"doc":"Client Capabilities for a {@link DocumentHighlightRequest}.","ref":"GenLSP.Structures.DocumentHighlightClientCapabilities.html","title":"GenLSP.Structures.DocumentHighlightClientCapabilities","type":"module"},{"doc":"Fields dynamic_registration: Whether document highlight supports dynamic registration.","ref":"GenLSP.Structures.DocumentHighlightClientCapabilities.html#__struct__/0","title":"GenLSP.Structures.DocumentHighlightClientCapabilities.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.DocumentHighlightClientCapabilities.html#t:t/0","title":"GenLSP.Structures.DocumentHighlightClientCapabilities.t/0","type":"type"},{"doc":"Provider options for a {@link DocumentHighlightRequest}.","ref":"GenLSP.Structures.DocumentHighlightOptions.html","title":"GenLSP.Structures.DocumentHighlightOptions","type":"module"},{"doc":"Fields work_done_progress","ref":"GenLSP.Structures.DocumentHighlightOptions.html#__struct__/0","title":"GenLSP.Structures.DocumentHighlightOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.DocumentHighlightOptions.html#t:t/0","title":"GenLSP.Structures.DocumentHighlightOptions.t/0","type":"type"},{"doc":"Parameters for a {@link DocumentHighlightRequest}.","ref":"GenLSP.Structures.DocumentHighlightParams.html","title":"GenLSP.Structures.DocumentHighlightParams","type":"module"},{"doc":"Fields work_done_token: An optional token that a server can use to report work done progress. partial_result_token: An optional token that a server can use to report partial results (e.g. streaming) to the client. text_document: The text document. position: The position inside the text document.","ref":"GenLSP.Structures.DocumentHighlightParams.html#__struct__/0","title":"GenLSP.Structures.DocumentHighlightParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.DocumentHighlightParams.html#t:t/0","title":"GenLSP.Structures.DocumentHighlightParams.t/0","type":"type"},{"doc":"Registration options for a {@link DocumentHighlightRequest}.","ref":"GenLSP.Structures.DocumentHighlightRegistrationOptions.html","title":"GenLSP.Structures.DocumentHighlightRegistrationOptions","type":"module"},{"doc":"Fields document_selector: A document selector to identify the scope of the registration. If set to null the document selector provided on the client side will be used.","ref":"GenLSP.Structures.DocumentHighlightRegistrationOptions.html#__struct__/0","title":"GenLSP.Structures.DocumentHighlightRegistrationOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.DocumentHighlightRegistrationOptions.html#t:t/0","title":"GenLSP.Structures.DocumentHighlightRegistrationOptions.t/0","type":"type"},{"doc":"A document link is a range in a text document that links to an internal or external resource, like another text document or a web site.","ref":"GenLSP.Structures.DocumentLink.html","title":"GenLSP.Structures.DocumentLink","type":"module"},{"doc":"Fields range: The range this link applies to. target: The uri this link points to. If missing a resolve request is sent later. tooltip: The tooltip text when you hover over this link. If a tooltip is provided, is will be displayed in a string that includes instructions on how to trigger the link, such as {0} (ctrl + click) . The specific instructions vary depending on OS, user settings, and localization. @since 3.15.0 data: A data entry field that is preserved on a document link between a DocumentLinkRequest and a DocumentLinkResolveRequest.","ref":"GenLSP.Structures.DocumentLink.html#__struct__/0","title":"GenLSP.Structures.DocumentLink.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.DocumentLink.html#t:t/0","title":"GenLSP.Structures.DocumentLink.t/0","type":"type"},{"doc":"The client capabilities of a {@link DocumentLinkRequest}.","ref":"GenLSP.Structures.DocumentLinkClientCapabilities.html","title":"GenLSP.Structures.DocumentLinkClientCapabilities","type":"module"},{"doc":"Fields dynamic_registration: Whether document link supports dynamic registration. tooltip_support: Whether the client supports the tooltip property on DocumentLink . @since 3.15.0","ref":"GenLSP.Structures.DocumentLinkClientCapabilities.html#__struct__/0","title":"GenLSP.Structures.DocumentLinkClientCapabilities.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.DocumentLinkClientCapabilities.html#t:t/0","title":"GenLSP.Structures.DocumentLinkClientCapabilities.t/0","type":"type"},{"doc":"Provider options for a {@link DocumentLinkRequest}.","ref":"GenLSP.Structures.DocumentLinkOptions.html","title":"GenLSP.Structures.DocumentLinkOptions","type":"module"},{"doc":"Fields resolve_provider: Document links have a resolve provider as well. work_done_progress","ref":"GenLSP.Structures.DocumentLinkOptions.html#__struct__/0","title":"GenLSP.Structures.DocumentLinkOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.DocumentLinkOptions.html#t:t/0","title":"GenLSP.Structures.DocumentLinkOptions.t/0","type":"type"},{"doc":"The parameters of a {@link DocumentLinkRequest}.","ref":"GenLSP.Structures.DocumentLinkParams.html","title":"GenLSP.Structures.DocumentLinkParams","type":"module"},{"doc":"Fields text_document: The document to provide document links for. work_done_token: An optional token that a server can use to report work done progress. partial_result_token: An optional token that a server can use to report partial results (e.g. streaming) to the client.","ref":"GenLSP.Structures.DocumentLinkParams.html#__struct__/0","title":"GenLSP.Structures.DocumentLinkParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.DocumentLinkParams.html#t:t/0","title":"GenLSP.Structures.DocumentLinkParams.t/0","type":"type"},{"doc":"Registration options for a {@link DocumentLinkRequest}.","ref":"GenLSP.Structures.DocumentLinkRegistrationOptions.html","title":"GenLSP.Structures.DocumentLinkRegistrationOptions","type":"module"},{"doc":"Fields document_selector: A document selector to identify the scope of the registration. If set to null the document selector provided on the client side will be used. resolve_provider: Document links have a resolve provider as well.","ref":"GenLSP.Structures.DocumentLinkRegistrationOptions.html#__struct__/0","title":"GenLSP.Structures.DocumentLinkRegistrationOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.DocumentLinkRegistrationOptions.html#t:t/0","title":"GenLSP.Structures.DocumentLinkRegistrationOptions.t/0","type":"type"},{"doc":"Client capabilities of a {@link DocumentOnTypeFormattingRequest}.","ref":"GenLSP.Structures.DocumentOnTypeFormattingClientCapabilities.html","title":"GenLSP.Structures.DocumentOnTypeFormattingClientCapabilities","type":"module"},{"doc":"Fields dynamic_registration: Whether on type formatting supports dynamic registration.","ref":"GenLSP.Structures.DocumentOnTypeFormattingClientCapabilities.html#__struct__/0","title":"GenLSP.Structures.DocumentOnTypeFormattingClientCapabilities.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.DocumentOnTypeFormattingClientCapabilities.html#t:t/0","title":"GenLSP.Structures.DocumentOnTypeFormattingClientCapabilities.t/0","type":"type"},{"doc":"Provider options for a {@link DocumentOnTypeFormattingRequest}.","ref":"GenLSP.Structures.DocumentOnTypeFormattingOptions.html","title":"GenLSP.Structures.DocumentOnTypeFormattingOptions","type":"module"},{"doc":"Fields first_trigger_character: A character on which formatting should be triggered, like { . more_trigger_character: More trigger characters.","ref":"GenLSP.Structures.DocumentOnTypeFormattingOptions.html#__struct__/0","title":"GenLSP.Structures.DocumentOnTypeFormattingOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.DocumentOnTypeFormattingOptions.html#t:t/0","title":"GenLSP.Structures.DocumentOnTypeFormattingOptions.t/0","type":"type"},{"doc":"The parameters of a {@link DocumentOnTypeFormattingRequest}.","ref":"GenLSP.Structures.DocumentOnTypeFormattingParams.html","title":"GenLSP.Structures.DocumentOnTypeFormattingParams","type":"module"},{"doc":"Fields text_document: The document to format. position: The position around which the on type formatting should happen. This is not necessarily the exact position where the character denoted by the property ch got typed. ch: The character that has been typed that triggered the formatting on type request. That is not necessarily the last character that got inserted into the document since the client could auto insert characters as well (e.g. like automatic brace completion). options: The formatting options.","ref":"GenLSP.Structures.DocumentOnTypeFormattingParams.html#__struct__/0","title":"GenLSP.Structures.DocumentOnTypeFormattingParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.DocumentOnTypeFormattingParams.html#t:t/0","title":"GenLSP.Structures.DocumentOnTypeFormattingParams.t/0","type":"type"},{"doc":"Registration options for a {@link DocumentOnTypeFormattingRequest}.","ref":"GenLSP.Structures.DocumentOnTypeFormattingRegistrationOptions.html","title":"GenLSP.Structures.DocumentOnTypeFormattingRegistrationOptions","type":"module"},{"doc":"Fields document_selector: A document selector to identify the scope of the registration. If set to null the document selector provided on the client side will be used. first_trigger_character: A character on which formatting should be triggered, like { . more_trigger_character: More trigger characters.","ref":"GenLSP.Structures.DocumentOnTypeFormattingRegistrationOptions.html#__struct__/0","title":"GenLSP.Structures.DocumentOnTypeFormattingRegistrationOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.DocumentOnTypeFormattingRegistrationOptions.html#t:t/0","title":"GenLSP.Structures.DocumentOnTypeFormattingRegistrationOptions.t/0","type":"type"},{"doc":"Client capabilities of a {@link DocumentRangeFormattingRequest}.","ref":"GenLSP.Structures.DocumentRangeFormattingClientCapabilities.html","title":"GenLSP.Structures.DocumentRangeFormattingClientCapabilities","type":"module"},{"doc":"Fields dynamic_registration: Whether range formatting supports dynamic registration.","ref":"GenLSP.Structures.DocumentRangeFormattingClientCapabilities.html#__struct__/0","title":"GenLSP.Structures.DocumentRangeFormattingClientCapabilities.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.DocumentRangeFormattingClientCapabilities.html#t:t/0","title":"GenLSP.Structures.DocumentRangeFormattingClientCapabilities.t/0","type":"type"},{"doc":"Provider options for a {@link DocumentRangeFormattingRequest}.","ref":"GenLSP.Structures.DocumentRangeFormattingOptions.html","title":"GenLSP.Structures.DocumentRangeFormattingOptions","type":"module"},{"doc":"Fields work_done_progress","ref":"GenLSP.Structures.DocumentRangeFormattingOptions.html#__struct__/0","title":"GenLSP.Structures.DocumentRangeFormattingOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.DocumentRangeFormattingOptions.html#t:t/0","title":"GenLSP.Structures.DocumentRangeFormattingOptions.t/0","type":"type"},{"doc":"The parameters of a {@link DocumentRangeFormattingRequest}.","ref":"GenLSP.Structures.DocumentRangeFormattingParams.html","title":"GenLSP.Structures.DocumentRangeFormattingParams","type":"module"},{"doc":"Fields text_document: The document to format. range: The range to format options: The format options work_done_token: An optional token that a server can use to report work done progress.","ref":"GenLSP.Structures.DocumentRangeFormattingParams.html#__struct__/0","title":"GenLSP.Structures.DocumentRangeFormattingParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.DocumentRangeFormattingParams.html#t:t/0","title":"GenLSP.Structures.DocumentRangeFormattingParams.t/0","type":"type"},{"doc":"Registration options for a {@link DocumentRangeFormattingRequest}.","ref":"GenLSP.Structures.DocumentRangeFormattingRegistrationOptions.html","title":"GenLSP.Structures.DocumentRangeFormattingRegistrationOptions","type":"module"},{"doc":"Fields document_selector: A document selector to identify the scope of the registration. If set to null the document selector provided on the client side will be used.","ref":"GenLSP.Structures.DocumentRangeFormattingRegistrationOptions.html#__struct__/0","title":"GenLSP.Structures.DocumentRangeFormattingRegistrationOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.DocumentRangeFormattingRegistrationOptions.html#t:t/0","title":"GenLSP.Structures.DocumentRangeFormattingRegistrationOptions.t/0","type":"type"},{"doc":"Represents programming constructs like variables, classes, interfaces etc. that appear in a document. Document symbols can be hierarchical and they have two ranges: one that encloses its definition and one that points to its most interesting range, e.g. the range of an identifier.","ref":"GenLSP.Structures.DocumentSymbol.html","title":"GenLSP.Structures.DocumentSymbol","type":"module"},{"doc":"Fields name: The name of this symbol. Will be displayed in the user interface and therefore must not be an empty string or a string only consisting of white spaces. detail: More detail for this symbol, e.g the signature of a function. kind: The kind of this symbol. tags: Tags for this document symbol. @since 3.16.0 deprecated: Indicates if this symbol is deprecated. @deprecated Use tags instead range: The range enclosing this symbol not including leading/trailing whitespace but everything else like comments. This information is typically used to determine if the clients cursor is inside the symbol to reveal in the symbol in the UI. selection_range: The range that should be selected and revealed when this symbol is being picked, e.g the name of a function. Must be contained by the range . children: Children of this symbol, e.g. properties of a class.","ref":"GenLSP.Structures.DocumentSymbol.html#__struct__/0","title":"GenLSP.Structures.DocumentSymbol.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.DocumentSymbol.html#t:t/0","title":"GenLSP.Structures.DocumentSymbol.t/0","type":"type"},{"doc":"Client Capabilities for a {@link DocumentSymbolRequest}.","ref":"GenLSP.Structures.DocumentSymbolClientCapabilities.html","title":"GenLSP.Structures.DocumentSymbolClientCapabilities","type":"module"},{"doc":"Fields dynamic_registration: Whether document symbol supports dynamic registration. symbol_kind: Specific capabilities for the SymbolKind in the textDocument/documentSymbol request. hierarchical_document_symbol_support: The client supports hierarchical document symbols. tag_support: The client supports tags on SymbolInformation . Tags are supported on DocumentSymbol if hierarchicalDocumentSymbolSupport is set to true. Clients supporting tags have to handle unknown tags gracefully. @since 3.16.0 label_support: The client supports an additional label presented in the UI when registering a document symbol provider. @since 3.16.0","ref":"GenLSP.Structures.DocumentSymbolClientCapabilities.html#__struct__/0","title":"GenLSP.Structures.DocumentSymbolClientCapabilities.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.DocumentSymbolClientCapabilities.html#t:t/0","title":"GenLSP.Structures.DocumentSymbolClientCapabilities.t/0","type":"type"},{"doc":"Provider options for a {@link DocumentSymbolRequest}.","ref":"GenLSP.Structures.DocumentSymbolOptions.html","title":"GenLSP.Structures.DocumentSymbolOptions","type":"module"},{"doc":"Fields label: A human-readable string that is shown when multiple outlines trees are shown for the same document. @since 3.16.0 work_done_progress","ref":"GenLSP.Structures.DocumentSymbolOptions.html#__struct__/0","title":"GenLSP.Structures.DocumentSymbolOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.DocumentSymbolOptions.html#t:t/0","title":"GenLSP.Structures.DocumentSymbolOptions.t/0","type":"type"},{"doc":"Parameters for a {@link DocumentSymbolRequest}.","ref":"GenLSP.Structures.DocumentSymbolParams.html","title":"GenLSP.Structures.DocumentSymbolParams","type":"module"},{"doc":"Fields text_document: The text document. work_done_token: An optional token that a server can use to report work done progress. partial_result_token: An optional token that a server can use to report partial results (e.g. streaming) to the client.","ref":"GenLSP.Structures.DocumentSymbolParams.html#__struct__/0","title":"GenLSP.Structures.DocumentSymbolParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.DocumentSymbolParams.html#t:t/0","title":"GenLSP.Structures.DocumentSymbolParams.t/0","type":"type"},{"doc":"Registration options for a {@link DocumentSymbolRequest}.","ref":"GenLSP.Structures.DocumentSymbolRegistrationOptions.html","title":"GenLSP.Structures.DocumentSymbolRegistrationOptions","type":"module"},{"doc":"Fields document_selector: A document selector to identify the scope of the registration. If set to null the document selector provided on the client side will be used. label: A human-readable string that is shown when multiple outlines trees are shown for the same document. @since 3.16.0","ref":"GenLSP.Structures.DocumentSymbolRegistrationOptions.html#__struct__/0","title":"GenLSP.Structures.DocumentSymbolRegistrationOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.DocumentSymbolRegistrationOptions.html#t:t/0","title":"GenLSP.Structures.DocumentSymbolRegistrationOptions.t/0","type":"type"},{"doc":"The client capabilities of a {@link ExecuteCommandRequest}.","ref":"GenLSP.Structures.ExecuteCommandClientCapabilities.html","title":"GenLSP.Structures.ExecuteCommandClientCapabilities","type":"module"},{"doc":"Fields dynamic_registration: Execute command supports dynamic registration.","ref":"GenLSP.Structures.ExecuteCommandClientCapabilities.html#__struct__/0","title":"GenLSP.Structures.ExecuteCommandClientCapabilities.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.ExecuteCommandClientCapabilities.html#t:t/0","title":"GenLSP.Structures.ExecuteCommandClientCapabilities.t/0","type":"type"},{"doc":"The server capabilities of a {@link ExecuteCommandRequest}.","ref":"GenLSP.Structures.ExecuteCommandOptions.html","title":"GenLSP.Structures.ExecuteCommandOptions","type":"module"},{"doc":"Fields commands: The commands to be executed on the server work_done_progress","ref":"GenLSP.Structures.ExecuteCommandOptions.html#__struct__/0","title":"GenLSP.Structures.ExecuteCommandOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.ExecuteCommandOptions.html#t:t/0","title":"GenLSP.Structures.ExecuteCommandOptions.t/0","type":"type"},{"doc":"The parameters of a {@link ExecuteCommandRequest}.","ref":"GenLSP.Structures.ExecuteCommandParams.html","title":"GenLSP.Structures.ExecuteCommandParams","type":"module"},{"doc":"Fields command: The identifier of the actual command handler. arguments: Arguments that the command should be invoked with. work_done_token: An optional token that a server can use to report work done progress.","ref":"GenLSP.Structures.ExecuteCommandParams.html#__struct__/0","title":"GenLSP.Structures.ExecuteCommandParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.ExecuteCommandParams.html#t:t/0","title":"GenLSP.Structures.ExecuteCommandParams.t/0","type":"type"},{"doc":"Registration options for a {@link ExecuteCommandRequest}.","ref":"GenLSP.Structures.ExecuteCommandRegistrationOptions.html","title":"GenLSP.Structures.ExecuteCommandRegistrationOptions","type":"module"},{"doc":"Fields commands: The commands to be executed on the server","ref":"GenLSP.Structures.ExecuteCommandRegistrationOptions.html#__struct__/0","title":"GenLSP.Structures.ExecuteCommandRegistrationOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.ExecuteCommandRegistrationOptions.html#t:t/0","title":"GenLSP.Structures.ExecuteCommandRegistrationOptions.t/0","type":"type"},{"doc":"","ref":"GenLSP.Structures.ExecutionSummary.html","title":"GenLSP.Structures.ExecutionSummary","type":"module"},{"doc":"Fields execution_order: A strict monotonically increasing value indicating the execution order of a cell inside a notebook. success: Whether the execution was successful or not if known by the client.","ref":"GenLSP.Structures.ExecutionSummary.html#__struct__/0","title":"GenLSP.Structures.ExecutionSummary.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.ExecutionSummary.html#t:t/0","title":"GenLSP.Structures.ExecutionSummary.t/0","type":"type"},{"doc":"Represents information on a file/folder create. @since 3.16.0","ref":"GenLSP.Structures.FileCreate.html","title":"GenLSP.Structures.FileCreate","type":"module"},{"doc":"Fields uri: A file:// URI for the location of the file/folder being created.","ref":"GenLSP.Structures.FileCreate.html#__struct__/0","title":"GenLSP.Structures.FileCreate.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.FileCreate.html#t:t/0","title":"GenLSP.Structures.FileCreate.t/0","type":"type"},{"doc":"Represents information on a file/folder delete. @since 3.16.0","ref":"GenLSP.Structures.FileDelete.html","title":"GenLSP.Structures.FileDelete","type":"module"},{"doc":"Fields uri: A file:// URI for the location of the file/folder being deleted.","ref":"GenLSP.Structures.FileDelete.html#__struct__/0","title":"GenLSP.Structures.FileDelete.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.FileDelete.html#t:t/0","title":"GenLSP.Structures.FileDelete.t/0","type":"type"},{"doc":"An event describing a file change.","ref":"GenLSP.Structures.FileEvent.html","title":"GenLSP.Structures.FileEvent","type":"module"},{"doc":"Fields uri: The file's uri. type: The change type.","ref":"GenLSP.Structures.FileEvent.html#__struct__/0","title":"GenLSP.Structures.FileEvent.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.FileEvent.html#t:t/0","title":"GenLSP.Structures.FileEvent.t/0","type":"type"},{"doc":"Capabilities relating to events from file operations by the user in the client. These events do not come from the file system, they come from user operations like renaming a file in the UI. @since 3.16.0","ref":"GenLSP.Structures.FileOperationClientCapabilities.html","title":"GenLSP.Structures.FileOperationClientCapabilities","type":"module"},{"doc":"Fields dynamic_registration: Whether the client supports dynamic registration for file requests/notifications. did_create: The client has support for sending didCreateFiles notifications. will_create: The client has support for sending willCreateFiles requests. did_rename: The client has support for sending didRenameFiles notifications. will_rename: The client has support for sending willRenameFiles requests. did_delete: The client has support for sending didDeleteFiles notifications. will_delete: The client has support for sending willDeleteFiles requests.","ref":"GenLSP.Structures.FileOperationClientCapabilities.html#__struct__/0","title":"GenLSP.Structures.FileOperationClientCapabilities.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.FileOperationClientCapabilities.html#t:t/0","title":"GenLSP.Structures.FileOperationClientCapabilities.t/0","type":"type"},{"doc":"A filter to describe in which file operation requests or notifications the server is interested in receiving. @since 3.16.0","ref":"GenLSP.Structures.FileOperationFilter.html","title":"GenLSP.Structures.FileOperationFilter","type":"module"},{"doc":"Fields scheme: A Uri scheme like file or untitled . pattern: The actual file operation pattern.","ref":"GenLSP.Structures.FileOperationFilter.html#__struct__/0","title":"GenLSP.Structures.FileOperationFilter.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.FileOperationFilter.html#t:t/0","title":"GenLSP.Structures.FileOperationFilter.t/0","type":"type"},{"doc":"Options for notifications/requests for user operations on files. @since 3.16.0","ref":"GenLSP.Structures.FileOperationOptions.html","title":"GenLSP.Structures.FileOperationOptions","type":"module"},{"doc":"Fields did_create: The server is interested in receiving didCreateFiles notifications. will_create: The server is interested in receiving willCreateFiles requests. did_rename: The server is interested in receiving didRenameFiles notifications. will_rename: The server is interested in receiving willRenameFiles requests. did_delete: The server is interested in receiving didDeleteFiles file notifications. will_delete: The server is interested in receiving willDeleteFiles file requests.","ref":"GenLSP.Structures.FileOperationOptions.html#__struct__/0","title":"GenLSP.Structures.FileOperationOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.FileOperationOptions.html#t:t/0","title":"GenLSP.Structures.FileOperationOptions.t/0","type":"type"},{"doc":"A pattern to describe in which file operation requests or notifications the server is interested in receiving. @since 3.16.0","ref":"GenLSP.Structures.FileOperationPattern.html","title":"GenLSP.Structures.FileOperationPattern","type":"module"},{"doc":"Fields glob: The glob pattern to match. Glob patterns can have the following syntax: * to match one or more characters in a path segment ? to match on one character in a path segment ** to match any number of path segments, including none {} to group sub patterns into an OR expression. (e.g. **​/*.{ts,js} matches all TypeScript and JavaScript files) [] to declare a range of characters to match in a path segment (e.g., example.[0-9] to match on example.0 , example.1 , …) [!...] to negate a range of characters to match in a path segment (e.g., example.[!0-9] to match on example.a , example.b , but not example.0 ) matches: Whether to match files or folders with this pattern. Matches both if undefined. options: Additional options used during matching.","ref":"GenLSP.Structures.FileOperationPattern.html#__struct__/0","title":"GenLSP.Structures.FileOperationPattern.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.FileOperationPattern.html#t:t/0","title":"GenLSP.Structures.FileOperationPattern.t/0","type":"type"},{"doc":"Matching options for the file operation pattern. @since 3.16.0","ref":"GenLSP.Structures.FileOperationPatternOptions.html","title":"GenLSP.Structures.FileOperationPatternOptions","type":"module"},{"doc":"Fields ignore_case: The pattern should be matched ignoring casing.","ref":"GenLSP.Structures.FileOperationPatternOptions.html#__struct__/0","title":"GenLSP.Structures.FileOperationPatternOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.FileOperationPatternOptions.html#t:t/0","title":"GenLSP.Structures.FileOperationPatternOptions.t/0","type":"type"},{"doc":"The options to register for file operations. @since 3.16.0","ref":"GenLSP.Structures.FileOperationRegistrationOptions.html","title":"GenLSP.Structures.FileOperationRegistrationOptions","type":"module"},{"doc":"Fields filters: The actual filters.","ref":"GenLSP.Structures.FileOperationRegistrationOptions.html#__struct__/0","title":"GenLSP.Structures.FileOperationRegistrationOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.FileOperationRegistrationOptions.html#t:t/0","title":"GenLSP.Structures.FileOperationRegistrationOptions.t/0","type":"type"},{"doc":"Represents information on a file/folder rename. @since 3.16.0","ref":"GenLSP.Structures.FileRename.html","title":"GenLSP.Structures.FileRename","type":"module"},{"doc":"Fields old_uri: A file:// URI for the original location of the file/folder being renamed. new_uri: A file:// URI for the new location of the file/folder being renamed.","ref":"GenLSP.Structures.FileRename.html#__struct__/0","title":"GenLSP.Structures.FileRename.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.FileRename.html#t:t/0","title":"GenLSP.Structures.FileRename.t/0","type":"type"},{"doc":"","ref":"GenLSP.Structures.FileSystemWatcher.html","title":"GenLSP.Structures.FileSystemWatcher","type":"module"},{"doc":"Fields glob_pattern: The glob pattern to watch. See {@link GlobPattern glob pattern} for more detail. @since 3.17.0 support for relative patterns. kind: The kind of events of interest. If omitted it defaults to WatchKind.Create | WatchKind.Change | WatchKind.Delete which is 7.","ref":"GenLSP.Structures.FileSystemWatcher.html#__struct__/0","title":"GenLSP.Structures.FileSystemWatcher.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.FileSystemWatcher.html#t:t/0","title":"GenLSP.Structures.FileSystemWatcher.t/0","type":"type"},{"doc":"Represents a folding range. To be valid, start and end line must be bigger than zero and smaller than the number of lines in the document. Clients are free to ignore invalid ranges.","ref":"GenLSP.Structures.FoldingRange.html","title":"GenLSP.Structures.FoldingRange","type":"module"},{"doc":"Fields start_line: The zero-based start line of the range to fold. The folded area starts after the line's last character. To be valid, the end must be zero or larger and smaller than the number of lines in the document. start_character: The zero-based character offset from where the folded range starts. If not defined, defaults to the length of the start line. end_line: The zero-based end line of the range to fold. The folded area ends with the line's last character. To be valid, the end must be zero or larger and smaller than the number of lines in the document. end_character: The zero-based character offset before the folded range ends. If not defined, defaults to the length of the end line. kind: Describes the kind of the folding range such as 'comment' or 'region'. The kind is used to categorize folding ranges and used by commands like 'Fold all comments'. See {@link FoldingRangeKind} for an enumeration of standardized kinds. collapsed_text: The text that the client should show when the specified range is collapsed. If not defined or not supported by the client, a default will be chosen by the client. @since 3.17.0","ref":"GenLSP.Structures.FoldingRange.html#__struct__/0","title":"GenLSP.Structures.FoldingRange.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.FoldingRange.html#t:t/0","title":"GenLSP.Structures.FoldingRange.t/0","type":"type"},{"doc":"","ref":"GenLSP.Structures.FoldingRangeClientCapabilities.html","title":"GenLSP.Structures.FoldingRangeClientCapabilities","type":"module"},{"doc":"Fields dynamic_registration: Whether implementation supports dynamic registration for folding range providers. If this is set to true the client supports the new FoldingRangeRegistrationOptions return value for the corresponding server capability as well. range_limit: The maximum number of folding ranges that the client prefers to receive per document. The value serves as a hint, servers are free to follow the limit. line_folding_only: If set, the client signals that it only supports folding complete lines. If set, client will ignore specified startCharacter and endCharacter properties in a FoldingRange. folding_range_kind: Specific options for the folding range kind. @since 3.17.0 folding_range: Specific options for the folding range. @since 3.17.0","ref":"GenLSP.Structures.FoldingRangeClientCapabilities.html#__struct__/0","title":"GenLSP.Structures.FoldingRangeClientCapabilities.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.FoldingRangeClientCapabilities.html#t:t/0","title":"GenLSP.Structures.FoldingRangeClientCapabilities.t/0","type":"type"},{"doc":"","ref":"GenLSP.Structures.FoldingRangeOptions.html","title":"GenLSP.Structures.FoldingRangeOptions","type":"module"},{"doc":"Fields work_done_progress","ref":"GenLSP.Structures.FoldingRangeOptions.html#__struct__/0","title":"GenLSP.Structures.FoldingRangeOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.FoldingRangeOptions.html#t:t/0","title":"GenLSP.Structures.FoldingRangeOptions.t/0","type":"type"},{"doc":"Parameters for a {@link FoldingRangeRequest}.","ref":"GenLSP.Structures.FoldingRangeParams.html","title":"GenLSP.Structures.FoldingRangeParams","type":"module"},{"doc":"Fields text_document: The text document. work_done_token: An optional token that a server can use to report work done progress. partial_result_token: An optional token that a server can use to report partial results (e.g. streaming) to the client.","ref":"GenLSP.Structures.FoldingRangeParams.html#__struct__/0","title":"GenLSP.Structures.FoldingRangeParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.FoldingRangeParams.html#t:t/0","title":"GenLSP.Structures.FoldingRangeParams.t/0","type":"type"},{"doc":"","ref":"GenLSP.Structures.FoldingRangeRegistrationOptions.html","title":"GenLSP.Structures.FoldingRangeRegistrationOptions","type":"module"},{"doc":"Fields id: The id used to register the request. The id can be used to deregister the request again. See also Registration#id. document_selector: A document selector to identify the scope of the registration. If set to null the document selector provided on the client side will be used.","ref":"GenLSP.Structures.FoldingRangeRegistrationOptions.html#__struct__/0","title":"GenLSP.Structures.FoldingRangeRegistrationOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.FoldingRangeRegistrationOptions.html#t:t/0","title":"GenLSP.Structures.FoldingRangeRegistrationOptions.t/0","type":"type"},{"doc":"Value-object describing what options formatting should use.","ref":"GenLSP.Structures.FormattingOptions.html","title":"GenLSP.Structures.FormattingOptions","type":"module"},{"doc":"Fields tab_size: Size of a tab in spaces. insert_spaces: Prefer spaces over tabs. trim_trailing_whitespace: Trim trailing whitespace on a line. @since 3.15.0 insert_final_newline: Insert a newline character at the end of the file if one does not exist. @since 3.15.0 trim_final_newlines: Trim all newlines after the final newline at the end of the file. @since 3.15.0","ref":"GenLSP.Structures.FormattingOptions.html#__struct__/0","title":"GenLSP.Structures.FormattingOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.FormattingOptions.html#t:t/0","title":"GenLSP.Structures.FormattingOptions.t/0","type":"type"},{"doc":"A diagnostic report with a full set of problems. @since 3.17.0","ref":"GenLSP.Structures.FullDocumentDiagnosticReport.html","title":"GenLSP.Structures.FullDocumentDiagnosticReport","type":"module"},{"doc":"Fields kind: A full document diagnostic report. result_id: An optional result id. If provided it will be sent on the next diagnostic request for the same document. items: The actual items.","ref":"GenLSP.Structures.FullDocumentDiagnosticReport.html#__struct__/0","title":"GenLSP.Structures.FullDocumentDiagnosticReport.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.FullDocumentDiagnosticReport.html#t:t/0","title":"GenLSP.Structures.FullDocumentDiagnosticReport.t/0","type":"type"},{"doc":"General client capabilities. @since 3.16.0","ref":"GenLSP.Structures.GeneralClientCapabilities.html","title":"GenLSP.Structures.GeneralClientCapabilities","type":"module"},{"doc":"Fields stale_request_support: Client capability that signals how the client handles stale requests (e.g. a request for which the client will not process the response anymore since the information is outdated). @since 3.17.0 regular_expressions: Client capabilities specific to regular expressions. @since 3.16.0 markdown: Client capabilities specific to the client's markdown parser. @since 3.16.0 position_encodings: The position encodings supported by the client. Client and server have to agree on the same position encoding to ensure that offsets (e.g. character position in a line) are interpreted the same on both sides. To keep the protocol backwards compatible the following applies: if the value 'utf-16' is missing from the array of position encodings servers can assume that the client supports UTF-16. UTF-16 is therefore a mandatory encoding. If omitted it defaults to ['utf-16']. Implementation considerations: since the conversion from one encoding into another requires the content of the file / line the conversion is best done where the file is read which is usually on the server side. @since 3.17.0","ref":"GenLSP.Structures.GeneralClientCapabilities.html#__struct__/0","title":"GenLSP.Structures.GeneralClientCapabilities.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.GeneralClientCapabilities.html#t:t/0","title":"GenLSP.Structures.GeneralClientCapabilities.t/0","type":"type"},{"doc":"The result of a hover request.","ref":"GenLSP.Structures.Hover.html","title":"GenLSP.Structures.Hover","type":"module"},{"doc":"Fields contents: The hover's content range: An optional range inside the text document that is used to visualize the hover, e.g. by changing the background color.","ref":"GenLSP.Structures.Hover.html#__struct__/0","title":"GenLSP.Structures.Hover.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.Hover.html#t:t/0","title":"GenLSP.Structures.Hover.t/0","type":"type"},{"doc":"","ref":"GenLSP.Structures.HoverClientCapabilities.html","title":"GenLSP.Structures.HoverClientCapabilities","type":"module"},{"doc":"Fields dynamic_registration: Whether hover supports dynamic registration. content_format: Client supports the following content formats for the content property. The order describes the preferred format of the client.","ref":"GenLSP.Structures.HoverClientCapabilities.html#__struct__/0","title":"GenLSP.Structures.HoverClientCapabilities.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.HoverClientCapabilities.html#t:t/0","title":"GenLSP.Structures.HoverClientCapabilities.t/0","type":"type"},{"doc":"Hover options.","ref":"GenLSP.Structures.HoverOptions.html","title":"GenLSP.Structures.HoverOptions","type":"module"},{"doc":"Fields work_done_progress","ref":"GenLSP.Structures.HoverOptions.html#__struct__/0","title":"GenLSP.Structures.HoverOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.HoverOptions.html#t:t/0","title":"GenLSP.Structures.HoverOptions.t/0","type":"type"},{"doc":"Parameters for a {@link HoverRequest}.","ref":"GenLSP.Structures.HoverParams.html","title":"GenLSP.Structures.HoverParams","type":"module"},{"doc":"Fields work_done_token: An optional token that a server can use to report work done progress. text_document: The text document. position: The position inside the text document.","ref":"GenLSP.Structures.HoverParams.html#__struct__/0","title":"GenLSP.Structures.HoverParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.HoverParams.html#t:t/0","title":"GenLSP.Structures.HoverParams.t/0","type":"type"},{"doc":"Registration options for a {@link HoverRequest}.","ref":"GenLSP.Structures.HoverRegistrationOptions.html","title":"GenLSP.Structures.HoverRegistrationOptions","type":"module"},{"doc":"Fields document_selector: A document selector to identify the scope of the registration. If set to null the document selector provided on the client side will be used.","ref":"GenLSP.Structures.HoverRegistrationOptions.html#__struct__/0","title":"GenLSP.Structures.HoverRegistrationOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.HoverRegistrationOptions.html#t:t/0","title":"GenLSP.Structures.HoverRegistrationOptions.t/0","type":"type"},{"doc":"@since 3.6.0","ref":"GenLSP.Structures.ImplementationClientCapabilities.html","title":"GenLSP.Structures.ImplementationClientCapabilities","type":"module"},{"doc":"Fields dynamic_registration: Whether implementation supports dynamic registration. If this is set to true the client supports the new ImplementationRegistrationOptions return value for the corresponding server capability as well. link_support: The client supports additional metadata in the form of definition links. @since 3.14.0","ref":"GenLSP.Structures.ImplementationClientCapabilities.html#__struct__/0","title":"GenLSP.Structures.ImplementationClientCapabilities.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.ImplementationClientCapabilities.html#t:t/0","title":"GenLSP.Structures.ImplementationClientCapabilities.t/0","type":"type"},{"doc":"","ref":"GenLSP.Structures.ImplementationOptions.html","title":"GenLSP.Structures.ImplementationOptions","type":"module"},{"doc":"Fields work_done_progress","ref":"GenLSP.Structures.ImplementationOptions.html#__struct__/0","title":"GenLSP.Structures.ImplementationOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.ImplementationOptions.html#t:t/0","title":"GenLSP.Structures.ImplementationOptions.t/0","type":"type"},{"doc":"","ref":"GenLSP.Structures.ImplementationParams.html","title":"GenLSP.Structures.ImplementationParams","type":"module"},{"doc":"Fields work_done_token: An optional token that a server can use to report work done progress. partial_result_token: An optional token that a server can use to report partial results (e.g. streaming) to the client. text_document: The text document. position: The position inside the text document.","ref":"GenLSP.Structures.ImplementationParams.html#__struct__/0","title":"GenLSP.Structures.ImplementationParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.ImplementationParams.html#t:t/0","title":"GenLSP.Structures.ImplementationParams.t/0","type":"type"},{"doc":"","ref":"GenLSP.Structures.ImplementationRegistrationOptions.html","title":"GenLSP.Structures.ImplementationRegistrationOptions","type":"module"},{"doc":"Fields id: The id used to register the request. The id can be used to deregister the request again. See also Registration#id. document_selector: A document selector to identify the scope of the registration. If set to null the document selector provided on the client side will be used.","ref":"GenLSP.Structures.ImplementationRegistrationOptions.html#__struct__/0","title":"GenLSP.Structures.ImplementationRegistrationOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.ImplementationRegistrationOptions.html#t:t/0","title":"GenLSP.Structures.ImplementationRegistrationOptions.t/0","type":"type"},{"doc":"The data type of the ResponseError if the initialize request fails.","ref":"GenLSP.Structures.InitializeError.html","title":"GenLSP.Structures.InitializeError","type":"module"},{"doc":"Fields retry: Indicates whether the client execute the following retry logic: (1) show the message provided by the ResponseError to the user (2) user selects retry or cancel (3) if user selected retry the initialize method is sent again.","ref":"GenLSP.Structures.InitializeError.html#__struct__/0","title":"GenLSP.Structures.InitializeError.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.InitializeError.html#t:t/0","title":"GenLSP.Structures.InitializeError.t/0","type":"type"},{"doc":"","ref":"GenLSP.Structures.InitializeParams.html","title":"GenLSP.Structures.InitializeParams","type":"module"},{"doc":"Fields process_id: The process Id of the parent process that started the server. Is null if the process has not been started by another process. If the parent process is not alive then the server should exit. client_info: Information about the client @since 3.15.0 locale: The locale the client is currently showing the user interface in. This must not necessarily be the locale of the operating system. Uses IETF language tags as the value's syntax (See https://en.wikipedia.org/wiki/IETF_language_tag ) @since 3.16.0 root_path: The rootPath of the workspace. Is null if no folder is open. @deprecated in favour of rootUri. root_uri: The rootUri of the workspace. Is null if no folder is open. If both rootPath and rootUri are set rootUri wins. @deprecated in favour of workspaceFolders. capabilities: The capabilities provided by the client (editor or tool) initialization_options: User provided initialization options. trace: The initial trace setting. If omitted trace is disabled ('off'). workspace_folders: The workspace folders configured in the client when the server starts. This property is only available if the client supports workspace folders. It can be null if the client supports workspace folders but none are configured. @since 3.6.0","ref":"GenLSP.Structures.InitializeParams.html#__struct__/0","title":"GenLSP.Structures.InitializeParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.InitializeParams.html#t:t/0","title":"GenLSP.Structures.InitializeParams.t/0","type":"type"},{"doc":"The result returned from an initialize request.","ref":"GenLSP.Structures.InitializeResult.html","title":"GenLSP.Structures.InitializeResult","type":"module"},{"doc":"Fields capabilities: The capabilities the language server provides. server_info: Information about the server. @since 3.15.0","ref":"GenLSP.Structures.InitializeResult.html#__struct__/0","title":"GenLSP.Structures.InitializeResult.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.InitializeResult.html#t:t/0","title":"GenLSP.Structures.InitializeResult.t/0","type":"type"},{"doc":"","ref":"GenLSP.Structures.InitializedParams.html","title":"GenLSP.Structures.InitializedParams","type":"module"},{"doc":"Fields","ref":"GenLSP.Structures.InitializedParams.html#__struct__/0","title":"GenLSP.Structures.InitializedParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.InitializedParams.html#t:t/0","title":"GenLSP.Structures.InitializedParams.t/0","type":"type"},{"doc":"Inlay hint information. @since 3.17.0","ref":"GenLSP.Structures.InlayHint.html","title":"GenLSP.Structures.InlayHint","type":"module"},{"doc":"Fields position: The position of this hint. label: The label of this hint. A human readable string or an array of InlayHintLabelPart label parts. Note that neither the string nor the label part can be empty. kind: The kind of this hint. Can be omitted in which case the client should fall back to a reasonable default. text_edits: Optional text edits that are performed when accepting this inlay hint. Note that edits are expected to change the document so that the inlay hint (or its nearest variant) is now part of the document and the inlay hint itself is now obsolete. tooltip: The tooltip text when you hover over this item. padding_left: Render padding before the hint. Note: Padding should use the editor's background color, not the background color of the hint itself. That means padding can be used to visually align/separate an inlay hint. padding_right: Render padding after the hint. Note: Padding should use the editor's background color, not the background color of the hint itself. That means padding can be used to visually align/separate an inlay hint. data: A data entry field that is preserved on an inlay hint between a textDocument/inlayHint and a inlayHint/resolve request.","ref":"GenLSP.Structures.InlayHint.html#__struct__/0","title":"GenLSP.Structures.InlayHint.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.InlayHint.html#t:t/0","title":"GenLSP.Structures.InlayHint.t/0","type":"type"},{"doc":"Inlay hint client capabilities. @since 3.17.0","ref":"GenLSP.Structures.InlayHintClientCapabilities.html","title":"GenLSP.Structures.InlayHintClientCapabilities","type":"module"},{"doc":"Fields dynamic_registration: Whether inlay hints support dynamic registration. resolve_support: Indicates which properties a client can resolve lazily on an inlay hint.","ref":"GenLSP.Structures.InlayHintClientCapabilities.html#__struct__/0","title":"GenLSP.Structures.InlayHintClientCapabilities.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.InlayHintClientCapabilities.html#t:t/0","title":"GenLSP.Structures.InlayHintClientCapabilities.t/0","type":"type"},{"doc":"An inlay hint label part allows for interactive and composite labels of inlay hints. @since 3.17.0","ref":"GenLSP.Structures.InlayHintLabelPart.html","title":"GenLSP.Structures.InlayHintLabelPart","type":"module"},{"doc":"Fields value: The value of this label part. tooltip: The tooltip text when you hover over this label part. Depending on the client capability inlayHint.resolveSupport clients might resolve this property late using the resolve request. location: An optional source code location that represents this label part. The editor will use this location for the hover and for code navigation features: This part will become a clickable link that resolves to the definition of the symbol at the given location (not necessarily the location itself), it shows the hover that shows at the given location, and it shows a context menu with further code navigation commands. Depending on the client capability inlayHint.resolveSupport clients might resolve this property late using the resolve request. command: An optional command for this label part. Depending on the client capability inlayHint.resolveSupport clients might resolve this property late using the resolve request.","ref":"GenLSP.Structures.InlayHintLabelPart.html#__struct__/0","title":"GenLSP.Structures.InlayHintLabelPart.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.InlayHintLabelPart.html#t:t/0","title":"GenLSP.Structures.InlayHintLabelPart.t/0","type":"type"},{"doc":"Inlay hint options used during static registration. @since 3.17.0","ref":"GenLSP.Structures.InlayHintOptions.html","title":"GenLSP.Structures.InlayHintOptions","type":"module"},{"doc":"Fields resolve_provider: The server provides support to resolve additional information for an inlay hint item. work_done_progress","ref":"GenLSP.Structures.InlayHintOptions.html#__struct__/0","title":"GenLSP.Structures.InlayHintOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.InlayHintOptions.html#t:t/0","title":"GenLSP.Structures.InlayHintOptions.t/0","type":"type"},{"doc":"A parameter literal used in inlay hint requests. @since 3.17.0","ref":"GenLSP.Structures.InlayHintParams.html","title":"GenLSP.Structures.InlayHintParams","type":"module"},{"doc":"Fields text_document: The text document. range: The document range for which inlay hints should be computed. work_done_token: An optional token that a server can use to report work done progress.","ref":"GenLSP.Structures.InlayHintParams.html#__struct__/0","title":"GenLSP.Structures.InlayHintParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.InlayHintParams.html#t:t/0","title":"GenLSP.Structures.InlayHintParams.t/0","type":"type"},{"doc":"Inlay hint options used during static or dynamic registration. @since 3.17.0","ref":"GenLSP.Structures.InlayHintRegistrationOptions.html","title":"GenLSP.Structures.InlayHintRegistrationOptions","type":"module"},{"doc":"Fields id: The id used to register the request. The id can be used to deregister the request again. See also Registration#id. resolve_provider: The server provides support to resolve additional information for an inlay hint item. document_selector: A document selector to identify the scope of the registration. If set to null the document selector provided on the client side will be used.","ref":"GenLSP.Structures.InlayHintRegistrationOptions.html#__struct__/0","title":"GenLSP.Structures.InlayHintRegistrationOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.InlayHintRegistrationOptions.html#t:t/0","title":"GenLSP.Structures.InlayHintRegistrationOptions.t/0","type":"type"},{"doc":"Client workspace capabilities specific to inlay hints. @since 3.17.0","ref":"GenLSP.Structures.InlayHintWorkspaceClientCapabilities.html","title":"GenLSP.Structures.InlayHintWorkspaceClientCapabilities","type":"module"},{"doc":"Fields refresh_support: Whether the client implementation supports a refresh request sent from the server to the client. Note that this event is global and will force the client to refresh all inlay hints currently shown. It should be used with absolute care and is useful for situation where a server for example detects a project wide change that requires such a calculation.","ref":"GenLSP.Structures.InlayHintWorkspaceClientCapabilities.html#__struct__/0","title":"GenLSP.Structures.InlayHintWorkspaceClientCapabilities.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.InlayHintWorkspaceClientCapabilities.html#t:t/0","title":"GenLSP.Structures.InlayHintWorkspaceClientCapabilities.t/0","type":"type"},{"doc":"Client capabilities specific to inline values. @since 3.17.0","ref":"GenLSP.Structures.InlineValueClientCapabilities.html","title":"GenLSP.Structures.InlineValueClientCapabilities","type":"module"},{"doc":"Fields dynamic_registration: Whether implementation supports dynamic registration for inline value providers.","ref":"GenLSP.Structures.InlineValueClientCapabilities.html#__struct__/0","title":"GenLSP.Structures.InlineValueClientCapabilities.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.InlineValueClientCapabilities.html#t:t/0","title":"GenLSP.Structures.InlineValueClientCapabilities.t/0","type":"type"},{"doc":"@since 3.17.0","ref":"GenLSP.Structures.InlineValueContext.html","title":"GenLSP.Structures.InlineValueContext","type":"module"},{"doc":"Fields frame_id: The stack frame (as a DAP Id) where the execution has stopped. stopped_location: The document range where execution has stopped. Typically the end position of the range denotes the line where the inline values are shown.","ref":"GenLSP.Structures.InlineValueContext.html#__struct__/0","title":"GenLSP.Structures.InlineValueContext.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.InlineValueContext.html#t:t/0","title":"GenLSP.Structures.InlineValueContext.t/0","type":"type"},{"doc":"Provide an inline value through an expression evaluation. If only a range is specified, the expression will be extracted from the underlying document. An optional expression can be used to override the extracted expression. @since 3.17.0","ref":"GenLSP.Structures.InlineValueEvaluatableExpression.html","title":"GenLSP.Structures.InlineValueEvaluatableExpression","type":"module"},{"doc":"Fields range: The document range for which the inline value applies. The range is used to extract the evaluatable expression from the underlying document. expression: If specified the expression overrides the extracted expression.","ref":"GenLSP.Structures.InlineValueEvaluatableExpression.html#__struct__/0","title":"GenLSP.Structures.InlineValueEvaluatableExpression.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.InlineValueEvaluatableExpression.html#t:t/0","title":"GenLSP.Structures.InlineValueEvaluatableExpression.t/0","type":"type"},{"doc":"Inline value options used during static registration. @since 3.17.0","ref":"GenLSP.Structures.InlineValueOptions.html","title":"GenLSP.Structures.InlineValueOptions","type":"module"},{"doc":"Fields work_done_progress","ref":"GenLSP.Structures.InlineValueOptions.html#__struct__/0","title":"GenLSP.Structures.InlineValueOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.InlineValueOptions.html#t:t/0","title":"GenLSP.Structures.InlineValueOptions.t/0","type":"type"},{"doc":"A parameter literal used in inline value requests. @since 3.17.0","ref":"GenLSP.Structures.InlineValueParams.html","title":"GenLSP.Structures.InlineValueParams","type":"module"},{"doc":"Fields text_document: The text document. range: The document range for which inline values should be computed. context: Additional information about the context in which inline values were requested. work_done_token: An optional token that a server can use to report work done progress.","ref":"GenLSP.Structures.InlineValueParams.html#__struct__/0","title":"GenLSP.Structures.InlineValueParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.InlineValueParams.html#t:t/0","title":"GenLSP.Structures.InlineValueParams.t/0","type":"type"},{"doc":"Inline value options used during static or dynamic registration. @since 3.17.0","ref":"GenLSP.Structures.InlineValueRegistrationOptions.html","title":"GenLSP.Structures.InlineValueRegistrationOptions","type":"module"},{"doc":"Fields id: The id used to register the request. The id can be used to deregister the request again. See also Registration#id. document_selector: A document selector to identify the scope of the registration. If set to null the document selector provided on the client side will be used.","ref":"GenLSP.Structures.InlineValueRegistrationOptions.html#__struct__/0","title":"GenLSP.Structures.InlineValueRegistrationOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.InlineValueRegistrationOptions.html#t:t/0","title":"GenLSP.Structures.InlineValueRegistrationOptions.t/0","type":"type"},{"doc":"Provide inline value as text. @since 3.17.0","ref":"GenLSP.Structures.InlineValueText.html","title":"GenLSP.Structures.InlineValueText","type":"module"},{"doc":"Fields range: The document range for which the inline value applies. text: The text of the inline value.","ref":"GenLSP.Structures.InlineValueText.html#__struct__/0","title":"GenLSP.Structures.InlineValueText.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.InlineValueText.html#t:t/0","title":"GenLSP.Structures.InlineValueText.t/0","type":"type"},{"doc":"Provide inline value through a variable lookup. If only a range is specified, the variable name will be extracted from the underlying document. An optional variable name can be used to override the extracted name. @since 3.17.0","ref":"GenLSP.Structures.InlineValueVariableLookup.html","title":"GenLSP.Structures.InlineValueVariableLookup","type":"module"},{"doc":"Fields range: The document range for which the inline value applies. The range is used to extract the variable name from the underlying document. variable_name: If specified the name of the variable to look up. case_sensitive_lookup: How to perform the lookup.","ref":"GenLSP.Structures.InlineValueVariableLookup.html#__struct__/0","title":"GenLSP.Structures.InlineValueVariableLookup.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.InlineValueVariableLookup.html#t:t/0","title":"GenLSP.Structures.InlineValueVariableLookup.t/0","type":"type"},{"doc":"Client workspace capabilities specific to inline values. @since 3.17.0","ref":"GenLSP.Structures.InlineValueWorkspaceClientCapabilities.html","title":"GenLSP.Structures.InlineValueWorkspaceClientCapabilities","type":"module"},{"doc":"Fields refresh_support: Whether the client implementation supports a refresh request sent from the server to the client. Note that this event is global and will force the client to refresh all inline values currently shown. It should be used with absolute care and is useful for situation where a server for example detects a project wide change that requires such a calculation.","ref":"GenLSP.Structures.InlineValueWorkspaceClientCapabilities.html#__struct__/0","title":"GenLSP.Structures.InlineValueWorkspaceClientCapabilities.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.InlineValueWorkspaceClientCapabilities.html#t:t/0","title":"GenLSP.Structures.InlineValueWorkspaceClientCapabilities.t/0","type":"type"},{"doc":"A special text edit to provide an insert and a replace operation. @since 3.16.0","ref":"GenLSP.Structures.InsertReplaceEdit.html","title":"GenLSP.Structures.InsertReplaceEdit","type":"module"},{"doc":"Fields new_text: The string to be inserted. insert: The range if the insert is requested replace: The range if the replace is requested.","ref":"GenLSP.Structures.InsertReplaceEdit.html#__struct__/0","title":"GenLSP.Structures.InsertReplaceEdit.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.InsertReplaceEdit.html#t:t/0","title":"GenLSP.Structures.InsertReplaceEdit.t/0","type":"type"},{"doc":"Client capabilities for the linked editing range request. @since 3.16.0","ref":"GenLSP.Structures.LinkedEditingRangeClientCapabilities.html","title":"GenLSP.Structures.LinkedEditingRangeClientCapabilities","type":"module"},{"doc":"Fields dynamic_registration: Whether implementation supports dynamic registration. If this is set to true the client supports the new (TextDocumentRegistrationOptions &amp; StaticRegistrationOptions) return value for the corresponding server capability as well.","ref":"GenLSP.Structures.LinkedEditingRangeClientCapabilities.html#__struct__/0","title":"GenLSP.Structures.LinkedEditingRangeClientCapabilities.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.LinkedEditingRangeClientCapabilities.html#t:t/0","title":"GenLSP.Structures.LinkedEditingRangeClientCapabilities.t/0","type":"type"},{"doc":"","ref":"GenLSP.Structures.LinkedEditingRangeOptions.html","title":"GenLSP.Structures.LinkedEditingRangeOptions","type":"module"},{"doc":"Fields work_done_progress","ref":"GenLSP.Structures.LinkedEditingRangeOptions.html#__struct__/0","title":"GenLSP.Structures.LinkedEditingRangeOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.LinkedEditingRangeOptions.html#t:t/0","title":"GenLSP.Structures.LinkedEditingRangeOptions.t/0","type":"type"},{"doc":"","ref":"GenLSP.Structures.LinkedEditingRangeParams.html","title":"GenLSP.Structures.LinkedEditingRangeParams","type":"module"},{"doc":"Fields work_done_token: An optional token that a server can use to report work done progress. text_document: The text document. position: The position inside the text document.","ref":"GenLSP.Structures.LinkedEditingRangeParams.html#__struct__/0","title":"GenLSP.Structures.LinkedEditingRangeParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.LinkedEditingRangeParams.html#t:t/0","title":"GenLSP.Structures.LinkedEditingRangeParams.t/0","type":"type"},{"doc":"","ref":"GenLSP.Structures.LinkedEditingRangeRegistrationOptions.html","title":"GenLSP.Structures.LinkedEditingRangeRegistrationOptions","type":"module"},{"doc":"Fields id: The id used to register the request. The id can be used to deregister the request again. See also Registration#id. document_selector: A document selector to identify the scope of the registration. If set to null the document selector provided on the client side will be used.","ref":"GenLSP.Structures.LinkedEditingRangeRegistrationOptions.html#__struct__/0","title":"GenLSP.Structures.LinkedEditingRangeRegistrationOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.LinkedEditingRangeRegistrationOptions.html#t:t/0","title":"GenLSP.Structures.LinkedEditingRangeRegistrationOptions.t/0","type":"type"},{"doc":"The result of a linked editing range request. @since 3.16.0","ref":"GenLSP.Structures.LinkedEditingRanges.html","title":"GenLSP.Structures.LinkedEditingRanges","type":"module"},{"doc":"Fields ranges: A list of ranges that can be edited together. The ranges must have identical length and contain identical text content. The ranges cannot overlap. word_pattern: An optional word pattern (regular expression) that describes valid contents for the given ranges. If no pattern is provided, the client configuration's word pattern will be used.","ref":"GenLSP.Structures.LinkedEditingRanges.html#__struct__/0","title":"GenLSP.Structures.LinkedEditingRanges.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.LinkedEditingRanges.html#t:t/0","title":"GenLSP.Structures.LinkedEditingRanges.t/0","type":"type"},{"doc":"Represents a location inside a resource, such as a line inside a text file.","ref":"GenLSP.Structures.Location.html","title":"GenLSP.Structures.Location","type":"module"},{"doc":"Fields uri range","ref":"GenLSP.Structures.Location.html#__struct__/0","title":"GenLSP.Structures.Location.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.Location.html#t:t/0","title":"GenLSP.Structures.Location.t/0","type":"type"},{"doc":"Represents the connection of two locations. Provides additional metadata over normal {@link Location locations}, including an origin range.","ref":"GenLSP.Structures.LocationLink.html","title":"GenLSP.Structures.LocationLink","type":"module"},{"doc":"Fields origin_selection_range: Span of the origin of this link. Used as the underlined span for mouse interaction. Defaults to the word range at the definition position. target_uri: The target resource identifier of this link. target_range: The full target range of this link. If the target for example is a symbol then target range is the range enclosing this symbol not including leading/trailing whitespace but everything else like comments. This information is typically used to highlight the range in the editor. target_selection_range: The range that should be selected and revealed when this link is being followed, e.g the name of a function. Must be contained by the targetRange . See also DocumentSymbol#range","ref":"GenLSP.Structures.LocationLink.html#__struct__/0","title":"GenLSP.Structures.LocationLink.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.LocationLink.html#t:t/0","title":"GenLSP.Structures.LocationLink.t/0","type":"type"},{"doc":"The log message parameters.","ref":"GenLSP.Structures.LogMessageParams.html","title":"GenLSP.Structures.LogMessageParams","type":"module"},{"doc":"Fields type: The message type. See {@link MessageType} message: The actual message.","ref":"GenLSP.Structures.LogMessageParams.html#__struct__/0","title":"GenLSP.Structures.LogMessageParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.LogMessageParams.html#t:t/0","title":"GenLSP.Structures.LogMessageParams.t/0","type":"type"},{"doc":"","ref":"GenLSP.Structures.LogTraceParams.html","title":"GenLSP.Structures.LogTraceParams","type":"module"},{"doc":"Fields message verbose","ref":"GenLSP.Structures.LogTraceParams.html#__struct__/0","title":"GenLSP.Structures.LogTraceParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.LogTraceParams.html#t:t/0","title":"GenLSP.Structures.LogTraceParams.t/0","type":"type"},{"doc":"Client capabilities specific to the used markdown parser. @since 3.16.0","ref":"GenLSP.Structures.MarkdownClientCapabilities.html","title":"GenLSP.Structures.MarkdownClientCapabilities","type":"module"},{"doc":"Fields parser: The name of the parser. version: The version of the parser. allowed_tags: A list of HTML tags that the client allows / supports in Markdown. @since 3.17.0","ref":"GenLSP.Structures.MarkdownClientCapabilities.html#__struct__/0","title":"GenLSP.Structures.MarkdownClientCapabilities.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.MarkdownClientCapabilities.html#t:t/0","title":"GenLSP.Structures.MarkdownClientCapabilities.t/0","type":"type"},{"doc":"A MarkupContent literal represents a string value which content is interpreted base on its kind flag. Currently the protocol supports plaintext and markdown as markup kinds. If the kind is markdown then the value can contain fenced code blocks like in GitHub issues. See https://help.github.com/articles/creating-and-highlighting-code-blocks/#syntax-highlighting Here is an example how such a string can be constructed using JavaScript / TypeScript: let markdown: MarkdownContent = { kind: MarkupKind.Markdown, value: [ '# Header', 'Some text', '```typescript', 'someCode();', '```' ].join(' ') }; Please Note that clients might sanitize the return markdown. A client could decide to remove HTML from the markdown to avoid script execution.","ref":"GenLSP.Structures.MarkupContent.html","title":"GenLSP.Structures.MarkupContent","type":"module"},{"doc":"Fields kind: The type of the Markup value: The content itself","ref":"GenLSP.Structures.MarkupContent.html#__struct__/0","title":"GenLSP.Structures.MarkupContent.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.MarkupContent.html#t:t/0","title":"GenLSP.Structures.MarkupContent.t/0","type":"type"},{"doc":"","ref":"GenLSP.Structures.MessageActionItem.html","title":"GenLSP.Structures.MessageActionItem","type":"module"},{"doc":"Fields title: A short title like 'Retry', 'Open Log' etc.","ref":"GenLSP.Structures.MessageActionItem.html#__struct__/0","title":"GenLSP.Structures.MessageActionItem.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.MessageActionItem.html#t:t/0","title":"GenLSP.Structures.MessageActionItem.t/0","type":"type"},{"doc":"Moniker definition to match LSIF 0.5 moniker definition. @since 3.16.0","ref":"GenLSP.Structures.Moniker.html","title":"GenLSP.Structures.Moniker","type":"module"},{"doc":"Fields scheme: The scheme of the moniker. For example tsc or .Net identifier: The identifier of the moniker. The value is opaque in LSIF however schema owners are allowed to define the structure if they want. unique: The scope in which the moniker is unique kind: The moniker kind if known.","ref":"GenLSP.Structures.Moniker.html#__struct__/0","title":"GenLSP.Structures.Moniker.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.Moniker.html#t:t/0","title":"GenLSP.Structures.Moniker.t/0","type":"type"},{"doc":"Client capabilities specific to the moniker request. @since 3.16.0","ref":"GenLSP.Structures.MonikerClientCapabilities.html","title":"GenLSP.Structures.MonikerClientCapabilities","type":"module"},{"doc":"Fields dynamic_registration: Whether moniker supports dynamic registration. If this is set to true the client supports the new MonikerRegistrationOptions return value for the corresponding server capability as well.","ref":"GenLSP.Structures.MonikerClientCapabilities.html#__struct__/0","title":"GenLSP.Structures.MonikerClientCapabilities.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.MonikerClientCapabilities.html#t:t/0","title":"GenLSP.Structures.MonikerClientCapabilities.t/0","type":"type"},{"doc":"","ref":"GenLSP.Structures.MonikerOptions.html","title":"GenLSP.Structures.MonikerOptions","type":"module"},{"doc":"Fields work_done_progress","ref":"GenLSP.Structures.MonikerOptions.html#__struct__/0","title":"GenLSP.Structures.MonikerOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.MonikerOptions.html#t:t/0","title":"GenLSP.Structures.MonikerOptions.t/0","type":"type"},{"doc":"","ref":"GenLSP.Structures.MonikerParams.html","title":"GenLSP.Structures.MonikerParams","type":"module"},{"doc":"Fields work_done_token: An optional token that a server can use to report work done progress. partial_result_token: An optional token that a server can use to report partial results (e.g. streaming) to the client. text_document: The text document. position: The position inside the text document.","ref":"GenLSP.Structures.MonikerParams.html#__struct__/0","title":"GenLSP.Structures.MonikerParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.MonikerParams.html#t:t/0","title":"GenLSP.Structures.MonikerParams.t/0","type":"type"},{"doc":"","ref":"GenLSP.Structures.MonikerRegistrationOptions.html","title":"GenLSP.Structures.MonikerRegistrationOptions","type":"module"},{"doc":"Fields document_selector: A document selector to identify the scope of the registration. If set to null the document selector provided on the client side will be used.","ref":"GenLSP.Structures.MonikerRegistrationOptions.html#__struct__/0","title":"GenLSP.Structures.MonikerRegistrationOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.MonikerRegistrationOptions.html#t:t/0","title":"GenLSP.Structures.MonikerRegistrationOptions.t/0","type":"type"},{"doc":"A notebook cell. A cell's document URI must be unique across ALL notebook cells and can therefore be used to uniquely identify a notebook cell or the cell's text document. @since 3.17.0","ref":"GenLSP.Structures.NotebookCell.html","title":"GenLSP.Structures.NotebookCell","type":"module"},{"doc":"Fields kind: The cell's kind document: The URI of the cell's text document content. metadata: Additional metadata stored with the cell. Note: should always be an object literal (e.g. LSPObject) execution_summary: Additional execution summary information if supported by the client.","ref":"GenLSP.Structures.NotebookCell.html#__struct__/0","title":"GenLSP.Structures.NotebookCell.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.NotebookCell.html#t:t/0","title":"GenLSP.Structures.NotebookCell.t/0","type":"type"},{"doc":"A change describing how to move a NotebookCell array from state S to S'. @since 3.17.0","ref":"GenLSP.Structures.NotebookCellArrayChange.html","title":"GenLSP.Structures.NotebookCellArrayChange","type":"module"},{"doc":"Fields start: The start oftest of the cell that changed. delete_count: The deleted cells cells: The new cells, if any","ref":"GenLSP.Structures.NotebookCellArrayChange.html#__struct__/0","title":"GenLSP.Structures.NotebookCellArrayChange.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.NotebookCellArrayChange.html#t:t/0","title":"GenLSP.Structures.NotebookCellArrayChange.t/0","type":"type"},{"doc":"A notebook cell text document filter denotes a cell text document by different properties. @since 3.17.0","ref":"GenLSP.Structures.NotebookCellTextDocumentFilter.html","title":"GenLSP.Structures.NotebookCellTextDocumentFilter","type":"module"},{"doc":"Fields notebook: A filter that matches against the notebook containing the notebook cell. If a string value is provided it matches against the notebook type. '*' matches every notebook. language: A language id like python . Will be matched against the language id of the notebook cell document. '*' matches every language.","ref":"GenLSP.Structures.NotebookCellTextDocumentFilter.html#__struct__/0","title":"GenLSP.Structures.NotebookCellTextDocumentFilter.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.NotebookCellTextDocumentFilter.html#t:t/0","title":"GenLSP.Structures.NotebookCellTextDocumentFilter.t/0","type":"type"},{"doc":"A notebook document. @since 3.17.0","ref":"GenLSP.Structures.NotebookDocument.html","title":"GenLSP.Structures.NotebookDocument","type":"module"},{"doc":"Fields uri: The notebook document's uri. notebook_type: The type of the notebook. version: The version number of this document (it will increase after each change, including undo/redo). metadata: Additional metadata stored with the notebook document. Note: should always be an object literal (e.g. LSPObject) cells: The cells of a notebook.","ref":"GenLSP.Structures.NotebookDocument.html#__struct__/0","title":"GenLSP.Structures.NotebookDocument.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.NotebookDocument.html#t:t/0","title":"GenLSP.Structures.NotebookDocument.t/0","type":"type"},{"doc":"A change event for a notebook document. @since 3.17.0","ref":"GenLSP.Structures.NotebookDocumentChangeEvent.html","title":"GenLSP.Structures.NotebookDocumentChangeEvent","type":"module"},{"doc":"Fields metadata: The changed meta data if any. Note: should always be an object literal (e.g. LSPObject) cells: Changes to cells","ref":"GenLSP.Structures.NotebookDocumentChangeEvent.html#__struct__/0","title":"GenLSP.Structures.NotebookDocumentChangeEvent.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.NotebookDocumentChangeEvent.html#t:t/0","title":"GenLSP.Structures.NotebookDocumentChangeEvent.t/0","type":"type"},{"doc":"Capabilities specific to the notebook document support. @since 3.17.0","ref":"GenLSP.Structures.NotebookDocumentClientCapabilities.html","title":"GenLSP.Structures.NotebookDocumentClientCapabilities","type":"module"},{"doc":"Fields synchronization: Capabilities specific to notebook document synchronization @since 3.17.0","ref":"GenLSP.Structures.NotebookDocumentClientCapabilities.html#__struct__/0","title":"GenLSP.Structures.NotebookDocumentClientCapabilities.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.NotebookDocumentClientCapabilities.html#t:t/0","title":"GenLSP.Structures.NotebookDocumentClientCapabilities.t/0","type":"type"},{"doc":"A literal to identify a notebook document in the client. @since 3.17.0","ref":"GenLSP.Structures.NotebookDocumentIdentifier.html","title":"GenLSP.Structures.NotebookDocumentIdentifier","type":"module"},{"doc":"Fields uri: The notebook document's uri.","ref":"GenLSP.Structures.NotebookDocumentIdentifier.html#__struct__/0","title":"GenLSP.Structures.NotebookDocumentIdentifier.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.NotebookDocumentIdentifier.html#t:t/0","title":"GenLSP.Structures.NotebookDocumentIdentifier.t/0","type":"type"},{"doc":"Notebook specific client capabilities. @since 3.17.0","ref":"GenLSP.Structures.NotebookDocumentSyncClientCapabilities.html","title":"GenLSP.Structures.NotebookDocumentSyncClientCapabilities","type":"module"},{"doc":"Fields dynamic_registration: Whether implementation supports dynamic registration. If this is set to true the client supports the new (TextDocumentRegistrationOptions &amp; StaticRegistrationOptions) return value for the corresponding server capability as well. execution_summary_support: The client supports sending execution summary data per cell.","ref":"GenLSP.Structures.NotebookDocumentSyncClientCapabilities.html#__struct__/0","title":"GenLSP.Structures.NotebookDocumentSyncClientCapabilities.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.NotebookDocumentSyncClientCapabilities.html#t:t/0","title":"GenLSP.Structures.NotebookDocumentSyncClientCapabilities.t/0","type":"type"},{"doc":"Options specific to a notebook plus its cells to be synced to the server. If a selector provides a notebook document filter but no cell selector all cells of a matching notebook document will be synced. If a selector provides no notebook document filter but only a cell selector all notebook document that contain at least one matching cell will be synced. @since 3.17.0","ref":"GenLSP.Structures.NotebookDocumentSyncOptions.html","title":"GenLSP.Structures.NotebookDocumentSyncOptions","type":"module"},{"doc":"Fields notebook_selector: The notebooks to be synced save: Whether save notification should be forwarded to the server. Will only be honored if mode === notebook .","ref":"GenLSP.Structures.NotebookDocumentSyncOptions.html#__struct__/0","title":"GenLSP.Structures.NotebookDocumentSyncOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.NotebookDocumentSyncOptions.html#t:t/0","title":"GenLSP.Structures.NotebookDocumentSyncOptions.t/0","type":"type"},{"doc":"Registration options specific to a notebook. @since 3.17.0","ref":"GenLSP.Structures.NotebookDocumentSyncRegistrationOptions.html","title":"GenLSP.Structures.NotebookDocumentSyncRegistrationOptions","type":"module"},{"doc":"Fields id: The id used to register the request. The id can be used to deregister the request again. See also Registration#id. notebook_selector: The notebooks to be synced save: Whether save notification should be forwarded to the server. Will only be honored if mode === notebook .","ref":"GenLSP.Structures.NotebookDocumentSyncRegistrationOptions.html#__struct__/0","title":"GenLSP.Structures.NotebookDocumentSyncRegistrationOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.NotebookDocumentSyncRegistrationOptions.html#t:t/0","title":"GenLSP.Structures.NotebookDocumentSyncRegistrationOptions.t/0","type":"type"},{"doc":"A text document identifier to optionally denote a specific version of a text document.","ref":"GenLSP.Structures.OptionalVersionedTextDocumentIdentifier.html","title":"GenLSP.Structures.OptionalVersionedTextDocumentIdentifier","type":"module"},{"doc":"Fields version: The version number of this document. If a versioned text document identifier is sent from the server to the client and the file is not open in the editor (the server has not received an open notification before) the server can send null to indicate that the version is unknown and the content on disk is the truth (as specified with document content ownership). uri: The text document's uri.","ref":"GenLSP.Structures.OptionalVersionedTextDocumentIdentifier.html#__struct__/0","title":"GenLSP.Structures.OptionalVersionedTextDocumentIdentifier.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.OptionalVersionedTextDocumentIdentifier.html#t:t/0","title":"GenLSP.Structures.OptionalVersionedTextDocumentIdentifier.t/0","type":"type"},{"doc":"Represents a parameter of a callable-signature. A parameter can have a label and a doc-comment.","ref":"GenLSP.Structures.ParameterInformation.html","title":"GenLSP.Structures.ParameterInformation","type":"module"},{"doc":"Fields label: The label of this parameter information. Either a string or an inclusive start and exclusive end offsets within its containing signature label. (see SignatureInformation.label). The offsets are based on a UTF-16 string representation as Position and Range does. Note : a label of type string should be a substring of its containing signature label. Its intended use case is to highlight the parameter label part in the SignatureInformation.label . documentation: The human-readable doc-comment of this parameter. Will be shown in the UI but can be omitted.","ref":"GenLSP.Structures.ParameterInformation.html#__struct__/0","title":"GenLSP.Structures.ParameterInformation.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.ParameterInformation.html#t:t/0","title":"GenLSP.Structures.ParameterInformation.t/0","type":"type"},{"doc":"","ref":"GenLSP.Structures.PartialResultParams.html","title":"GenLSP.Structures.PartialResultParams","type":"module"},{"doc":"Fields partial_result_token: An optional token that a server can use to report partial results (e.g. streaming) to the client.","ref":"GenLSP.Structures.PartialResultParams.html#__struct__/0","title":"GenLSP.Structures.PartialResultParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.PartialResultParams.html#t:t/0","title":"GenLSP.Structures.PartialResultParams.t/0","type":"type"},{"doc":"Position in a text document expressed as zero-based line and character offset. Prior to 3.17 the offsets were always based on a UTF-16 string representation. So a string of the form a𐐀b the character offset of the character a is 0, the character offset of 𐐀 is 1 and the character offset of b is 3 since 𐐀 is represented using two code units in UTF-16. Since 3.17 clients and servers can agree on a different string encoding representation (e.g. UTF-8). The client announces it's supported encoding via the client capability general.positionEncodings . The value is an array of position encodings the client supports, with decreasing preference (e.g. the encoding at index 0 is the most preferred one). To stay backwards compatible the only mandatory encoding is UTF-16 represented via the string utf-16 . The server can pick one of the encodings offered by the client and signals that encoding back to the client via the initialize result's property capabilities.positionEncoding . If the string value utf-16 is missing from the client's capability general.positionEncodings servers can safely assume that the client supports UTF-16. If the server omits the position encoding in its initialize result the encoding defaults to the string value utf-16 . Implementation considerations: since the conversion from one encoding into another requires the content of the file / line the conversion is best done where the file is read which is usually on the server side. Positions are line end character agnostic. So you can not specify a position that denotes | or | where | represents the character offset. @since 3.17.0 - support for negotiated position encoding.","ref":"GenLSP.Structures.Position.html","title":"GenLSP.Structures.Position","type":"module"},{"doc":"Fields line: Line position in a document (zero-based). If a line number is greater than the number of lines in a document, it defaults back to the number of lines in the document. If a line number is negative, it defaults to 0. character: Character offset on a line in a document (zero-based). The meaning of this offset is determined by the negotiated PositionEncodingKind . If the character value is greater than the line length it defaults back to the line length.","ref":"GenLSP.Structures.Position.html#__struct__/0","title":"GenLSP.Structures.Position.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.Position.html#t:t/0","title":"GenLSP.Structures.Position.t/0","type":"type"},{"doc":"","ref":"GenLSP.Structures.PrepareRenameParams.html","title":"GenLSP.Structures.PrepareRenameParams","type":"module"},{"doc":"Fields work_done_token: An optional token that a server can use to report work done progress. text_document: The text document. position: The position inside the text document.","ref":"GenLSP.Structures.PrepareRenameParams.html#__struct__/0","title":"GenLSP.Structures.PrepareRenameParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.PrepareRenameParams.html#t:t/0","title":"GenLSP.Structures.PrepareRenameParams.t/0","type":"type"},{"doc":"A previous result id in a workspace pull request. @since 3.17.0","ref":"GenLSP.Structures.PreviousResultId.html","title":"GenLSP.Structures.PreviousResultId","type":"module"},{"doc":"Fields uri: The URI for which the client knowns a result id. value: The value of the previous result id.","ref":"GenLSP.Structures.PreviousResultId.html#__struct__/0","title":"GenLSP.Structures.PreviousResultId.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.PreviousResultId.html#t:t/0","title":"GenLSP.Structures.PreviousResultId.t/0","type":"type"},{"doc":"The initialize parameters","ref":"GenLSP.Structures.PrivateInitializeParams.html","title":"GenLSP.Structures.PrivateInitializeParams","type":"module"},{"doc":"Fields process_id: The process Id of the parent process that started the server. Is null if the process has not been started by another process. If the parent process is not alive then the server should exit. client_info: Information about the client @since 3.15.0 locale: The locale the client is currently showing the user interface in. This must not necessarily be the locale of the operating system. Uses IETF language tags as the value's syntax (See https://en.wikipedia.org/wiki/IETF_language_tag ) @since 3.16.0 root_path: The rootPath of the workspace. Is null if no folder is open. @deprecated in favour of rootUri. root_uri: The rootUri of the workspace. Is null if no folder is open. If both rootPath and rootUri are set rootUri wins. @deprecated in favour of workspaceFolders. capabilities: The capabilities provided by the client (editor or tool) initialization_options: User provided initialization options. trace: The initial trace setting. If omitted trace is disabled ('off'). work_done_token: An optional token that a server can use to report work done progress.","ref":"GenLSP.Structures.PrivateInitializeParams.html#__struct__/0","title":"GenLSP.Structures.PrivateInitializeParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.PrivateInitializeParams.html#t:t/0","title":"GenLSP.Structures.PrivateInitializeParams.t/0","type":"type"},{"doc":"","ref":"GenLSP.Structures.ProgressParams.html","title":"GenLSP.Structures.ProgressParams","type":"module"},{"doc":"Fields token: The progress token provided by the client or server. value: The progress data.","ref":"GenLSP.Structures.ProgressParams.html#__struct__/0","title":"GenLSP.Structures.ProgressParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.ProgressParams.html#t:t/0","title":"GenLSP.Structures.ProgressParams.t/0","type":"type"},{"doc":"The publish diagnostic client capabilities.","ref":"GenLSP.Structures.PublishDiagnosticsClientCapabilities.html","title":"GenLSP.Structures.PublishDiagnosticsClientCapabilities","type":"module"},{"doc":"Fields related_information: Whether the clients accepts diagnostics with related information. tag_support: Client supports the tag property to provide meta data about a diagnostic. Clients supporting tags have to handle unknown tags gracefully. @since 3.15.0 version_support: Whether the client interprets the version property of the textDocument/publishDiagnostics notification's parameter. @since 3.15.0 code_description_support: Client supports a codeDescription property @since 3.16.0 data_support: Whether code action supports the data property which is preserved between a textDocument/publishDiagnostics and textDocument/codeAction request. @since 3.16.0","ref":"GenLSP.Structures.PublishDiagnosticsClientCapabilities.html#__struct__/0","title":"GenLSP.Structures.PublishDiagnosticsClientCapabilities.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.PublishDiagnosticsClientCapabilities.html#t:t/0","title":"GenLSP.Structures.PublishDiagnosticsClientCapabilities.t/0","type":"type"},{"doc":"The publish diagnostic notification's parameters.","ref":"GenLSP.Structures.PublishDiagnosticsParams.html","title":"GenLSP.Structures.PublishDiagnosticsParams","type":"module"},{"doc":"Fields uri: The URI for which diagnostic information is reported. version: Optional the version number of the document the diagnostics are published for. @since 3.15.0 diagnostics: An array of diagnostic information items.","ref":"GenLSP.Structures.PublishDiagnosticsParams.html#__struct__/0","title":"GenLSP.Structures.PublishDiagnosticsParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.PublishDiagnosticsParams.html#t:t/0","title":"GenLSP.Structures.PublishDiagnosticsParams.t/0","type":"type"},{"doc":"A range in a text document expressed as (zero-based) start and end positions. If you want to specify a range that contains a line including the line ending character(s) then use an end position denoting the start of the next line. For example: { start: { line: 5, character: 23 } end : { line 6, character : 0 } }","ref":"GenLSP.Structures.Range.html","title":"GenLSP.Structures.Range","type":"module"},{"doc":"Fields start: The range's start position. end: The range's end position.","ref":"GenLSP.Structures.Range.html#__struct__/0","title":"GenLSP.Structures.Range.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.Range.html#t:t/0","title":"GenLSP.Structures.Range.t/0","type":"type"},{"doc":"Client Capabilities for a {@link ReferencesRequest}.","ref":"GenLSP.Structures.ReferenceClientCapabilities.html","title":"GenLSP.Structures.ReferenceClientCapabilities","type":"module"},{"doc":"Fields dynamic_registration: Whether references supports dynamic registration.","ref":"GenLSP.Structures.ReferenceClientCapabilities.html#__struct__/0","title":"GenLSP.Structures.ReferenceClientCapabilities.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.ReferenceClientCapabilities.html#t:t/0","title":"GenLSP.Structures.ReferenceClientCapabilities.t/0","type":"type"},{"doc":"Value-object that contains additional information when requesting references.","ref":"GenLSP.Structures.ReferenceContext.html","title":"GenLSP.Structures.ReferenceContext","type":"module"},{"doc":"Fields include_declaration: Include the declaration of the current symbol.","ref":"GenLSP.Structures.ReferenceContext.html#__struct__/0","title":"GenLSP.Structures.ReferenceContext.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.ReferenceContext.html#t:t/0","title":"GenLSP.Structures.ReferenceContext.t/0","type":"type"},{"doc":"Reference options.","ref":"GenLSP.Structures.ReferenceOptions.html","title":"GenLSP.Structures.ReferenceOptions","type":"module"},{"doc":"Fields work_done_progress","ref":"GenLSP.Structures.ReferenceOptions.html#__struct__/0","title":"GenLSP.Structures.ReferenceOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.ReferenceOptions.html#t:t/0","title":"GenLSP.Structures.ReferenceOptions.t/0","type":"type"},{"doc":"Parameters for a {@link ReferencesRequest}.","ref":"GenLSP.Structures.ReferenceParams.html","title":"GenLSP.Structures.ReferenceParams","type":"module"},{"doc":"Fields context work_done_token: An optional token that a server can use to report work done progress. partial_result_token: An optional token that a server can use to report partial results (e.g. streaming) to the client. text_document: The text document. position: The position inside the text document.","ref":"GenLSP.Structures.ReferenceParams.html#__struct__/0","title":"GenLSP.Structures.ReferenceParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.ReferenceParams.html#t:t/0","title":"GenLSP.Structures.ReferenceParams.t/0","type":"type"},{"doc":"Registration options for a {@link ReferencesRequest}.","ref":"GenLSP.Structures.ReferenceRegistrationOptions.html","title":"GenLSP.Structures.ReferenceRegistrationOptions","type":"module"},{"doc":"Fields document_selector: A document selector to identify the scope of the registration. If set to null the document selector provided on the client side will be used.","ref":"GenLSP.Structures.ReferenceRegistrationOptions.html#__struct__/0","title":"GenLSP.Structures.ReferenceRegistrationOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.ReferenceRegistrationOptions.html#t:t/0","title":"GenLSP.Structures.ReferenceRegistrationOptions.t/0","type":"type"},{"doc":"General parameters to register for a notification or to register a provider.","ref":"GenLSP.Structures.Registration.html","title":"GenLSP.Structures.Registration","type":"module"},{"doc":"Fields id: The id used to register the request. The id can be used to deregister the request again. method: The method / capability to register for. register_options: Options necessary for the registration.","ref":"GenLSP.Structures.Registration.html#__struct__/0","title":"GenLSP.Structures.Registration.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.Registration.html#t:t/0","title":"GenLSP.Structures.Registration.t/0","type":"type"},{"doc":"","ref":"GenLSP.Structures.RegistrationParams.html","title":"GenLSP.Structures.RegistrationParams","type":"module"},{"doc":"Fields registrations","ref":"GenLSP.Structures.RegistrationParams.html#__struct__/0","title":"GenLSP.Structures.RegistrationParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.RegistrationParams.html#t:t/0","title":"GenLSP.Structures.RegistrationParams.t/0","type":"type"},{"doc":"Client capabilities specific to regular expressions. @since 3.16.0","ref":"GenLSP.Structures.RegularExpressionsClientCapabilities.html","title":"GenLSP.Structures.RegularExpressionsClientCapabilities","type":"module"},{"doc":"Fields engine: The engine's name. version: The engine's version.","ref":"GenLSP.Structures.RegularExpressionsClientCapabilities.html#__struct__/0","title":"GenLSP.Structures.RegularExpressionsClientCapabilities.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.RegularExpressionsClientCapabilities.html#t:t/0","title":"GenLSP.Structures.RegularExpressionsClientCapabilities.t/0","type":"type"},{"doc":"A full diagnostic report with a set of related documents. @since 3.17.0","ref":"GenLSP.Structures.RelatedFullDocumentDiagnosticReport.html","title":"GenLSP.Structures.RelatedFullDocumentDiagnosticReport","type":"module"},{"doc":"Fields related_documents: Diagnostics of related documents. This information is useful in programming languages where code in a file A can generate diagnostics in a file B which A depends on. An example of such a language is C/C++ where marco definitions in a file a.cpp and result in errors in a header file b.hpp. @since 3.17.0 kind: A full document diagnostic report. result_id: An optional result id. If provided it will be sent on the next diagnostic request for the same document. items: The actual items.","ref":"GenLSP.Structures.RelatedFullDocumentDiagnosticReport.html#__struct__/0","title":"GenLSP.Structures.RelatedFullDocumentDiagnosticReport.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.RelatedFullDocumentDiagnosticReport.html#t:t/0","title":"GenLSP.Structures.RelatedFullDocumentDiagnosticReport.t/0","type":"type"},{"doc":"An unchanged diagnostic report with a set of related documents. @since 3.17.0","ref":"GenLSP.Structures.RelatedUnchangedDocumentDiagnosticReport.html","title":"GenLSP.Structures.RelatedUnchangedDocumentDiagnosticReport","type":"module"},{"doc":"Fields related_documents: Diagnostics of related documents. This information is useful in programming languages where code in a file A can generate diagnostics in a file B which A depends on. An example of such a language is C/C++ where marco definitions in a file a.cpp and result in errors in a header file b.hpp. @since 3.17.0 kind: A document diagnostic report indicating no changes to the last result. A server can only return unchanged if result ids are provided. result_id: A result id which will be sent on the next diagnostic request for the same document.","ref":"GenLSP.Structures.RelatedUnchangedDocumentDiagnosticReport.html#__struct__/0","title":"GenLSP.Structures.RelatedUnchangedDocumentDiagnosticReport.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.RelatedUnchangedDocumentDiagnosticReport.html#t:t/0","title":"GenLSP.Structures.RelatedUnchangedDocumentDiagnosticReport.t/0","type":"type"},{"doc":"A relative pattern is a helper to construct glob patterns that are matched relatively to a base URI. The common value for a baseUri is a workspace folder root, but it can be another absolute URI as well. @since 3.17.0","ref":"GenLSP.Structures.RelativePattern.html","title":"GenLSP.Structures.RelativePattern","type":"module"},{"doc":"Fields base_uri: A workspace folder or a base URI to which this pattern will be matched against relatively. pattern: The actual glob pattern;","ref":"GenLSP.Structures.RelativePattern.html#__struct__/0","title":"GenLSP.Structures.RelativePattern.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.RelativePattern.html#t:t/0","title":"GenLSP.Structures.RelativePattern.t/0","type":"type"},{"doc":"","ref":"GenLSP.Structures.RenameClientCapabilities.html","title":"GenLSP.Structures.RenameClientCapabilities","type":"module"},{"doc":"Fields dynamic_registration: Whether rename supports dynamic registration. prepare_support: Client supports testing for validity of rename operations before execution. @since 3.12.0 prepare_support_default_behavior: Client supports the default behavior result. The value indicates the default behavior used by the client. @since 3.16.0 honors_change_annotations: Whether the client honors the change annotations in text edits and resource operations returned via the rename request's workspace edit by for example presenting the workspace edit in the user interface and asking for confirmation. @since 3.16.0","ref":"GenLSP.Structures.RenameClientCapabilities.html#__struct__/0","title":"GenLSP.Structures.RenameClientCapabilities.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.RenameClientCapabilities.html#t:t/0","title":"GenLSP.Structures.RenameClientCapabilities.t/0","type":"type"},{"doc":"Rename file operation","ref":"GenLSP.Structures.RenameFile.html","title":"GenLSP.Structures.RenameFile","type":"module"},{"doc":"Fields kind: A rename old_uri: The old (existing) location. new_uri: The new location. options: Rename options. annotation_id: An optional annotation identifier describing the operation. @since 3.16.0","ref":"GenLSP.Structures.RenameFile.html#__struct__/0","title":"GenLSP.Structures.RenameFile.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.RenameFile.html#t:t/0","title":"GenLSP.Structures.RenameFile.t/0","type":"type"},{"doc":"Rename file options","ref":"GenLSP.Structures.RenameFileOptions.html","title":"GenLSP.Structures.RenameFileOptions","type":"module"},{"doc":"Fields overwrite: Overwrite target if existing. Overwrite wins over ignoreIfExists ignore_if_exists: Ignores if target exists.","ref":"GenLSP.Structures.RenameFileOptions.html#__struct__/0","title":"GenLSP.Structures.RenameFileOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.RenameFileOptions.html#t:t/0","title":"GenLSP.Structures.RenameFileOptions.t/0","type":"type"},{"doc":"The parameters sent in notifications/requests for user-initiated renames of files. @since 3.16.0","ref":"GenLSP.Structures.RenameFilesParams.html","title":"GenLSP.Structures.RenameFilesParams","type":"module"},{"doc":"Fields files: An array of all files/folders renamed in this operation. When a folder is renamed, only the folder will be included, and not its children.","ref":"GenLSP.Structures.RenameFilesParams.html#__struct__/0","title":"GenLSP.Structures.RenameFilesParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.RenameFilesParams.html#t:t/0","title":"GenLSP.Structures.RenameFilesParams.t/0","type":"type"},{"doc":"Provider options for a {@link RenameRequest}.","ref":"GenLSP.Structures.RenameOptions.html","title":"GenLSP.Structures.RenameOptions","type":"module"},{"doc":"Fields prepare_provider: Renames should be checked and tested before being executed. @since version 3.12.0 work_done_progress","ref":"GenLSP.Structures.RenameOptions.html#__struct__/0","title":"GenLSP.Structures.RenameOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.RenameOptions.html#t:t/0","title":"GenLSP.Structures.RenameOptions.t/0","type":"type"},{"doc":"The parameters of a {@link RenameRequest}.","ref":"GenLSP.Structures.RenameParams.html","title":"GenLSP.Structures.RenameParams","type":"module"},{"doc":"Fields text_document: The document to rename. position: The position at which this request was sent. new_name: The new name of the symbol. If the given name is not valid the request must return a {@link ResponseError} with an appropriate message set. work_done_token: An optional token that a server can use to report work done progress.","ref":"GenLSP.Structures.RenameParams.html#__struct__/0","title":"GenLSP.Structures.RenameParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.RenameParams.html#t:t/0","title":"GenLSP.Structures.RenameParams.t/0","type":"type"},{"doc":"Registration options for a {@link RenameRequest}.","ref":"GenLSP.Structures.RenameRegistrationOptions.html","title":"GenLSP.Structures.RenameRegistrationOptions","type":"module"},{"doc":"Fields document_selector: A document selector to identify the scope of the registration. If set to null the document selector provided on the client side will be used. prepare_provider: Renames should be checked and tested before being executed. @since version 3.12.0","ref":"GenLSP.Structures.RenameRegistrationOptions.html#__struct__/0","title":"GenLSP.Structures.RenameRegistrationOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.RenameRegistrationOptions.html#t:t/0","title":"GenLSP.Structures.RenameRegistrationOptions.t/0","type":"type"},{"doc":"A generic resource operation.","ref":"GenLSP.Structures.ResourceOperation.html","title":"GenLSP.Structures.ResourceOperation","type":"module"},{"doc":"Fields kind: The resource operation kind. annotation_id: An optional annotation identifier describing the operation. @since 3.16.0","ref":"GenLSP.Structures.ResourceOperation.html#__struct__/0","title":"GenLSP.Structures.ResourceOperation.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.ResourceOperation.html#t:t/0","title":"GenLSP.Structures.ResourceOperation.t/0","type":"type"},{"doc":"Save options.","ref":"GenLSP.Structures.SaveOptions.html","title":"GenLSP.Structures.SaveOptions","type":"module"},{"doc":"Fields include_text: The client is supposed to include the content on save.","ref":"GenLSP.Structures.SaveOptions.html#__struct__/0","title":"GenLSP.Structures.SaveOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.SaveOptions.html#t:t/0","title":"GenLSP.Structures.SaveOptions.t/0","type":"type"},{"doc":"A selection range represents a part of a selection hierarchy. A selection range may have a parent selection range that contains it.","ref":"GenLSP.Structures.SelectionRange.html","title":"GenLSP.Structures.SelectionRange","type":"module"},{"doc":"Fields range: The {@link Range range} of this selection range. parent: The parent selection range containing this range. Therefore parent.range must contain this.range .","ref":"GenLSP.Structures.SelectionRange.html#__struct__/0","title":"GenLSP.Structures.SelectionRange.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.SelectionRange.html#t:t/0","title":"GenLSP.Structures.SelectionRange.t/0","type":"type"},{"doc":"","ref":"GenLSP.Structures.SelectionRangeClientCapabilities.html","title":"GenLSP.Structures.SelectionRangeClientCapabilities","type":"module"},{"doc":"Fields dynamic_registration: Whether implementation supports dynamic registration for selection range providers. If this is set to true the client supports the new SelectionRangeRegistrationOptions return value for the corresponding server capability as well.","ref":"GenLSP.Structures.SelectionRangeClientCapabilities.html#__struct__/0","title":"GenLSP.Structures.SelectionRangeClientCapabilities.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.SelectionRangeClientCapabilities.html#t:t/0","title":"GenLSP.Structures.SelectionRangeClientCapabilities.t/0","type":"type"},{"doc":"","ref":"GenLSP.Structures.SelectionRangeOptions.html","title":"GenLSP.Structures.SelectionRangeOptions","type":"module"},{"doc":"Fields work_done_progress","ref":"GenLSP.Structures.SelectionRangeOptions.html#__struct__/0","title":"GenLSP.Structures.SelectionRangeOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.SelectionRangeOptions.html#t:t/0","title":"GenLSP.Structures.SelectionRangeOptions.t/0","type":"type"},{"doc":"A parameter literal used in selection range requests.","ref":"GenLSP.Structures.SelectionRangeParams.html","title":"GenLSP.Structures.SelectionRangeParams","type":"module"},{"doc":"Fields text_document: The text document. positions: The positions inside the text document. work_done_token: An optional token that a server can use to report work done progress. partial_result_token: An optional token that a server can use to report partial results (e.g. streaming) to the client.","ref":"GenLSP.Structures.SelectionRangeParams.html#__struct__/0","title":"GenLSP.Structures.SelectionRangeParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.SelectionRangeParams.html#t:t/0","title":"GenLSP.Structures.SelectionRangeParams.t/0","type":"type"},{"doc":"","ref":"GenLSP.Structures.SelectionRangeRegistrationOptions.html","title":"GenLSP.Structures.SelectionRangeRegistrationOptions","type":"module"},{"doc":"Fields id: The id used to register the request. The id can be used to deregister the request again. See also Registration#id. document_selector: A document selector to identify the scope of the registration. If set to null the document selector provided on the client side will be used.","ref":"GenLSP.Structures.SelectionRangeRegistrationOptions.html#__struct__/0","title":"GenLSP.Structures.SelectionRangeRegistrationOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.SelectionRangeRegistrationOptions.html#t:t/0","title":"GenLSP.Structures.SelectionRangeRegistrationOptions.t/0","type":"type"},{"doc":"@since 3.16.0","ref":"GenLSP.Structures.SemanticTokens.html","title":"GenLSP.Structures.SemanticTokens","type":"module"},{"doc":"Fields result_id: An optional result id. If provided and clients support delta updating the client will include the result id in the next semantic token request. A server can then instead of computing all semantic tokens again simply send a delta. data: The actual tokens.","ref":"GenLSP.Structures.SemanticTokens.html#__struct__/0","title":"GenLSP.Structures.SemanticTokens.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.SemanticTokens.html#t:t/0","title":"GenLSP.Structures.SemanticTokens.t/0","type":"type"},{"doc":"@since 3.16.0","ref":"GenLSP.Structures.SemanticTokensClientCapabilities.html","title":"GenLSP.Structures.SemanticTokensClientCapabilities","type":"module"},{"doc":"Fields dynamic_registration: Whether implementation supports dynamic registration. If this is set to true the client supports the new (TextDocumentRegistrationOptions &amp; StaticRegistrationOptions) return value for the corresponding server capability as well. requests: Which requests the client supports and might send to the server depending on the server's capability. Please note that clients might not show semantic tokens or degrade some of the user experience if a range or full request is advertised by the client but not provided by the server. If for example the client capability requests.full and request.range are both set to true but the server only provides a range provider the client might not render a minimap correctly or might even decide to not show any semantic tokens at all. token_types: The token types that the client supports. token_modifiers: The token modifiers that the client supports. formats: The token formats the clients supports. overlapping_token_support: Whether the client supports tokens that can overlap each other. multiline_token_support: Whether the client supports tokens that can span multiple lines. server_cancel_support: Whether the client allows the server to actively cancel a semantic token request, e.g. supports returning LSPErrorCodes.ServerCancelled. If a server does the client needs to retrigger the request. @since 3.17.0 augments_syntax_tokens: Whether the client uses semantic tokens to augment existing syntax tokens. If set to true client side created syntax tokens and semantic tokens are both used for colorization. If set to false the client only uses the returned semantic tokens for colorization. If the value is undefined then the client behavior is not specified. @since 3.17.0","ref":"GenLSP.Structures.SemanticTokensClientCapabilities.html#__struct__/0","title":"GenLSP.Structures.SemanticTokensClientCapabilities.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.SemanticTokensClientCapabilities.html#t:t/0","title":"GenLSP.Structures.SemanticTokensClientCapabilities.t/0","type":"type"},{"doc":"@since 3.16.0","ref":"GenLSP.Structures.SemanticTokensDelta.html","title":"GenLSP.Structures.SemanticTokensDelta","type":"module"},{"doc":"Fields result_id edits: The semantic token edits to transform a previous result into a new result.","ref":"GenLSP.Structures.SemanticTokensDelta.html#__struct__/0","title":"GenLSP.Structures.SemanticTokensDelta.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.SemanticTokensDelta.html#t:t/0","title":"GenLSP.Structures.SemanticTokensDelta.t/0","type":"type"},{"doc":"@since 3.16.0","ref":"GenLSP.Structures.SemanticTokensDeltaParams.html","title":"GenLSP.Structures.SemanticTokensDeltaParams","type":"module"},{"doc":"Fields text_document: The text document. previous_result_id: The result id of a previous response. The result Id can either point to a full response or a delta response depending on what was received last. work_done_token: An optional token that a server can use to report work done progress. partial_result_token: An optional token that a server can use to report partial results (e.g. streaming) to the client.","ref":"GenLSP.Structures.SemanticTokensDeltaParams.html#__struct__/0","title":"GenLSP.Structures.SemanticTokensDeltaParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.SemanticTokensDeltaParams.html#t:t/0","title":"GenLSP.Structures.SemanticTokensDeltaParams.t/0","type":"type"},{"doc":"@since 3.16.0","ref":"GenLSP.Structures.SemanticTokensDeltaPartialResult.html","title":"GenLSP.Structures.SemanticTokensDeltaPartialResult","type":"module"},{"doc":"Fields edits","ref":"GenLSP.Structures.SemanticTokensDeltaPartialResult.html#__struct__/0","title":"GenLSP.Structures.SemanticTokensDeltaPartialResult.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.SemanticTokensDeltaPartialResult.html#t:t/0","title":"GenLSP.Structures.SemanticTokensDeltaPartialResult.t/0","type":"type"},{"doc":"@since 3.16.0","ref":"GenLSP.Structures.SemanticTokensEdit.html","title":"GenLSP.Structures.SemanticTokensEdit","type":"module"},{"doc":"Fields start: The start offset of the edit. delete_count: The count of elements to remove. data: The elements to insert.","ref":"GenLSP.Structures.SemanticTokensEdit.html#__struct__/0","title":"GenLSP.Structures.SemanticTokensEdit.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.SemanticTokensEdit.html#t:t/0","title":"GenLSP.Structures.SemanticTokensEdit.t/0","type":"type"},{"doc":"@since 3.16.0","ref":"GenLSP.Structures.SemanticTokensLegend.html","title":"GenLSP.Structures.SemanticTokensLegend","type":"module"},{"doc":"Fields token_types: The token types a server uses. token_modifiers: The token modifiers a server uses.","ref":"GenLSP.Structures.SemanticTokensLegend.html#__struct__/0","title":"GenLSP.Structures.SemanticTokensLegend.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.SemanticTokensLegend.html#t:t/0","title":"GenLSP.Structures.SemanticTokensLegend.t/0","type":"type"},{"doc":"@since 3.16.0","ref":"GenLSP.Structures.SemanticTokensOptions.html","title":"GenLSP.Structures.SemanticTokensOptions","type":"module"},{"doc":"Fields legend: The legend used by the server range: Server supports providing semantic tokens for a specific range of a document. full: Server supports providing semantic tokens for a full document. work_done_progress","ref":"GenLSP.Structures.SemanticTokensOptions.html#__struct__/0","title":"GenLSP.Structures.SemanticTokensOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.SemanticTokensOptions.html#t:t/0","title":"GenLSP.Structures.SemanticTokensOptions.t/0","type":"type"},{"doc":"@since 3.16.0","ref":"GenLSP.Structures.SemanticTokensParams.html","title":"GenLSP.Structures.SemanticTokensParams","type":"module"},{"doc":"Fields text_document: The text document. work_done_token: An optional token that a server can use to report work done progress. partial_result_token: An optional token that a server can use to report partial results (e.g. streaming) to the client.","ref":"GenLSP.Structures.SemanticTokensParams.html#__struct__/0","title":"GenLSP.Structures.SemanticTokensParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.SemanticTokensParams.html#t:t/0","title":"GenLSP.Structures.SemanticTokensParams.t/0","type":"type"},{"doc":"@since 3.16.0","ref":"GenLSP.Structures.SemanticTokensPartialResult.html","title":"GenLSP.Structures.SemanticTokensPartialResult","type":"module"},{"doc":"Fields data","ref":"GenLSP.Structures.SemanticTokensPartialResult.html#__struct__/0","title":"GenLSP.Structures.SemanticTokensPartialResult.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.SemanticTokensPartialResult.html#t:t/0","title":"GenLSP.Structures.SemanticTokensPartialResult.t/0","type":"type"},{"doc":"@since 3.16.0","ref":"GenLSP.Structures.SemanticTokensRangeParams.html","title":"GenLSP.Structures.SemanticTokensRangeParams","type":"module"},{"doc":"Fields text_document: The text document. range: The range the semantic tokens are requested for. work_done_token: An optional token that a server can use to report work done progress. partial_result_token: An optional token that a server can use to report partial results (e.g. streaming) to the client.","ref":"GenLSP.Structures.SemanticTokensRangeParams.html#__struct__/0","title":"GenLSP.Structures.SemanticTokensRangeParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.SemanticTokensRangeParams.html#t:t/0","title":"GenLSP.Structures.SemanticTokensRangeParams.t/0","type":"type"},{"doc":"@since 3.16.0","ref":"GenLSP.Structures.SemanticTokensRegistrationOptions.html","title":"GenLSP.Structures.SemanticTokensRegistrationOptions","type":"module"},{"doc":"Fields id: The id used to register the request. The id can be used to deregister the request again. See also Registration#id. document_selector: A document selector to identify the scope of the registration. If set to null the document selector provided on the client side will be used. legend: The legend used by the server range: Server supports providing semantic tokens for a specific range of a document. full: Server supports providing semantic tokens for a full document.","ref":"GenLSP.Structures.SemanticTokensRegistrationOptions.html#__struct__/0","title":"GenLSP.Structures.SemanticTokensRegistrationOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.SemanticTokensRegistrationOptions.html#t:t/0","title":"GenLSP.Structures.SemanticTokensRegistrationOptions.t/0","type":"type"},{"doc":"@since 3.16.0","ref":"GenLSP.Structures.SemanticTokensWorkspaceClientCapabilities.html","title":"GenLSP.Structures.SemanticTokensWorkspaceClientCapabilities","type":"module"},{"doc":"Fields refresh_support: Whether the client implementation supports a refresh request sent from the server to the client. Note that this event is global and will force the client to refresh all semantic tokens currently shown. It should be used with absolute care and is useful for situation where a server for example detects a project wide change that requires such a calculation.","ref":"GenLSP.Structures.SemanticTokensWorkspaceClientCapabilities.html#__struct__/0","title":"GenLSP.Structures.SemanticTokensWorkspaceClientCapabilities.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.SemanticTokensWorkspaceClientCapabilities.html#t:t/0","title":"GenLSP.Structures.SemanticTokensWorkspaceClientCapabilities.t/0","type":"type"},{"doc":"Defines the capabilities provided by a language server.","ref":"GenLSP.Structures.ServerCapabilities.html","title":"GenLSP.Structures.ServerCapabilities","type":"module"},{"doc":"Fields position_encoding: The position encoding the server picked from the encodings offered by the client via the client capability general.positionEncodings . If the client didn't provide any position encodings the only valid value that a server can return is 'utf-16'. If omitted it defaults to 'utf-16'. @since 3.17.0 text_document_sync: Defines how text documents are synced. Is either a detailed structure defining each notification or for backwards compatibility the TextDocumentSyncKind number. notebook_document_sync: Defines how notebook documents are synced. @since 3.17.0 completion_provider: The server provides completion support. hover_provider: The server provides hover support. signature_help_provider: The server provides signature help support. declaration_provider: The server provides Goto Declaration support. definition_provider: The server provides goto definition support. type_definition_provider: The server provides Goto Type Definition support. implementation_provider: The server provides Goto Implementation support. references_provider: The server provides find references support. document_highlight_provider: The server provides document highlight support. document_symbol_provider: The server provides document symbol support. code_action_provider: The server provides code actions. CodeActionOptions may only be specified if the client states that it supports codeActionLiteralSupport in its initial initialize request. code_lens_provider: The server provides code lens. document_link_provider: The server provides document link support. color_provider: The server provides color provider support. workspace_symbol_provider: The server provides workspace symbol support. document_formatting_provider: The server provides document formatting. document_range_formatting_provider: The server provides document range formatting. document_on_type_formatting_provider: The server provides document formatting on typing. rename_provider: The server provides rename support. RenameOptions may only be specified if the client states that it supports prepareSupport in its initial initialize request. folding_range_provider: The server provides folding provider support. selection_range_provider: The server provides selection range support. execute_command_provider: The server provides execute command support. call_hierarchy_provider: The server provides call hierarchy support. @since 3.16.0 linked_editing_range_provider: The server provides linked editing range support. @since 3.16.0 semantic_tokens_provider: The server provides semantic tokens support. @since 3.16.0 moniker_provider: The server provides moniker support. @since 3.16.0 type_hierarchy_provider: The server provides type hierarchy support. @since 3.17.0 inline_value_provider: The server provides inline values. @since 3.17.0 inlay_hint_provider: The server provides inlay hints. @since 3.17.0 diagnostic_provider: The server has support for pull model diagnostics. @since 3.17.0 workspace: Workspace specific server capabilities. experimental: Experimental server capabilities.","ref":"GenLSP.Structures.ServerCapabilities.html#__struct__/0","title":"GenLSP.Structures.ServerCapabilities.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.ServerCapabilities.html#t:t/0","title":"GenLSP.Structures.ServerCapabilities.t/0","type":"type"},{"doc":"","ref":"GenLSP.Structures.SetTraceParams.html","title":"GenLSP.Structures.SetTraceParams","type":"module"},{"doc":"Fields value","ref":"GenLSP.Structures.SetTraceParams.html#__struct__/0","title":"GenLSP.Structures.SetTraceParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.SetTraceParams.html#t:t/0","title":"GenLSP.Structures.SetTraceParams.t/0","type":"type"},{"doc":"Client capabilities for the showDocument request. @since 3.16.0","ref":"GenLSP.Structures.ShowDocumentClientCapabilities.html","title":"GenLSP.Structures.ShowDocumentClientCapabilities","type":"module"},{"doc":"Fields support: The client has support for the showDocument request.","ref":"GenLSP.Structures.ShowDocumentClientCapabilities.html#__struct__/0","title":"GenLSP.Structures.ShowDocumentClientCapabilities.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.ShowDocumentClientCapabilities.html#t:t/0","title":"GenLSP.Structures.ShowDocumentClientCapabilities.t/0","type":"type"},{"doc":"Params to show a document. @since 3.16.0","ref":"GenLSP.Structures.ShowDocumentParams.html","title":"GenLSP.Structures.ShowDocumentParams","type":"module"},{"doc":"Fields uri: The document uri to show. external: Indicates to show the resource in an external program. To show for example https://code.visualstudio.com/ in the default WEB browser set external to true . take_focus: An optional property to indicate whether the editor showing the document should take focus or not. Clients might ignore this property if an external program is started. selection: An optional selection range if the document is a text document. Clients might ignore the property if an external program is started or the file is not a text file.","ref":"GenLSP.Structures.ShowDocumentParams.html#__struct__/0","title":"GenLSP.Structures.ShowDocumentParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.ShowDocumentParams.html#t:t/0","title":"GenLSP.Structures.ShowDocumentParams.t/0","type":"type"},{"doc":"The result of a showDocument request. @since 3.16.0","ref":"GenLSP.Structures.ShowDocumentResult.html","title":"GenLSP.Structures.ShowDocumentResult","type":"module"},{"doc":"Fields success: A boolean indicating if the show was successful.","ref":"GenLSP.Structures.ShowDocumentResult.html#__struct__/0","title":"GenLSP.Structures.ShowDocumentResult.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.ShowDocumentResult.html#t:t/0","title":"GenLSP.Structures.ShowDocumentResult.t/0","type":"type"},{"doc":"The parameters of a notification message.","ref":"GenLSP.Structures.ShowMessageParams.html","title":"GenLSP.Structures.ShowMessageParams","type":"module"},{"doc":"Fields type: The message type. See {@link MessageType} message: The actual message.","ref":"GenLSP.Structures.ShowMessageParams.html#__struct__/0","title":"GenLSP.Structures.ShowMessageParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.ShowMessageParams.html#t:t/0","title":"GenLSP.Structures.ShowMessageParams.t/0","type":"type"},{"doc":"Show message request client capabilities","ref":"GenLSP.Structures.ShowMessageRequestClientCapabilities.html","title":"GenLSP.Structures.ShowMessageRequestClientCapabilities","type":"module"},{"doc":"Fields message_action_item: Capabilities specific to the MessageActionItem type.","ref":"GenLSP.Structures.ShowMessageRequestClientCapabilities.html#__struct__/0","title":"GenLSP.Structures.ShowMessageRequestClientCapabilities.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.ShowMessageRequestClientCapabilities.html#t:t/0","title":"GenLSP.Structures.ShowMessageRequestClientCapabilities.t/0","type":"type"},{"doc":"","ref":"GenLSP.Structures.ShowMessageRequestParams.html","title":"GenLSP.Structures.ShowMessageRequestParams","type":"module"},{"doc":"Fields type: The message type. See {@link MessageType} message: The actual message. actions: The message action items to present.","ref":"GenLSP.Structures.ShowMessageRequestParams.html#__struct__/0","title":"GenLSP.Structures.ShowMessageRequestParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.ShowMessageRequestParams.html#t:t/0","title":"GenLSP.Structures.ShowMessageRequestParams.t/0","type":"type"},{"doc":"Signature help represents the signature of something callable. There can be multiple signature but only one active and only one active parameter.","ref":"GenLSP.Structures.SignatureHelp.html","title":"GenLSP.Structures.SignatureHelp","type":"module"},{"doc":"Fields signatures: One or more signatures. active_signature: The active signature. If omitted or the value lies outside the range of signatures the value defaults to zero or is ignored if the SignatureHelp has no signatures. Whenever possible implementors should make an active decision about the active signature and shouldn't rely on a default value. In future version of the protocol this property might become mandatory to better express this. active_parameter: The active parameter of the active signature. If omitted or the value lies outside the range of signatures[activeSignature].parameters defaults to 0 if the active signature has parameters. If the active signature has no parameters it is ignored. In future version of the protocol this property might become mandatory to better express the active parameter if the active signature does have any.","ref":"GenLSP.Structures.SignatureHelp.html#__struct__/0","title":"GenLSP.Structures.SignatureHelp.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.SignatureHelp.html#t:t/0","title":"GenLSP.Structures.SignatureHelp.t/0","type":"type"},{"doc":"Client Capabilities for a {@link SignatureHelpRequest}.","ref":"GenLSP.Structures.SignatureHelpClientCapabilities.html","title":"GenLSP.Structures.SignatureHelpClientCapabilities","type":"module"},{"doc":"Fields dynamic_registration: Whether signature help supports dynamic registration. signature_information: The client supports the following SignatureInformation specific properties. context_support: The client supports to send additional context information for a textDocument/signatureHelp request. A client that opts into contextSupport will also support the retriggerCharacters on SignatureHelpOptions . @since 3.15.0","ref":"GenLSP.Structures.SignatureHelpClientCapabilities.html#__struct__/0","title":"GenLSP.Structures.SignatureHelpClientCapabilities.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.SignatureHelpClientCapabilities.html#t:t/0","title":"GenLSP.Structures.SignatureHelpClientCapabilities.t/0","type":"type"},{"doc":"Additional information about the context in which a signature help request was triggered. @since 3.15.0","ref":"GenLSP.Structures.SignatureHelpContext.html","title":"GenLSP.Structures.SignatureHelpContext","type":"module"},{"doc":"Fields trigger_kind: Action that caused signature help to be triggered. trigger_character: Character that caused signature help to be triggered. This is undefined when triggerKind !== SignatureHelpTriggerKind.TriggerCharacter is_retrigger: true if signature help was already showing when it was triggered. Retriggers occurs when the signature help is already active and can be caused by actions such as typing a trigger character, a cursor move, or document content changes. active_signature_help: The currently active SignatureHelp . The activeSignatureHelp has its SignatureHelp.activeSignature field updated based on the user navigating through available signatures.","ref":"GenLSP.Structures.SignatureHelpContext.html#__struct__/0","title":"GenLSP.Structures.SignatureHelpContext.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.SignatureHelpContext.html#t:t/0","title":"GenLSP.Structures.SignatureHelpContext.t/0","type":"type"},{"doc":"Server Capabilities for a {@link SignatureHelpRequest}.","ref":"GenLSP.Structures.SignatureHelpOptions.html","title":"GenLSP.Structures.SignatureHelpOptions","type":"module"},{"doc":"Fields trigger_characters: List of characters that trigger signature help automatically. retrigger_characters: List of characters that re-trigger signature help. These trigger characters are only active when signature help is already showing. All trigger characters are also counted as re-trigger characters. @since 3.15.0 work_done_progress","ref":"GenLSP.Structures.SignatureHelpOptions.html#__struct__/0","title":"GenLSP.Structures.SignatureHelpOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.SignatureHelpOptions.html#t:t/0","title":"GenLSP.Structures.SignatureHelpOptions.t/0","type":"type"},{"doc":"Parameters for a {@link SignatureHelpRequest}.","ref":"GenLSP.Structures.SignatureHelpParams.html","title":"GenLSP.Structures.SignatureHelpParams","type":"module"},{"doc":"Fields context: The signature help context. This is only available if the client specifies to send this using the client capability textDocument.signatureHelp.contextSupport === true @since 3.15.0 work_done_token: An optional token that a server can use to report work done progress. text_document: The text document. position: The position inside the text document.","ref":"GenLSP.Structures.SignatureHelpParams.html#__struct__/0","title":"GenLSP.Structures.SignatureHelpParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.SignatureHelpParams.html#t:t/0","title":"GenLSP.Structures.SignatureHelpParams.t/0","type":"type"},{"doc":"Registration options for a {@link SignatureHelpRequest}.","ref":"GenLSP.Structures.SignatureHelpRegistrationOptions.html","title":"GenLSP.Structures.SignatureHelpRegistrationOptions","type":"module"},{"doc":"Fields document_selector: A document selector to identify the scope of the registration. If set to null the document selector provided on the client side will be used. trigger_characters: List of characters that trigger signature help automatically. retrigger_characters: List of characters that re-trigger signature help. These trigger characters are only active when signature help is already showing. All trigger characters are also counted as re-trigger characters. @since 3.15.0","ref":"GenLSP.Structures.SignatureHelpRegistrationOptions.html#__struct__/0","title":"GenLSP.Structures.SignatureHelpRegistrationOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.SignatureHelpRegistrationOptions.html#t:t/0","title":"GenLSP.Structures.SignatureHelpRegistrationOptions.t/0","type":"type"},{"doc":"Represents the signature of something callable. A signature can have a label, like a function-name, a doc-comment, and a set of parameters.","ref":"GenLSP.Structures.SignatureInformation.html","title":"GenLSP.Structures.SignatureInformation","type":"module"},{"doc":"Fields label: The label of this signature. Will be shown in the UI. documentation: The human-readable doc-comment of this signature. Will be shown in the UI but can be omitted. parameters: The parameters of this signature. active_parameter: The index of the active parameter. If provided, this is used in place of SignatureHelp.activeParameter . @since 3.16.0","ref":"GenLSP.Structures.SignatureInformation.html#__struct__/0","title":"GenLSP.Structures.SignatureInformation.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.SignatureInformation.html#t:t/0","title":"GenLSP.Structures.SignatureInformation.t/0","type":"type"},{"doc":"Static registration options to be returned in the initialize request.","ref":"GenLSP.Structures.StaticRegistrationOptions.html","title":"GenLSP.Structures.StaticRegistrationOptions","type":"module"},{"doc":"Fields id: The id used to register the request. The id can be used to deregister the request again. See also Registration#id.","ref":"GenLSP.Structures.StaticRegistrationOptions.html#__struct__/0","title":"GenLSP.Structures.StaticRegistrationOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.StaticRegistrationOptions.html#t:t/0","title":"GenLSP.Structures.StaticRegistrationOptions.t/0","type":"type"},{"doc":"Represents information about programming constructs like variables, classes, interfaces etc.","ref":"GenLSP.Structures.SymbolInformation.html","title":"GenLSP.Structures.SymbolInformation","type":"module"},{"doc":"Fields deprecated: Indicates if this symbol is deprecated. @deprecated Use tags instead location: The location of this symbol. The location's range is used by a tool to reveal the location in the editor. If the symbol is selected in the tool the range's start information is used to position the cursor. So the range usually spans more than the actual symbol's name and does normally include things like visibility modifiers. The range doesn't have to denote a node range in the sense of an abstract syntax tree. It can therefore not be used to re-construct a hierarchy of the symbols. name: The name of this symbol. kind: The kind of this symbol. tags: Tags for this symbol. @since 3.16.0 container_name: The name of the symbol containing this symbol. This information is for user interface purposes (e.g. to render a qualifier in the user interface if necessary). It can't be used to re-infer a hierarchy for the document symbols.","ref":"GenLSP.Structures.SymbolInformation.html#__struct__/0","title":"GenLSP.Structures.SymbolInformation.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.SymbolInformation.html#t:t/0","title":"GenLSP.Structures.SymbolInformation.t/0","type":"type"},{"doc":"Describe options to be used when registered for text document change events.","ref":"GenLSP.Structures.TextDocumentChangeRegistrationOptions.html","title":"GenLSP.Structures.TextDocumentChangeRegistrationOptions","type":"module"},{"doc":"Fields sync_kind: How documents are synced to the server. document_selector: A document selector to identify the scope of the registration. If set to null the document selector provided on the client side will be used.","ref":"GenLSP.Structures.TextDocumentChangeRegistrationOptions.html#__struct__/0","title":"GenLSP.Structures.TextDocumentChangeRegistrationOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.TextDocumentChangeRegistrationOptions.html#t:t/0","title":"GenLSP.Structures.TextDocumentChangeRegistrationOptions.t/0","type":"type"},{"doc":"Text document specific client capabilities.","ref":"GenLSP.Structures.TextDocumentClientCapabilities.html","title":"GenLSP.Structures.TextDocumentClientCapabilities","type":"module"},{"doc":"Fields synchronization: Defines which synchronization capabilities the client supports. completion: Capabilities specific to the textDocument/completion request. hover: Capabilities specific to the textDocument/hover request. signature_help: Capabilities specific to the textDocument/signatureHelp request. declaration: Capabilities specific to the textDocument/declaration request. @since 3.14.0 definition: Capabilities specific to the textDocument/definition request. type_definition: Capabilities specific to the textDocument/typeDefinition request. @since 3.6.0 implementation: Capabilities specific to the textDocument/implementation request. @since 3.6.0 references: Capabilities specific to the textDocument/references request. document_highlight: Capabilities specific to the textDocument/documentHighlight request. document_symbol: Capabilities specific to the textDocument/documentSymbol request. code_action: Capabilities specific to the textDocument/codeAction request. code_lens: Capabilities specific to the textDocument/codeLens request. document_link: Capabilities specific to the textDocument/documentLink request. color_provider: Capabilities specific to the textDocument/documentColor and the textDocument/colorPresentation request. @since 3.6.0 formatting: Capabilities specific to the textDocument/formatting request. range_formatting: Capabilities specific to the textDocument/rangeFormatting request. on_type_formatting: Capabilities specific to the textDocument/onTypeFormatting request. rename: Capabilities specific to the textDocument/rename request. folding_range: Capabilities specific to the textDocument/foldingRange request. @since 3.10.0 selection_range: Capabilities specific to the textDocument/selectionRange request. @since 3.15.0 publish_diagnostics: Capabilities specific to the textDocument/publishDiagnostics notification. call_hierarchy: Capabilities specific to the various call hierarchy requests. @since 3.16.0 semantic_tokens: Capabilities specific to the various semantic token request. @since 3.16.0 linked_editing_range: Capabilities specific to the textDocument/linkedEditingRange request. @since 3.16.0 moniker: Client capabilities specific to the textDocument/moniker request. @since 3.16.0 type_hierarchy: Capabilities specific to the various type hierarchy requests. @since 3.17.0 inline_value: Capabilities specific to the textDocument/inlineValue request. @since 3.17.0 inlay_hint: Capabilities specific to the textDocument/inlayHint request. @since 3.17.0 diagnostic: Capabilities specific to the diagnostic pull model. @since 3.17.0","ref":"GenLSP.Structures.TextDocumentClientCapabilities.html#__struct__/0","title":"GenLSP.Structures.TextDocumentClientCapabilities.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.TextDocumentClientCapabilities.html#t:t/0","title":"GenLSP.Structures.TextDocumentClientCapabilities.t/0","type":"type"},{"doc":"Describes textual changes on a text document. A TextDocumentEdit describes all changes on a document version Si and after they are applied move the document to version Si+1. So the creator of a TextDocumentEdit doesn't need to sort the array of edits or do any kind of ordering. However the edits must be non overlapping.","ref":"GenLSP.Structures.TextDocumentEdit.html","title":"GenLSP.Structures.TextDocumentEdit","type":"module"},{"doc":"Fields text_document: The text document to change. edits: The edits to be applied. @since 3.16.0 - support for AnnotatedTextEdit. This is guarded using a client capability.","ref":"GenLSP.Structures.TextDocumentEdit.html#__struct__/0","title":"GenLSP.Structures.TextDocumentEdit.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.TextDocumentEdit.html#t:t/0","title":"GenLSP.Structures.TextDocumentEdit.t/0","type":"type"},{"doc":"A literal to identify a text document in the client.","ref":"GenLSP.Structures.TextDocumentIdentifier.html","title":"GenLSP.Structures.TextDocumentIdentifier","type":"module"},{"doc":"Fields uri: The text document's uri.","ref":"GenLSP.Structures.TextDocumentIdentifier.html#__struct__/0","title":"GenLSP.Structures.TextDocumentIdentifier.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.TextDocumentIdentifier.html#t:t/0","title":"GenLSP.Structures.TextDocumentIdentifier.t/0","type":"type"},{"doc":"An item to transfer a text document from the client to the server.","ref":"GenLSP.Structures.TextDocumentItem.html","title":"GenLSP.Structures.TextDocumentItem","type":"module"},{"doc":"Fields uri: The text document's uri. language_id: The text document's language identifier. version: The version number of this document (it will increase after each change, including undo/redo). text: The content of the opened text document.","ref":"GenLSP.Structures.TextDocumentItem.html#__struct__/0","title":"GenLSP.Structures.TextDocumentItem.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.TextDocumentItem.html#t:t/0","title":"GenLSP.Structures.TextDocumentItem.t/0","type":"type"},{"doc":"A parameter literal used in requests to pass a text document and a position inside that document.","ref":"GenLSP.Structures.TextDocumentPositionParams.html","title":"GenLSP.Structures.TextDocumentPositionParams","type":"module"},{"doc":"Fields text_document: The text document. position: The position inside the text document.","ref":"GenLSP.Structures.TextDocumentPositionParams.html#__struct__/0","title":"GenLSP.Structures.TextDocumentPositionParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.TextDocumentPositionParams.html#t:t/0","title":"GenLSP.Structures.TextDocumentPositionParams.t/0","type":"type"},{"doc":"General text document registration options.","ref":"GenLSP.Structures.TextDocumentRegistrationOptions.html","title":"GenLSP.Structures.TextDocumentRegistrationOptions","type":"module"},{"doc":"Fields document_selector: A document selector to identify the scope of the registration. If set to null the document selector provided on the client side will be used.","ref":"GenLSP.Structures.TextDocumentRegistrationOptions.html#__struct__/0","title":"GenLSP.Structures.TextDocumentRegistrationOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.TextDocumentRegistrationOptions.html#t:t/0","title":"GenLSP.Structures.TextDocumentRegistrationOptions.t/0","type":"type"},{"doc":"Save registration options.","ref":"GenLSP.Structures.TextDocumentSaveRegistrationOptions.html","title":"GenLSP.Structures.TextDocumentSaveRegistrationOptions","type":"module"},{"doc":"Fields document_selector: A document selector to identify the scope of the registration. If set to null the document selector provided on the client side will be used. include_text: The client is supposed to include the content on save.","ref":"GenLSP.Structures.TextDocumentSaveRegistrationOptions.html#__struct__/0","title":"GenLSP.Structures.TextDocumentSaveRegistrationOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.TextDocumentSaveRegistrationOptions.html#t:t/0","title":"GenLSP.Structures.TextDocumentSaveRegistrationOptions.t/0","type":"type"},{"doc":"","ref":"GenLSP.Structures.TextDocumentSyncClientCapabilities.html","title":"GenLSP.Structures.TextDocumentSyncClientCapabilities","type":"module"},{"doc":"Fields dynamic_registration: Whether text document synchronization supports dynamic registration. will_save: The client supports sending will save notifications. will_save_wait_until: The client supports sending a will save request and waits for a response providing text edits which will be applied to the document before it is saved. did_save: The client supports did save notifications.","ref":"GenLSP.Structures.TextDocumentSyncClientCapabilities.html#__struct__/0","title":"GenLSP.Structures.TextDocumentSyncClientCapabilities.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.TextDocumentSyncClientCapabilities.html#t:t/0","title":"GenLSP.Structures.TextDocumentSyncClientCapabilities.t/0","type":"type"},{"doc":"","ref":"GenLSP.Structures.TextDocumentSyncOptions.html","title":"GenLSP.Structures.TextDocumentSyncOptions","type":"module"},{"doc":"Fields open_close: Open and close notifications are sent to the server. If omitted open close notification should not be sent. change: Change notifications are sent to the server. See TextDocumentSyncKind.None, TextDocumentSyncKind.Full and TextDocumentSyncKind.Incremental. If omitted it defaults to TextDocumentSyncKind.None. will_save: If present will save notifications are sent to the server. If omitted the notification should not be sent. will_save_wait_until: If present will save wait until requests are sent to the server. If omitted the request should not be sent. save: If present save notifications are sent to the server. If omitted the notification should not be sent.","ref":"GenLSP.Structures.TextDocumentSyncOptions.html#__struct__/0","title":"GenLSP.Structures.TextDocumentSyncOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.TextDocumentSyncOptions.html#t:t/0","title":"GenLSP.Structures.TextDocumentSyncOptions.t/0","type":"type"},{"doc":"A text edit applicable to a text document.","ref":"GenLSP.Structures.TextEdit.html","title":"GenLSP.Structures.TextEdit","type":"module"},{"doc":"Fields range: The range of the text document to be manipulated. To insert text into a document create a range where start === end. new_text: The string to be inserted. For delete operations use an empty string.","ref":"GenLSP.Structures.TextEdit.html#__struct__/0","title":"GenLSP.Structures.TextEdit.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.TextEdit.html#t:t/0","title":"GenLSP.Structures.TextEdit.t/0","type":"type"},{"doc":"Since 3.6.0","ref":"GenLSP.Structures.TypeDefinitionClientCapabilities.html","title":"GenLSP.Structures.TypeDefinitionClientCapabilities","type":"module"},{"doc":"Fields dynamic_registration: Whether implementation supports dynamic registration. If this is set to true the client supports the new TypeDefinitionRegistrationOptions return value for the corresponding server capability as well. link_support: The client supports additional metadata in the form of definition links. Since 3.14.0","ref":"GenLSP.Structures.TypeDefinitionClientCapabilities.html#__struct__/0","title":"GenLSP.Structures.TypeDefinitionClientCapabilities.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.TypeDefinitionClientCapabilities.html#t:t/0","title":"GenLSP.Structures.TypeDefinitionClientCapabilities.t/0","type":"type"},{"doc":"","ref":"GenLSP.Structures.TypeDefinitionOptions.html","title":"GenLSP.Structures.TypeDefinitionOptions","type":"module"},{"doc":"Fields work_done_progress","ref":"GenLSP.Structures.TypeDefinitionOptions.html#__struct__/0","title":"GenLSP.Structures.TypeDefinitionOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.TypeDefinitionOptions.html#t:t/0","title":"GenLSP.Structures.TypeDefinitionOptions.t/0","type":"type"},{"doc":"","ref":"GenLSP.Structures.TypeDefinitionParams.html","title":"GenLSP.Structures.TypeDefinitionParams","type":"module"},{"doc":"Fields work_done_token: An optional token that a server can use to report work done progress. partial_result_token: An optional token that a server can use to report partial results (e.g. streaming) to the client. text_document: The text document. position: The position inside the text document.","ref":"GenLSP.Structures.TypeDefinitionParams.html#__struct__/0","title":"GenLSP.Structures.TypeDefinitionParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.TypeDefinitionParams.html#t:t/0","title":"GenLSP.Structures.TypeDefinitionParams.t/0","type":"type"},{"doc":"","ref":"GenLSP.Structures.TypeDefinitionRegistrationOptions.html","title":"GenLSP.Structures.TypeDefinitionRegistrationOptions","type":"module"},{"doc":"Fields id: The id used to register the request. The id can be used to deregister the request again. See also Registration#id. document_selector: A document selector to identify the scope of the registration. If set to null the document selector provided on the client side will be used.","ref":"GenLSP.Structures.TypeDefinitionRegistrationOptions.html#__struct__/0","title":"GenLSP.Structures.TypeDefinitionRegistrationOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.TypeDefinitionRegistrationOptions.html#t:t/0","title":"GenLSP.Structures.TypeDefinitionRegistrationOptions.t/0","type":"type"},{"doc":"@since 3.17.0","ref":"GenLSP.Structures.TypeHierarchyClientCapabilities.html","title":"GenLSP.Structures.TypeHierarchyClientCapabilities","type":"module"},{"doc":"Fields dynamic_registration: Whether implementation supports dynamic registration. If this is set to true the client supports the new (TextDocumentRegistrationOptions &amp; StaticRegistrationOptions) return value for the corresponding server capability as well.","ref":"GenLSP.Structures.TypeHierarchyClientCapabilities.html#__struct__/0","title":"GenLSP.Structures.TypeHierarchyClientCapabilities.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.TypeHierarchyClientCapabilities.html#t:t/0","title":"GenLSP.Structures.TypeHierarchyClientCapabilities.t/0","type":"type"},{"doc":"@since 3.17.0","ref":"GenLSP.Structures.TypeHierarchyItem.html","title":"GenLSP.Structures.TypeHierarchyItem","type":"module"},{"doc":"Fields name: The name of this item. kind: The kind of this item. tags: Tags for this item. detail: More detail for this item, e.g. the signature of a function. uri: The resource identifier of this item. range: The range enclosing this symbol not including leading/trailing whitespace but everything else, e.g. comments and code. selection_range: The range that should be selected and revealed when this symbol is being picked, e.g. the name of a function. Must be contained by the {@link TypeHierarchyItem.range range }. data: A data entry field that is preserved between a type hierarchy prepare and supertypes or subtypes requests. It could also be used to identify the type hierarchy in the server, helping improve the performance on resolving supertypes and subtypes.","ref":"GenLSP.Structures.TypeHierarchyItem.html#__struct__/0","title":"GenLSP.Structures.TypeHierarchyItem.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.TypeHierarchyItem.html#t:t/0","title":"GenLSP.Structures.TypeHierarchyItem.t/0","type":"type"},{"doc":"Type hierarchy options used during static registration. @since 3.17.0","ref":"GenLSP.Structures.TypeHierarchyOptions.html","title":"GenLSP.Structures.TypeHierarchyOptions","type":"module"},{"doc":"Fields work_done_progress","ref":"GenLSP.Structures.TypeHierarchyOptions.html#__struct__/0","title":"GenLSP.Structures.TypeHierarchyOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.TypeHierarchyOptions.html#t:t/0","title":"GenLSP.Structures.TypeHierarchyOptions.t/0","type":"type"},{"doc":"The parameter of a textDocument/prepareTypeHierarchy request. @since 3.17.0","ref":"GenLSP.Structures.TypeHierarchyPrepareParams.html","title":"GenLSP.Structures.TypeHierarchyPrepareParams","type":"module"},{"doc":"Fields work_done_token: An optional token that a server can use to report work done progress. text_document: The text document. position: The position inside the text document.","ref":"GenLSP.Structures.TypeHierarchyPrepareParams.html#__struct__/0","title":"GenLSP.Structures.TypeHierarchyPrepareParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.TypeHierarchyPrepareParams.html#t:t/0","title":"GenLSP.Structures.TypeHierarchyPrepareParams.t/0","type":"type"},{"doc":"Type hierarchy options used during static or dynamic registration. @since 3.17.0","ref":"GenLSP.Structures.TypeHierarchyRegistrationOptions.html","title":"GenLSP.Structures.TypeHierarchyRegistrationOptions","type":"module"},{"doc":"Fields id: The id used to register the request. The id can be used to deregister the request again. See also Registration#id. document_selector: A document selector to identify the scope of the registration. If set to null the document selector provided on the client side will be used.","ref":"GenLSP.Structures.TypeHierarchyRegistrationOptions.html#__struct__/0","title":"GenLSP.Structures.TypeHierarchyRegistrationOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.TypeHierarchyRegistrationOptions.html#t:t/0","title":"GenLSP.Structures.TypeHierarchyRegistrationOptions.t/0","type":"type"},{"doc":"The parameter of a typeHierarchy/subtypes request. @since 3.17.0","ref":"GenLSP.Structures.TypeHierarchySubtypesParams.html","title":"GenLSP.Structures.TypeHierarchySubtypesParams","type":"module"},{"doc":"Fields item work_done_token: An optional token that a server can use to report work done progress. partial_result_token: An optional token that a server can use to report partial results (e.g. streaming) to the client.","ref":"GenLSP.Structures.TypeHierarchySubtypesParams.html#__struct__/0","title":"GenLSP.Structures.TypeHierarchySubtypesParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.TypeHierarchySubtypesParams.html#t:t/0","title":"GenLSP.Structures.TypeHierarchySubtypesParams.t/0","type":"type"},{"doc":"The parameter of a typeHierarchy/supertypes request. @since 3.17.0","ref":"GenLSP.Structures.TypeHierarchySupertypesParams.html","title":"GenLSP.Structures.TypeHierarchySupertypesParams","type":"module"},{"doc":"Fields item work_done_token: An optional token that a server can use to report work done progress. partial_result_token: An optional token that a server can use to report partial results (e.g. streaming) to the client.","ref":"GenLSP.Structures.TypeHierarchySupertypesParams.html#__struct__/0","title":"GenLSP.Structures.TypeHierarchySupertypesParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.TypeHierarchySupertypesParams.html#t:t/0","title":"GenLSP.Structures.TypeHierarchySupertypesParams.t/0","type":"type"},{"doc":"A diagnostic report indicating that the last returned report is still accurate. @since 3.17.0","ref":"GenLSP.Structures.UnchangedDocumentDiagnosticReport.html","title":"GenLSP.Structures.UnchangedDocumentDiagnosticReport","type":"module"},{"doc":"Fields kind: A document diagnostic report indicating no changes to the last result. A server can only return unchanged if result ids are provided. result_id: A result id which will be sent on the next diagnostic request for the same document.","ref":"GenLSP.Structures.UnchangedDocumentDiagnosticReport.html#__struct__/0","title":"GenLSP.Structures.UnchangedDocumentDiagnosticReport.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.UnchangedDocumentDiagnosticReport.html#t:t/0","title":"GenLSP.Structures.UnchangedDocumentDiagnosticReport.t/0","type":"type"},{"doc":"General parameters to unregister a request or notification.","ref":"GenLSP.Structures.Unregistration.html","title":"GenLSP.Structures.Unregistration","type":"module"},{"doc":"Fields id: The id used to unregister the request or notification. Usually an id provided during the register request. method: The method to unregister for.","ref":"GenLSP.Structures.Unregistration.html#__struct__/0","title":"GenLSP.Structures.Unregistration.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.Unregistration.html#t:t/0","title":"GenLSP.Structures.Unregistration.t/0","type":"type"},{"doc":"","ref":"GenLSP.Structures.UnregistrationParams.html","title":"GenLSP.Structures.UnregistrationParams","type":"module"},{"doc":"Fields unregisterations","ref":"GenLSP.Structures.UnregistrationParams.html#__struct__/0","title":"GenLSP.Structures.UnregistrationParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.UnregistrationParams.html#t:t/0","title":"GenLSP.Structures.UnregistrationParams.t/0","type":"type"},{"doc":"A versioned notebook document identifier. @since 3.17.0","ref":"GenLSP.Structures.VersionedNotebookDocumentIdentifier.html","title":"GenLSP.Structures.VersionedNotebookDocumentIdentifier","type":"module"},{"doc":"Fields version: The version number of this notebook document. uri: The notebook document's uri.","ref":"GenLSP.Structures.VersionedNotebookDocumentIdentifier.html#__struct__/0","title":"GenLSP.Structures.VersionedNotebookDocumentIdentifier.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.VersionedNotebookDocumentIdentifier.html#t:t/0","title":"GenLSP.Structures.VersionedNotebookDocumentIdentifier.t/0","type":"type"},{"doc":"A text document identifier to denote a specific version of a text document.","ref":"GenLSP.Structures.VersionedTextDocumentIdentifier.html","title":"GenLSP.Structures.VersionedTextDocumentIdentifier","type":"module"},{"doc":"Fields version: The version number of this document. uri: The text document's uri.","ref":"GenLSP.Structures.VersionedTextDocumentIdentifier.html#__struct__/0","title":"GenLSP.Structures.VersionedTextDocumentIdentifier.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.VersionedTextDocumentIdentifier.html#t:t/0","title":"GenLSP.Structures.VersionedTextDocumentIdentifier.t/0","type":"type"},{"doc":"The parameters sent in a will save text document notification.","ref":"GenLSP.Structures.WillSaveTextDocumentParams.html","title":"GenLSP.Structures.WillSaveTextDocumentParams","type":"module"},{"doc":"Fields text_document: The document that will be saved. reason: The 'TextDocumentSaveReason'.","ref":"GenLSP.Structures.WillSaveTextDocumentParams.html#__struct__/0","title":"GenLSP.Structures.WillSaveTextDocumentParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.WillSaveTextDocumentParams.html#t:t/0","title":"GenLSP.Structures.WillSaveTextDocumentParams.t/0","type":"type"},{"doc":"","ref":"GenLSP.Structures.WindowClientCapabilities.html","title":"GenLSP.Structures.WindowClientCapabilities","type":"module"},{"doc":"Fields work_done_progress: It indicates whether the client supports server initiated progress using the window/workDoneProgress/create request. The capability also controls Whether client supports handling of progress notifications. If set servers are allowed to report a workDoneProgress property in the request specific server capabilities. @since 3.15.0 show_message: Capabilities specific to the showMessage request. @since 3.16.0 show_document: Capabilities specific to the showDocument request. @since 3.16.0","ref":"GenLSP.Structures.WindowClientCapabilities.html#__struct__/0","title":"GenLSP.Structures.WindowClientCapabilities.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.WindowClientCapabilities.html#t:t/0","title":"GenLSP.Structures.WindowClientCapabilities.t/0","type":"type"},{"doc":"","ref":"GenLSP.Structures.WorkDoneProgressBegin.html","title":"GenLSP.Structures.WorkDoneProgressBegin","type":"module"},{"doc":"Fields kind title: Mandatory title of the progress operation. Used to briefly inform about the kind of operation being performed. Examples: &quot;Indexing&quot; or &quot;Linking dependencies&quot;. cancellable: Controls if a cancel button should show to allow the user to cancel the long running operation. Clients that don't support cancellation are allowed to ignore the setting. message: Optional, more detailed associated progress message. Contains complementary information to the title . Examples: &quot;3/25 files&quot;, &quot;project/src/module2&quot;, &quot;node_modules/some_dep&quot;. If unset, the previous progress message (if any) is still valid. percentage: Optional progress percentage to display (value 100 is considered 100%). If not provided infinite progress is assumed and clients are allowed to ignore the percentage value in subsequent in report notifications. The value should be steadily rising. Clients are free to ignore values that are not following this rule. The value range is [0, 100].","ref":"GenLSP.Structures.WorkDoneProgressBegin.html#__struct__/0","title":"GenLSP.Structures.WorkDoneProgressBegin.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.WorkDoneProgressBegin.html#t:t/0","title":"GenLSP.Structures.WorkDoneProgressBegin.t/0","type":"type"},{"doc":"","ref":"GenLSP.Structures.WorkDoneProgressCancelParams.html","title":"GenLSP.Structures.WorkDoneProgressCancelParams","type":"module"},{"doc":"Fields token: The token to be used to report progress.","ref":"GenLSP.Structures.WorkDoneProgressCancelParams.html#__struct__/0","title":"GenLSP.Structures.WorkDoneProgressCancelParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.WorkDoneProgressCancelParams.html#t:t/0","title":"GenLSP.Structures.WorkDoneProgressCancelParams.t/0","type":"type"},{"doc":"","ref":"GenLSP.Structures.WorkDoneProgressCreateParams.html","title":"GenLSP.Structures.WorkDoneProgressCreateParams","type":"module"},{"doc":"Fields token: The token to be used to report progress.","ref":"GenLSP.Structures.WorkDoneProgressCreateParams.html#__struct__/0","title":"GenLSP.Structures.WorkDoneProgressCreateParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.WorkDoneProgressCreateParams.html#t:t/0","title":"GenLSP.Structures.WorkDoneProgressCreateParams.t/0","type":"type"},{"doc":"","ref":"GenLSP.Structures.WorkDoneProgressEnd.html","title":"GenLSP.Structures.WorkDoneProgressEnd","type":"module"},{"doc":"Fields kind message: Optional, a final message indicating to for example indicate the outcome of the operation.","ref":"GenLSP.Structures.WorkDoneProgressEnd.html#__struct__/0","title":"GenLSP.Structures.WorkDoneProgressEnd.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.WorkDoneProgressEnd.html#t:t/0","title":"GenLSP.Structures.WorkDoneProgressEnd.t/0","type":"type"},{"doc":"","ref":"GenLSP.Structures.WorkDoneProgressOptions.html","title":"GenLSP.Structures.WorkDoneProgressOptions","type":"module"},{"doc":"Fields work_done_progress","ref":"GenLSP.Structures.WorkDoneProgressOptions.html#__struct__/0","title":"GenLSP.Structures.WorkDoneProgressOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.WorkDoneProgressOptions.html#t:t/0","title":"GenLSP.Structures.WorkDoneProgressOptions.t/0","type":"type"},{"doc":"","ref":"GenLSP.Structures.WorkDoneProgressParams.html","title":"GenLSP.Structures.WorkDoneProgressParams","type":"module"},{"doc":"Fields work_done_token: An optional token that a server can use to report work done progress.","ref":"GenLSP.Structures.WorkDoneProgressParams.html#__struct__/0","title":"GenLSP.Structures.WorkDoneProgressParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.WorkDoneProgressParams.html#t:t/0","title":"GenLSP.Structures.WorkDoneProgressParams.t/0","type":"type"},{"doc":"","ref":"GenLSP.Structures.WorkDoneProgressReport.html","title":"GenLSP.Structures.WorkDoneProgressReport","type":"module"},{"doc":"Fields kind cancellable: Controls enablement state of a cancel button. Clients that don't support cancellation or don't support controlling the button's enablement state are allowed to ignore the property. message: Optional, more detailed associated progress message. Contains complementary information to the title . Examples: &quot;3/25 files&quot;, &quot;project/src/module2&quot;, &quot;node_modules/some_dep&quot;. If unset, the previous progress message (if any) is still valid. percentage: Optional progress percentage to display (value 100 is considered 100%). If not provided infinite progress is assumed and clients are allowed to ignore the percentage value in subsequent in report notifications. The value should be steadily rising. Clients are free to ignore values that are not following this rule. The value range is [0, 100]","ref":"GenLSP.Structures.WorkDoneProgressReport.html#__struct__/0","title":"GenLSP.Structures.WorkDoneProgressReport.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.WorkDoneProgressReport.html#t:t/0","title":"GenLSP.Structures.WorkDoneProgressReport.t/0","type":"type"},{"doc":"Workspace specific client capabilities.","ref":"GenLSP.Structures.WorkspaceClientCapabilities.html","title":"GenLSP.Structures.WorkspaceClientCapabilities","type":"module"},{"doc":"Fields apply_edit: The client supports applying batch edits to the workspace by supporting the request 'workspace/applyEdit' workspace_edit: Capabilities specific to WorkspaceEdit s. did_change_configuration: Capabilities specific to the workspace/didChangeConfiguration notification. did_change_watched_files: Capabilities specific to the workspace/didChangeWatchedFiles notification. symbol: Capabilities specific to the workspace/symbol request. execute_command: Capabilities specific to the workspace/executeCommand request. workspace_folders: The client has support for workspace folders. @since 3.6.0 configuration: The client supports workspace/configuration requests. @since 3.6.0 semantic_tokens: Capabilities specific to the semantic token requests scoped to the workspace. @since 3.16.0. code_lens: Capabilities specific to the code lens requests scoped to the workspace. @since 3.16.0. file_operations: The client has support for file notifications/requests for user operations on files. Since 3.16.0 inline_value: Capabilities specific to the inline values requests scoped to the workspace. @since 3.17.0. inlay_hint: Capabilities specific to the inlay hint requests scoped to the workspace. @since 3.17.0. diagnostics: Capabilities specific to the diagnostic requests scoped to the workspace. @since 3.17.0.","ref":"GenLSP.Structures.WorkspaceClientCapabilities.html#__struct__/0","title":"GenLSP.Structures.WorkspaceClientCapabilities.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.WorkspaceClientCapabilities.html#t:t/0","title":"GenLSP.Structures.WorkspaceClientCapabilities.t/0","type":"type"},{"doc":"Parameters of the workspace diagnostic request. @since 3.17.0","ref":"GenLSP.Structures.WorkspaceDiagnosticParams.html","title":"GenLSP.Structures.WorkspaceDiagnosticParams","type":"module"},{"doc":"Fields identifier: The additional identifier provided during registration. previous_result_ids: The currently known diagnostic reports with their previous result ids. work_done_token: An optional token that a server can use to report work done progress. partial_result_token: An optional token that a server can use to report partial results (e.g. streaming) to the client.","ref":"GenLSP.Structures.WorkspaceDiagnosticParams.html#__struct__/0","title":"GenLSP.Structures.WorkspaceDiagnosticParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.WorkspaceDiagnosticParams.html#t:t/0","title":"GenLSP.Structures.WorkspaceDiagnosticParams.t/0","type":"type"},{"doc":"A workspace diagnostic report. @since 3.17.0","ref":"GenLSP.Structures.WorkspaceDiagnosticReport.html","title":"GenLSP.Structures.WorkspaceDiagnosticReport","type":"module"},{"doc":"Fields items","ref":"GenLSP.Structures.WorkspaceDiagnosticReport.html#__struct__/0","title":"GenLSP.Structures.WorkspaceDiagnosticReport.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.WorkspaceDiagnosticReport.html#t:t/0","title":"GenLSP.Structures.WorkspaceDiagnosticReport.t/0","type":"type"},{"doc":"A partial result for a workspace diagnostic report. @since 3.17.0","ref":"GenLSP.Structures.WorkspaceDiagnosticReportPartialResult.html","title":"GenLSP.Structures.WorkspaceDiagnosticReportPartialResult","type":"module"},{"doc":"Fields items","ref":"GenLSP.Structures.WorkspaceDiagnosticReportPartialResult.html#__struct__/0","title":"GenLSP.Structures.WorkspaceDiagnosticReportPartialResult.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.WorkspaceDiagnosticReportPartialResult.html#t:t/0","title":"GenLSP.Structures.WorkspaceDiagnosticReportPartialResult.t/0","type":"type"},{"doc":"A workspace edit represents changes to many resources managed in the workspace. The edit should either provide changes or documentChanges . If documentChanges are present they are preferred over changes if the client can handle versioned document edits. Since version 3.13.0 a workspace edit can contain resource operations as well. If resource operations are present clients need to execute the operations in the order in which they are provided. So a workspace edit for example can consist of the following two changes: (1) a create file a.txt and (2) a text document edit which insert text into file a.txt. An invalid sequence (e.g. (1) delete file a.txt and (2) insert text into file a.txt) will cause failure of the operation. How the client recovers from the failure is described by the client capability: workspace.workspaceEdit.failureHandling","ref":"GenLSP.Structures.WorkspaceEdit.html","title":"GenLSP.Structures.WorkspaceEdit","type":"module"},{"doc":"Fields changes: Holds changes to existing resources. document_changes: Depending on the client capability workspace.workspaceEdit.resourceOperations document changes are either an array of TextDocumentEdit s to express changes to n different text documents where each text document edit addresses a specific version of a text document. Or it can contain above TextDocumentEdit s mixed with create, rename and delete file / folder operations. Whether a client supports versioned document edits is expressed via workspace.workspaceEdit.documentChanges client capability. If a client neither supports documentChanges nor workspace.workspaceEdit.resourceOperations then only plain TextEdit s using the changes property are supported. change_annotations: A map of change annotations that can be referenced in AnnotatedTextEdit s or create, rename and delete file / folder operations. Whether clients honor this property depends on the client capability workspace.changeAnnotationSupport . @since 3.16.0","ref":"GenLSP.Structures.WorkspaceEdit.html#__struct__/0","title":"GenLSP.Structures.WorkspaceEdit.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.WorkspaceEdit.html#t:t/0","title":"GenLSP.Structures.WorkspaceEdit.t/0","type":"type"},{"doc":"","ref":"GenLSP.Structures.WorkspaceEditClientCapabilities.html","title":"GenLSP.Structures.WorkspaceEditClientCapabilities","type":"module"},{"doc":"Fields document_changes: The client supports versioned document changes in WorkspaceEdit s resource_operations: The resource operations the client supports. Clients should at least support 'create', 'rename' and 'delete' files and folders. @since 3.13.0 failure_handling: The failure handling strategy of a client if applying the workspace edit fails. @since 3.13.0 normalizes_line_endings: Whether the client normalizes line endings to the client specific setting. If set to true the client will normalize line ending characters in a workspace edit to the client-specified new line character. @since 3.16.0 change_annotation_support: Whether the client in general supports change annotations on text edits, create file, rename file and delete file changes. @since 3.16.0","ref":"GenLSP.Structures.WorkspaceEditClientCapabilities.html#__struct__/0","title":"GenLSP.Structures.WorkspaceEditClientCapabilities.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.WorkspaceEditClientCapabilities.html#t:t/0","title":"GenLSP.Structures.WorkspaceEditClientCapabilities.t/0","type":"type"},{"doc":"A workspace folder inside a client.","ref":"GenLSP.Structures.WorkspaceFolder.html","title":"GenLSP.Structures.WorkspaceFolder","type":"module"},{"doc":"Fields uri: The associated URI for this workspace folder. name: The name of the workspace folder. Used to refer to this workspace folder in the user interface.","ref":"GenLSP.Structures.WorkspaceFolder.html#__struct__/0","title":"GenLSP.Structures.WorkspaceFolder.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.WorkspaceFolder.html#t:t/0","title":"GenLSP.Structures.WorkspaceFolder.t/0","type":"type"},{"doc":"The workspace folder change event.","ref":"GenLSP.Structures.WorkspaceFoldersChangeEvent.html","title":"GenLSP.Structures.WorkspaceFoldersChangeEvent","type":"module"},{"doc":"Fields added: The array of added workspace folders removed: The array of the removed workspace folders","ref":"GenLSP.Structures.WorkspaceFoldersChangeEvent.html#__struct__/0","title":"GenLSP.Structures.WorkspaceFoldersChangeEvent.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.WorkspaceFoldersChangeEvent.html#t:t/0","title":"GenLSP.Structures.WorkspaceFoldersChangeEvent.t/0","type":"type"},{"doc":"","ref":"GenLSP.Structures.WorkspaceFoldersInitializeParams.html","title":"GenLSP.Structures.WorkspaceFoldersInitializeParams","type":"module"},{"doc":"Fields workspace_folders: The workspace folders configured in the client when the server starts. This property is only available if the client supports workspace folders. It can be null if the client supports workspace folders but none are configured. @since 3.6.0","ref":"GenLSP.Structures.WorkspaceFoldersInitializeParams.html#__struct__/0","title":"GenLSP.Structures.WorkspaceFoldersInitializeParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.WorkspaceFoldersInitializeParams.html#t:t/0","title":"GenLSP.Structures.WorkspaceFoldersInitializeParams.t/0","type":"type"},{"doc":"","ref":"GenLSP.Structures.WorkspaceFoldersServerCapabilities.html","title":"GenLSP.Structures.WorkspaceFoldersServerCapabilities","type":"module"},{"doc":"Fields supported: The server has support for workspace folders change_notifications: Whether the server wants to receive workspace folder change notifications. If a string is provided the string is treated as an ID under which the notification is registered on the client side. The ID can be used to unregister for these events using the client/unregisterCapability request.","ref":"GenLSP.Structures.WorkspaceFoldersServerCapabilities.html#__struct__/0","title":"GenLSP.Structures.WorkspaceFoldersServerCapabilities.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.WorkspaceFoldersServerCapabilities.html#t:t/0","title":"GenLSP.Structures.WorkspaceFoldersServerCapabilities.t/0","type":"type"},{"doc":"A full document diagnostic report for a workspace diagnostic result. @since 3.17.0","ref":"GenLSP.Structures.WorkspaceFullDocumentDiagnosticReport.html","title":"GenLSP.Structures.WorkspaceFullDocumentDiagnosticReport","type":"module"},{"doc":"Fields uri: The URI for which diagnostic information is reported. version: The version number for which the diagnostics are reported. If the document is not marked as open null can be provided. kind: A full document diagnostic report. result_id: An optional result id. If provided it will be sent on the next diagnostic request for the same document. items: The actual items.","ref":"GenLSP.Structures.WorkspaceFullDocumentDiagnosticReport.html#__struct__/0","title":"GenLSP.Structures.WorkspaceFullDocumentDiagnosticReport.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.WorkspaceFullDocumentDiagnosticReport.html#t:t/0","title":"GenLSP.Structures.WorkspaceFullDocumentDiagnosticReport.t/0","type":"type"},{"doc":"A special workspace symbol that supports locations without a range. See also SymbolInformation. @since 3.17.0","ref":"GenLSP.Structures.WorkspaceSymbol.html","title":"GenLSP.Structures.WorkspaceSymbol","type":"module"},{"doc":"Fields location: The location of the symbol. Whether a server is allowed to return a location without a range depends on the client capability workspace.symbol.resolveSupport . See SymbolInformation#location for more details. data: A data entry field that is preserved on a workspace symbol between a workspace symbol request and a workspace symbol resolve request. name: The name of this symbol. kind: The kind of this symbol. tags: Tags for this symbol. @since 3.16.0 container_name: The name of the symbol containing this symbol. This information is for user interface purposes (e.g. to render a qualifier in the user interface if necessary). It can't be used to re-infer a hierarchy for the document symbols.","ref":"GenLSP.Structures.WorkspaceSymbol.html#__struct__/0","title":"GenLSP.Structures.WorkspaceSymbol.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.WorkspaceSymbol.html#t:t/0","title":"GenLSP.Structures.WorkspaceSymbol.t/0","type":"type"},{"doc":"Client capabilities for a {@link WorkspaceSymbolRequest}.","ref":"GenLSP.Structures.WorkspaceSymbolClientCapabilities.html","title":"GenLSP.Structures.WorkspaceSymbolClientCapabilities","type":"module"},{"doc":"Fields dynamic_registration: Symbol request supports dynamic registration. symbol_kind: Specific capabilities for the SymbolKind in the workspace/symbol request. tag_support: The client supports tags on SymbolInformation . Clients supporting tags have to handle unknown tags gracefully. @since 3.16.0 resolve_support: The client support partial workspace symbols. The client will send the request workspaceSymbol/resolve to the server to resolve additional properties. @since 3.17.0","ref":"GenLSP.Structures.WorkspaceSymbolClientCapabilities.html#__struct__/0","title":"GenLSP.Structures.WorkspaceSymbolClientCapabilities.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.WorkspaceSymbolClientCapabilities.html#t:t/0","title":"GenLSP.Structures.WorkspaceSymbolClientCapabilities.t/0","type":"type"},{"doc":"Server capabilities for a {@link WorkspaceSymbolRequest}.","ref":"GenLSP.Structures.WorkspaceSymbolOptions.html","title":"GenLSP.Structures.WorkspaceSymbolOptions","type":"module"},{"doc":"Fields resolve_provider: The server provides support to resolve additional information for a workspace symbol. @since 3.17.0 work_done_progress","ref":"GenLSP.Structures.WorkspaceSymbolOptions.html#__struct__/0","title":"GenLSP.Structures.WorkspaceSymbolOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.WorkspaceSymbolOptions.html#t:t/0","title":"GenLSP.Structures.WorkspaceSymbolOptions.t/0","type":"type"},{"doc":"The parameters of a {@link WorkspaceSymbolRequest}.","ref":"GenLSP.Structures.WorkspaceSymbolParams.html","title":"GenLSP.Structures.WorkspaceSymbolParams","type":"module"},{"doc":"Fields query: A query string to filter symbols by. Clients may send an empty string here to request all symbols. work_done_token: An optional token that a server can use to report work done progress. partial_result_token: An optional token that a server can use to report partial results (e.g. streaming) to the client.","ref":"GenLSP.Structures.WorkspaceSymbolParams.html#__struct__/0","title":"GenLSP.Structures.WorkspaceSymbolParams.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.WorkspaceSymbolParams.html#t:t/0","title":"GenLSP.Structures.WorkspaceSymbolParams.t/0","type":"type"},{"doc":"Registration options for a {@link WorkspaceSymbolRequest}.","ref":"GenLSP.Structures.WorkspaceSymbolRegistrationOptions.html","title":"GenLSP.Structures.WorkspaceSymbolRegistrationOptions","type":"module"},{"doc":"Fields resolve_provider: The server provides support to resolve additional information for a workspace symbol. @since 3.17.0","ref":"GenLSP.Structures.WorkspaceSymbolRegistrationOptions.html#__struct__/0","title":"GenLSP.Structures.WorkspaceSymbolRegistrationOptions.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.WorkspaceSymbolRegistrationOptions.html#t:t/0","title":"GenLSP.Structures.WorkspaceSymbolRegistrationOptions.t/0","type":"type"},{"doc":"An unchanged document diagnostic report for a workspace diagnostic result. @since 3.17.0","ref":"GenLSP.Structures.WorkspaceUnchangedDocumentDiagnosticReport.html","title":"GenLSP.Structures.WorkspaceUnchangedDocumentDiagnosticReport","type":"module"},{"doc":"Fields uri: The URI for which diagnostic information is reported. version: The version number for which the diagnostics are reported. If the document is not marked as open null can be provided. kind: A document diagnostic report indicating no changes to the last result. A server can only return unchanged if result ids are provided. result_id: A result id which will be sent on the next diagnostic request for the same document.","ref":"GenLSP.Structures.WorkspaceUnchangedDocumentDiagnosticReport.html#__struct__/0","title":"GenLSP.Structures.WorkspaceUnchangedDocumentDiagnosticReport.__struct__/0","type":"function"},{"doc":"","ref":"GenLSP.Structures.WorkspaceUnchangedDocumentDiagnosticReport.html#t:t/0","title":"GenLSP.Structures.WorkspaceUnchangedDocumentDiagnosticReport.t/0","type":"type"},{"doc":"An identifier to refer to a change annotation stored with a workspace edit.","ref":"GenLSP.TypeAlias.ChangeAnnotationIdentifier.html","title":"GenLSP.TypeAlias.ChangeAnnotationIdentifier","type":"module"},{"doc":"","ref":"GenLSP.TypeAlias.ChangeAnnotationIdentifier.html#t:t/0","title":"GenLSP.TypeAlias.ChangeAnnotationIdentifier.t/0","type":"type"},{"doc":"The declaration of a symbol representation as one or many {@link Location locations}.","ref":"GenLSP.TypeAlias.Declaration.html","title":"GenLSP.TypeAlias.Declaration","type":"module"},{"doc":"","ref":"GenLSP.TypeAlias.Declaration.html#t:t/0","title":"GenLSP.TypeAlias.Declaration.t/0","type":"type"},{"doc":"Information about where a symbol is declared. Provides additional metadata over normal {@link Location location} declarations, including the range of the declaring symbol. Servers should prefer returning DeclarationLink over Declaration if supported by the client.","ref":"GenLSP.TypeAlias.DeclarationLink.html","title":"GenLSP.TypeAlias.DeclarationLink","type":"module"},{"doc":"","ref":"GenLSP.TypeAlias.DeclarationLink.html#t:t/0","title":"GenLSP.TypeAlias.DeclarationLink.t/0","type":"type"},{"doc":"The definition of a symbol represented as one or many {@link Location locations}. For most programming languages there is only one location at which a symbol is defined. Servers should prefer returning DefinitionLink over Definition if supported by the client.","ref":"GenLSP.TypeAlias.Definition.html","title":"GenLSP.TypeAlias.Definition","type":"module"},{"doc":"","ref":"GenLSP.TypeAlias.Definition.html#t:t/0","title":"GenLSP.TypeAlias.Definition.t/0","type":"type"},{"doc":"Information about where a symbol is defined. Provides additional metadata over normal {@link Location location} definitions, including the range of the defining symbol","ref":"GenLSP.TypeAlias.DefinitionLink.html","title":"GenLSP.TypeAlias.DefinitionLink","type":"module"},{"doc":"","ref":"GenLSP.TypeAlias.DefinitionLink.html#t:t/0","title":"GenLSP.TypeAlias.DefinitionLink.t/0","type":"type"},{"doc":"The result of a document diagnostic pull request. A report can either be a full report containing all diagnostics for the requested document or an unchanged report indicating that nothing has changed in terms of diagnostics in comparison to the last pull request. @since 3.17.0","ref":"GenLSP.TypeAlias.DocumentDiagnosticReport.html","title":"GenLSP.TypeAlias.DocumentDiagnosticReport","type":"module"},{"doc":"","ref":"GenLSP.TypeAlias.DocumentDiagnosticReport.html#t:t/0","title":"GenLSP.TypeAlias.DocumentDiagnosticReport.t/0","type":"type"},{"doc":"A document filter describes a top level text document or a notebook cell document. @since 3.17.0 - proposed support for NotebookCellTextDocumentFilter.","ref":"GenLSP.TypeAlias.DocumentFilter.html","title":"GenLSP.TypeAlias.DocumentFilter","type":"module"},{"doc":"","ref":"GenLSP.TypeAlias.DocumentFilter.html#t:t/0","title":"GenLSP.TypeAlias.DocumentFilter.t/0","type":"type"},{"doc":"A document selector is the combination of one or many document filters. @sample let sel:DocumentSelector = [{ language: 'typescript' }, { language: 'json', pattern: '**∕tsconfig.json' }] ; The use of a string as a document filter is deprecated @since 3.16.0.","ref":"GenLSP.TypeAlias.DocumentSelector.html","title":"GenLSP.TypeAlias.DocumentSelector","type":"module"},{"doc":"","ref":"GenLSP.TypeAlias.DocumentSelector.html#t:t/0","title":"GenLSP.TypeAlias.DocumentSelector.t/0","type":"type"},{"doc":"The glob pattern. Either a string pattern or a relative pattern. @since 3.17.0","ref":"GenLSP.TypeAlias.GlobPattern.html","title":"GenLSP.TypeAlias.GlobPattern","type":"module"},{"doc":"","ref":"GenLSP.TypeAlias.GlobPattern.html#t:t/0","title":"GenLSP.TypeAlias.GlobPattern.t/0","type":"type"},{"doc":"Inline value information can be provided by different means: directly as a text value (class InlineValueText). as a name to use for a variable lookup (class InlineValueVariableLookup) as an evaluatable expression (class InlineValueEvaluatableExpression) The InlineValue types combines all inline value types into one type. @since 3.17.0","ref":"GenLSP.TypeAlias.InlineValue.html","title":"GenLSP.TypeAlias.InlineValue","type":"module"},{"doc":"","ref":"GenLSP.TypeAlias.InlineValue.html#t:t/0","title":"GenLSP.TypeAlias.InlineValue.t/0","type":"type"},{"doc":"The LSP any type. Please note that strictly speaking a property with the value undefined can't be converted into JSON preserving the property name. However for convenience it is allowed and assumed that all these properties are optional as well. @since 3.17.0","ref":"GenLSP.TypeAlias.LSPAny.html","title":"GenLSP.TypeAlias.LSPAny","type":"module"},{"doc":"","ref":"GenLSP.TypeAlias.LSPAny.html#t:t/0","title":"GenLSP.TypeAlias.LSPAny.t/0","type":"type"},{"doc":"LSP arrays. @since 3.17.0","ref":"GenLSP.TypeAlias.LSPArray.html","title":"GenLSP.TypeAlias.LSPArray","type":"module"},{"doc":"","ref":"GenLSP.TypeAlias.LSPArray.html#t:t/0","title":"GenLSP.TypeAlias.LSPArray.t/0","type":"type"},{"doc":"LSP object definition. @since 3.17.0","ref":"GenLSP.TypeAlias.LSPObject.html","title":"GenLSP.TypeAlias.LSPObject","type":"module"},{"doc":"","ref":"GenLSP.TypeAlias.LSPObject.html#t:t/0","title":"GenLSP.TypeAlias.LSPObject.t/0","type":"type"},{"doc":"MarkedString can be used to render human readable text. It is either a markdown string or a code-block that provides a language and a code snippet. The language identifier is semantically equal to the optional language identifier in fenced code blocks in GitHub issues. See https://help.github.com/articles/creating-and-highlighting-code-blocks/#syntax-highlighting The pair of a language and a value is an equivalent to markdown: ${value} Note that markdown strings will be sanitized - that means html will be escaped. @deprecated use MarkupContent instead.","ref":"GenLSP.TypeAlias.MarkedString.html","title":"GenLSP.TypeAlias.MarkedString","type":"module"},{"doc":"","ref":"GenLSP.TypeAlias.MarkedString.html#t:t/0","title":"GenLSP.TypeAlias.MarkedString.t/0","type":"type"},{"doc":"A notebook document filter denotes a notebook document by different properties. The properties will be match against the notebook's URI (same as with documents) @since 3.17.0","ref":"GenLSP.TypeAlias.NotebookDocumentFilter.html","title":"GenLSP.TypeAlias.NotebookDocumentFilter","type":"module"},{"doc":"","ref":"GenLSP.TypeAlias.NotebookDocumentFilter.html#t:t/0","title":"GenLSP.TypeAlias.NotebookDocumentFilter.t/0","type":"type"},{"doc":"The glob pattern to watch relative to the base path. Glob patterns can have the following syntax: * to match one or more characters in a path segment ? to match on one character in a path segment ** to match any number of path segments, including none {} to group conditions (e.g. **​/*.{ts,js} matches all TypeScript and JavaScript files) [] to declare a range of characters to match in a path segment (e.g., example.[0-9] to match on example.0 , example.1 , …) [!...] to negate a range of characters to match in a path segment (e.g., example.[!0-9] to match on example.a , example.b , but not example.0 ) @since 3.17.0","ref":"GenLSP.TypeAlias.Pattern.html","title":"GenLSP.TypeAlias.Pattern","type":"module"},{"doc":"","ref":"GenLSP.TypeAlias.Pattern.html#t:t/0","title":"GenLSP.TypeAlias.Pattern.t/0","type":"type"},{"doc":"","ref":"GenLSP.TypeAlias.PrepareRenameResult.html","title":"GenLSP.TypeAlias.PrepareRenameResult","type":"module"},{"doc":"","ref":"GenLSP.TypeAlias.PrepareRenameResult.html#t:t/0","title":"GenLSP.TypeAlias.PrepareRenameResult.t/0","type":"type"},{"doc":"","ref":"GenLSP.TypeAlias.ProgressToken.html","title":"GenLSP.TypeAlias.ProgressToken","type":"module"},{"doc":"","ref":"GenLSP.TypeAlias.ProgressToken.html#t:t/0","title":"GenLSP.TypeAlias.ProgressToken.t/0","type":"type"},{"doc":"An event describing a change to a text document. If only a text is provided it is considered to be the full content of the document.","ref":"GenLSP.TypeAlias.TextDocumentContentChangeEvent.html","title":"GenLSP.TypeAlias.TextDocumentContentChangeEvent","type":"module"},{"doc":"","ref":"GenLSP.TypeAlias.TextDocumentContentChangeEvent.html#t:t/0","title":"GenLSP.TypeAlias.TextDocumentContentChangeEvent.t/0","type":"type"},{"doc":"A document filter denotes a document by different properties like the {@link TextDocument.languageId language}, the {@link Uri.scheme scheme} of its resource, or a glob-pattern that is applied to the {@link TextDocument.fileName path}. Glob patterns can have the following syntax: * to match one or more characters in a path segment ? to match on one character in a path segment ** to match any number of path segments, including none {} to group sub patterns into an OR expression. (e.g. **​/*.{ts,js} matches all TypeScript and JavaScript files) [] to declare a range of characters to match in a path segment (e.g., example.[0-9] to match on example.0 , example.1 , …) [!...] to negate a range of characters to match in a path segment (e.g., example.[!0-9] to match on example.a , example.b , but not example.0 ) @sample A language filter that applies to typescript files on disk: { language: 'typescript', scheme: 'file' } @sample A language filter that applies to all package.json paths: { language: 'json', pattern: '**package.json' } @since 3.17.0","ref":"GenLSP.TypeAlias.TextDocumentFilter.html","title":"GenLSP.TypeAlias.TextDocumentFilter","type":"module"},{"doc":"","ref":"GenLSP.TypeAlias.TextDocumentFilter.html#t:t/0","title":"GenLSP.TypeAlias.TextDocumentFilter.t/0","type":"type"},{"doc":"A workspace diagnostic document report. @since 3.17.0","ref":"GenLSP.TypeAlias.WorkspaceDocumentDiagnosticReport.html","title":"GenLSP.TypeAlias.WorkspaceDocumentDiagnosticReport","type":"module"},{"doc":"","ref":"GenLSP.TypeAlias.WorkspaceDocumentDiagnosticReport.html#t:t/0","title":"GenLSP.TypeAlias.WorkspaceDocumentDiagnosticReport.t/0","type":"type"}]